**************************************************************
**Syntax producing the USA heritage time use files 1975-1976**
**written by Dr. Kimberly Fisher, Institute for Social and  **
**Economic Research, University of Essex, Wivenhoe Park     **
**Colchester, United Kingdom                                **
**11 April 2006, updated 20 May 2010, 5 October 2010        **
**************************************************************.

*****************************************
*Part 2 - create diary files for spouses*
*****************************************.

**************************************************
**In the base file, respondent information and  **
**spouse information appears on the same row    **
**case for each main respondent. The columns    **
**alternate from main respondent information to **
**spouse information (with spouse columns blank **
**for respondents who did not have a spouse/    **
**partner as well as for those who have a       **
**partner on whom no information was collected  **
**in that wave. The original survey then copied **
**the row cases of the main respondents with    **
**spouses or partners and appended these rows   **
**to the end of the file, then transposed the   **
**spouse and main respondent column information **
**on the new spouse rows. Thus, the spouse      **
**columns on the spouse rows contain the same   **
**information found on the main respondent rows **
**in the main respondent columns, minus some    **
**information asked only of main respondents.   **
**The respondent columns on the spouse rows     **
**mirror the spouse column information on the   **
**main respondent rows - with one problem - the **
**information collected from main respondents   **
**but not asked of spouses is not deleted from  **
**the main respondent columns for the spouses.  **
**Thus, if one uses the spouse rows and main    **
**respondent columns, one obtains the misleading**
**impression that spouses also provided who else**
**is present and secondary activity information,**
**when spouses were not asked this information. **
**As the spouses are not included in the main   **
**heritage file but as an adjunct to the main   **
**respondent file, this file extracts the spouse**
**demographic information from the base files   **
**from the spouse columns on the respondent rows**
**Two syntax files document the testing of the  **
**original file to confirm the files structure: **
**convertUSATUV-OLDpart1.sps and test diaries on**
**rows.sps                                      **
**************************************************.

**********
**WAVE 1**
**********.

*********************************************
**demographic and day variables for spouses**
*********************************************.

*************************************************
**a number of variables mention the age and the**
**sex of the spouse, but there are some errors **
**in these variables. The range of variables,  **
**v36, v39, v1596, v3650 to v3667, v5661 to    **
**v5678; v5969, have been manually examined for**
**the most consistent fit of information       **
*************************************************.

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2 v1183 v1687 v7968 v3654 v1596 v36 v37 v39 v41 v46 v211 v201 v210 v216 v217 v218 v231 v232 
    v234 v226 v222 v336 v1187 v1188 v1189 v1592.

freq v1187 v1188 v1189 v1596 v211 v1596 v36 v37 v39 v41 v46 v201 v210 v216 v217 v218 v231 v232 v234 
     v226 v222 v336. 

rename variables
     (v2 v1183 v1187 v1188 v1596 v211 v336 v3654=
      hhid pid month cday sexsp wkhrsp mwagesp agesp).

recode pid v1687 (sysmis=-8).
Do if pid=-8.
   compute pid= v1687.
End if.
desc pid. 
*some -8 values remain. Test that these -8 values
*only represent main respondents without spouses
*by checking the pid codes for the corresponding
*spouse rows - here there should be no -8 and all 
*values between 1 and 1999.
temp.
select if hhid>1999.
desc pid.

compute usualday =-8.
val lab usualday
    -8 missing
    -7 not asked of spouses
     0 usual day
     1 unusual day.
If v1592=5 usualday=0.
If v1592=1 usualday=1.
freq usualday.
cro usualday by v1592.

*spouse information from the respondent row selected.

select if v7968=1 and pid>0.
desc hhid pid.

*rows now exist for 912 spouses; as there are 887 spouse diaries,
*these extra cases are be saved for weighting probabilities later.

*correct age errors.
If hhid=992  agesp=98.
If hhid=1027 agesp=23.
If hhid=1202 agesp=64.
If hhid=1472 agesp=68.
If hhid=1480 agesp=29.
If pid=2531 agesp=51.
If pid=2059 agesp=74.
If pid=2803 agesp=68.
If pid=2351 agesp=72.
If pid=2698 agesp=73.
If pid=2518 agesp=60.
If pid=2873 agesp=50.
If pid=2662 agesp=68.
If pid=2668 agesp=45.
If pid=2165 agesp=55.
If pid=2713 agesp=54.
If pid=2036 agesp=69.
If pid=2512 agesp=55.
If pid=2852 agesp=55.
If pid=2645 agesp=69.
If pid=8136 agesp=48.
If pid=2334 agesp=47.
If pid=2385 agesp=44.
If pid=2297 agesp=47.
If pid=2342 agesp=46.
If pid=2837 agesp=45.
If pid=2237 agesp=48.
If pid=2429 agesp=41.
If pid=2212 agesp=41.
If hhid=928 agesp=41.
If hhid=883 agesp=26.
If hhid=833 agesp=43.
If hhid=58  agesp=37.
If hhid=1014 agesp=40.
If hhid=1144 agesp=30.
If hhid=355 agesp=37.
If hhid=823 agesp=33.
If hhid=1257 agesp=33.
If hhid=1420 agesp=29.
If hhid=985 agesp=31.
If hhid=1030 agesp=29.
If hhid=169 agesp=27.
If hhid=634 agesp=27.
If hhid=996 agesp=21.
If hhid=1430 agesp=26.
If hhid=1268 agesp=18.
If hhid=1085 agesp=46.
If hhid=95 agesp=18.
If hhid=12 agesp=74.
If hhid=214 agesp=83.
If hhid=246 agesp=58.
If hhid=521 agesp=50.
If hhid=575 agesp=51.
If hhid=652 agesp=34.
If hhid=800 agesp=70.
recode agesp (sysmis=-8).
freq agesp.

compute year=1975.
recode month cday (sysmis=-8).
recode v1189 (1=2) (2=3) (3=4) (4=5) (5=6) (6=7) (7=1) (0=1) (ELSE=-8) 
   INTO diaryday.
compute empstsp=-8.
compute educsp=-8.
compute disrtsp=0.
compute unempsp=0.
compute students=0.
compute wave=1.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp1.sav'.

freq year wave cday month.
cro v1189 by diaryday.

*these cross-tabs reveal no overlap between the 2 variables for age of spouse 
*and the 3 variables for the level of education of the spouse.
cro v36 by v39.
cro v37 by v41 by v46.

*note that the three working status variables have
*low levels of reported information.
temp. 
select if v201=5.
desc wkhrsp mwagesp.
*the people reported as not working on variable 201
*have no reported income, though a few have reported 
*hours of work.
cro v201 by v216.
*note that the working status variables are not
*consistent with one another.

means wkhrsp by v201
   /cells min max mean.

temp.
select if v216>0.
freq wkhrsp.

means mwagesp wkhrsp by v201 v210 v216
   /cells min max mean. 

cro v210 by v201 v226 v222.
*note also that v210 has labels for 1 digit but has two digit
*values, where the first digit seems to largely conform with
*the 1 digit labels.

temp.
select if pid>1999.
freq v210 v201 v226 v222.

cro v210 by v231.

temp.
select if v210>19.
freq wkhrsp.

recode wkhrsp mwagesp (sysmis=-8). 
recode v210 (sysmis=0).

Do if ((v210>0 and v210<20) or (v201=1 and mwagesp>0 and
   wkhrsp>0)) and wkhrsp>20.
   compute empstsp=1.
Else if ((v210>0 and v210<20) or (v201=1 and mwagesp>0 and
   wkhrsp>0)) and (wkhrsp>0 and wkhrsp<21).
   compute empstsp=2.
Else if v210>0 and v210<20.
   compute empstsp=3.
Else if v210>19 and (wkhrsp>0 and wkhrsp<21).
   compute empstsp=2.
Else if v210>19 and (wkhrsp>20).
   compute empstsp=1.
Else if v210>19.
   compute empstsp=4.
Else if v201=5.
   compute empstsp=4.
End if.
If empstsp=-8 and v210>19 empstsp=4.
freq empstsp.
cro empstsp by v210.
means wkhrsp by empstsp
   /cells min max mean.

temp.
select if agesp>-8.
means agesp by empstsp
   /cells min max mean.

If wkhrsp=-8 and empstsp=4 wkhrsp=0.
If mwagesp=-8 and empstsp=4 mwagesp=0.
freq wkhrsp mwagesp.

temp.
select if wkhrsp>-8.
means wkhrsp by empstsp
   /cells min max mean.

temp.
select if mwagesp>-8.
means mwagesp by empstsp
   /cells min max mean.

*correct errors with sex.
recode sexsp (sysmis=-8).
If hhid=1393 sexsp=2. 
If hhid=17   sexsp=1. 
If hhid=73   sexsp=1. 
If hhid=792  sexsp=1. 
If hhid=313  sexsp=2. 
If hhid=831  sexsp=1. 
If hhid=136  sexsp=1. 
If hhid=818  sexsp=2. 
If hhid=558  sexsp=1. 
If hhid=929  sexsp=1. 
If hhid=1023 sexsp=1. 
If hhid=1377 sexsp=1. 
If hhid=1511 sexsp=2. 
If hhid=528  sexsp=1. 
If hhid=791  sexsp=1. 
If hhid=1285 sexsp=2. 
If hhid=985  sexsp=1. 
If hhid=1030 sexsp=1. 
If hhid=102  sexsp=2. 
If hhid=1503 sexsp=1. 
If hhid=1263 sexsp=2. 
If hhid=1430 sexsp=1. 
If hhid=1347 sexsp=1. 
If hhid=425  sexsp=1. 
If hhid=1069 sexsp=1. 
If hhid=1085 sexsp=1. 
If hhid=833  sexsp=2. 
If hhid=928  sexsp=1. 
If hhid=1271 sexsp=1. 
If hhid=1341 sexsp=2. 
If hhid=204  sexsp=1. 
If hhid=379  sexsp=1. 
If hhid=226  sexsp=1. 
If hhid=901  sexsp=2. 
If hhid=1090 sexsp=1. 
If hhid=851  sexsp=1. 
freq sexsp.

recode v37 v46 v41 (sysmis=0).
Do if v37>0 and v37<96.
   compute educsp= v37.
Else if v46>0.
   compute educsp= v46.
Else if v41>0 and v41<96.
   compute educsp= v41.
End if.
Recode educsp (6=5) (5=4) (4=3).
freq educsp.
cro educsp by v37 v41 v46. 

cro v231 by v234.
cro v231 by v210.

recode v222 v226 (sysmis=0).
If v231=1 or v231=2 unempsp=1.
If v226>0 or (v210>69 and v210<80) students=1.
If v222>0 or (v210>49 and v210<60) disrtsp=1.
freq students unempsp disrtsp.
cro students by v226 v210.
cro unempsp by v231 v210.
cro disrtsp by v222 v210.

temp.
select if agesp>-8.
means agesp by students unempsp disrtsp
   /cells min max mean.

sort cases by wave hhid pid.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w1dspdem.sav'
  /BREAK=wave hhid pid
  /agesp = MAX(agesp) /sexsp = MAX(sexsp) /educsp = MAX(educsp) 
  /wkhrsp = MAX(wkhrsp) /empstsp = MAX(empstsp) /unempsp = 
  MAX(unempsp) /disrtsp = MAX(disrtsp) /students = MAX(students) 
  /mwagesp = MAX(mwagesp) /diaryday = MAX(diaryday) /cday =
  MAX(cday) /month = MAX(month) /year = MAX(year).

**************************************************************
**For more convenience in converting the main respondent and**
**spouse diaries, I extract diaries from the main respondent**
**columns for both sets, here saving the spouse rows        **
**************************************************************.

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2  v1183 v1687 v7968
 v434  v442  v450  v458  v466  v474  v482  v490  v498  v506
 v514  v522  v530  v538  v546  v554  v562  v570  v578  v586
 v594  v602  v610  v618  v626  v634  v642  v650  v658  v666
 v674  v682  v690  v698  v706  v714  v722  v730  v738  v746
 v754  v762  v770  v778  v786  v794  v802  v810  v818  v826
 v834  v842  v850  v858  v866  v874  v882  v890  v898  v906
 v914  v922  v930  v938  v946  v954  v962  v970  v978  v986
 v994  v1002 v1010 v1018 v1026 v1034 v1042 v1050 v1058 v1066
 v437  v445  v453  v461  v469  v477  v485  v493  v501  v509
 v517  v525  v533  v541  v549  v557  v565  v573  v581  v589
 v597  v605  v613  v621  v629  v637  v645  v653  v661  v669
 v677  v685  v693  v701  v709  v717  v725  v733  v741  v749
 v757  v765  v773  v781  v789  v797  v805  v813  v821  v829
 v837  v845  v853  v861  v869  v877  v885  v893  v901  v909
 v917  v925  v933  v941  v949  v957  v965  v973  v981  v989
 v997  v1005 v1013 v1021 v1029 v1037 v1045 v1053 v1061 v1069
 v435  v443  v451  v459  v467  v475  v483  v491  v499  v507
 v515  v523  v531  v539  v547  v555  v563  v571  v579  v587
 v595  v603  v611  v619  v627  v635  v643  v651  v659  v667
 v675  v683  v691  v699  v707  v715  v723  v731  v739  v747
 v755  v763  v771  v779  v787  v795  v803  v811  v819  v827
 v835  v843  v851  v859  v867  v875  v883  v891  v899  v907
 v915  v923  v931  v939  v947  v955  v963  v971  v979  v987
 v995  v1003 v1011 v1019 v1027 v1035 v1043 v1051 v1059 v1067
 v436  v444  v452  v460  v468  v476  v484  v492  v500  v508
 v516  v524  v532  v540  v548  v556  v564  v572  v580  v588
 v596  v604  v612  v620  v628  v636  v644  v652  v660  v668
 v676  v684  v692  v700  v708  v716  v724  v732  v740  v748
 v756  v764  v772  v780  v788  v796  v804  v812  v820  v828
 v836  v844  v852  v860  v868  v876  v884  v892  v900  v908
 v916  v924  v932  v940  v948  v956  v964  v972  v980  v988
 v996  v1004 v1012 v1020 v1028 v1036 v1044 v1052 v1060 v1068
 v7972 v7973 v7976.

rename variables
(v434  v442  v450  v458  v466  v474  v482  v490  v498  v506 
 v514  v522  v530  v538  v546  v554  v562  v570  v578  v586 
 v594  v602  v610  v618  v626  v634  v642  v650  v658  v666 
 v674  v682  v690  v698  v706  v714  v722  v730  v738  v746 
 v754  v762  v770  v778  v786  v794  v802  v810  v818  v826 
 v834  v842  v850  v858  v866  v874  v882  v890  v898  v906 
 v914  v922  v930  v938  v946  v954  v962  v970  v978  v986 
 v994  v1002 v1010 v1018 v1026 v1034 v1042 v1050 v1058 v1066=
 pri1  pri2  pri3  pri4  pri5  pri6  pri7  pri8  pri9  pri10
 pri11 pri12 pri13 pri14 pri15 pri16 pri17 pri18 pri19 pri20
 pri21 pri22 pri23 pri24 pri25 pri26 pri27 pri28 pri29 pri30
 pri31 pri32 pri33 pri34 pri35 pri36 pri37 pri38 pri39 pri40
 pri41 pri42 pri43 pri44 pri45 pri46 pri47 pri48 pri49 pri50
 pri51 pri52 pri53 pri54 pri55 pri56 pri57 pri58 pri59 pri60
 pri61 pri62 pri63 pri64 pri65 pri66 pri67 pri68 pri69 pri70
 pri71 pri72 pri73 pri74 pri75 pri76 pri77 pri78 pri79 pri80).

vector secact(80) wha(80) whb(80).
Do repeat a=secact1 to whb80.
   compute a=-9.
End repeat.
freq secact1 secact80 wha1 whb80.

rename variables
(v437  v445  v453  v461  v469  v477  v485  v493  v501  v509 
 v517  v525  v533  v541  v549  v557  v565  v573  v581  v589 
 v597  v605  v613  v621  v629  v637  v645  v653  v661  v669
 v677  v685  v693  v701  v709  v717  v725  v733  v741  v749 
 v757  v765  v773  v781  v789  v797  v805  v813  v821  v829 
 v837  v845  v853  v861  v869  v877  v885  v893  v901  v909
 v917  v925  v933  v941  v949  v957  v965  v973  v981  v989 
 v997  v1005 v1013 v1021 v1029 v1037 v1045 v1053 v1061 v1069=
 whr1  whr2  whr3  whr4  whr5  whr6  whr7  whr8  whr9  whr10
 whr11 whr12 whr13 whr14 whr15 whr16 whr17 whr18 whr19 whr20
 whr21 whr22 whr23 whr24 whr25 whr26 whr27 whr28 whr29 whr30
 whr31 whr32 whr33 whr34 whr35 whr36 whr37 whr38 whr39 whr40
 whr41 whr42 whr43 whr44 whr45 whr46 whr47 whr48 whr49 whr50
 whr51 whr52 whr53 whr54 whr55 whr56 whr57 whr58 whr59 whr60
 whr61 whr62 whr63 whr64 whr65 whr66 whr67 whr68 whr69 whr70
 whr71 whr72 whr73 whr74 whr75 whr76 whr77 whr78 whr79 whr80).

rename variables
(v435  v443  v451  v459  v467  v475  v483  v491  v499  v507 
 v515  v523  v531  v539  v547  v555  v563  v571  v579  v587 
 v595  v603  v611  v619  v627  v635  v643  v651  v659  v667
 v675  v683  v691  v699  v707  v715  v723  v731  v739  v747 
 v755  v763  v771  v779  v787  v795  v803  v811  v819  v827 
 v835  v843  v851  v859  v867  v875  v883  v891  v899  v907
 v915  v923  v931  v939  v947  v955  v963  v971  v979  v987 
 v995  v1003 v1011 v1019 v1027 v1035 v1043 v1051 v1059 v1067=
 str1  str2  str3  str4  str5  str6  str7  str8  str9  str10
 str11 str12 str13 str14 str15 str16 str17 str18 str19 str20
 str21 str22 str23 str24 str25 str26 str27 str28 str29 str30
 str31 str32 str33 str34 str35 str36 str37 str38 str39 str40
 str41 str42 str43 str44 str45 str46 str47 str48 str49 str50
 str51 str52 str53 str54 str55 str56 str57 str58 str59 str60
 str61 str62 str63 str64 str65 str66 str67 str68 str69 str70
 str71 str72 str73 str74 str75 str76 str77 str78 str79 str80).

rename variables
(v436  v444  v452  v460  v468  v476  v484  v492  v500  v508 
 v516  v524  v532  v540  v548  v556  v564  v572  v580  v588 
 v596  v604  v612  v620  v628  v636  v644  v652  v660  v668
 v676  v684  v692  v700  v708  v716  v724  v732  v740  v748 
 v756  v764  v772  v780  v788  v796  v804  v812  v820  v828 
 v836  v844  v852  v860  v868  v876  v884  v892  v900  v908
 v916  v924  v932  v940  v948  v956  v964  v972  v980  v988 
 v996  v1004 v1012 v1020 v1028 v1036 v1044 v1052 v1060 v1068=
 fin1  fin2  fin3  fin4  fin5  fin6  fin7  fin8  fin9  fin10
 fin11 fin12 fin13 fin14 fin15 fin16 fin17 fin18 fin19 fin20
 fin21 fin22 fin23 fin24 fin25 fin26 fin27 fin28 fin29 fin30
 fin31 fin32 fin33 fin34 fin35 fin36 fin37 fin38 fin39 fin40
 fin41 fin42 fin43 fin44 fin45 fin46 fin47 fin48 fin49 fin50
 fin51 fin52 fin53 fin54 fin55 fin56 fin57 fin58 fin59 fin60
 fin61 fin62 fin63 fin64 fin65 fin66 fin67 fin68 fin69 fin70
 fin71 fin72 fin73 fin74 fin75 fin76 fin77 fin78 fin79 fin80).

rename variable (v2 v1183 = pid hhid).

recode hhid v1687 (sysmis=-8).
Do if hhid=-8.
   compute hhid= v1687.
End if.
desc hhid. 

temp.
select if pid>1999.
desc hhid.

compute survey=2.
freq survey.

*select spouse line diaries.

select if v7968=2.
desc hhid.

sort cases by hhid pid.

vector pri = pri1 to pri80 /secact = secact1 to secact80 /whr = whr1 to whr80 
      /wha = wha1 to wha80 /whb = whb1 to whb80 /str = str1 to str80
      /fin = fin1 to fin80.

loop i=1 to 80.
     compute pri=pri(i).
     compute secact=secact(i).
     compute whr=whr(i).
     compute wha=wha(i).
     compute whb=whb(i).
     compute str=str(i).
     compute fin=fin(i).
     var lab pri main activity.
     var lab secact secondary activity.
     var lab whr location.
     var lab wha "with whom 1st mention".
     var lab whb "with whom 2nd mention".
     var lab str start time.
     var lab fin finish time.
     val lab pri secact
      -8  missing
       0	'no secondary activity'
      11	'normal work-main job inc work at home'
      12    'work at home'
      22	'job search, look for work'
      23	'apply for, collect unemployment benefit'
      24	'apply for/collect other welfare'
      59	'2nd job (& small jobs of FT students)'
      69	'meals at work'
      78	'time before or after work at workplace'
      79	'other work related activity'
      89	'work breaks'
      97	'travel related to job search'
      98	'travel to/from work making other stops'
      99	'travel directly to/from workplace'
     109	'meal preparation, cook or serve food'
     119	'meal clean-up, do dishes'
     129	'routine indoor cleaning & chores'
     139	'routine clean house (outside)'
     149	'laundry, iron, fold clothes'
     161	'repair vehicle, home'
     162	'exterior repairs or maintenance'
     163	'car care, cleaning, tune up'
     164	'home improvements, remodelling'
     171	'gardening'
     172    'care of pets, walk dogs'
     173	'care of house plants'
     191	'other domestic work'
     192	'putter in yard'
     193	'household paperwork, pay bills'
     197	'other household chores'
     209	'care of babies aged under 5 years old'
     218	'care for children of mixed ages'
     219	'care for child aged 5-17'
     221	'teach child skill, show how to do things'
     222	'help child with homework'
     239	'read to/talk with child, listen to child'
     249	'adult play with child inside'
     259	'sport, walk, outside with child'
     269	'medical care for child'
     278	'unpaid babysitting'
     279	'other child care'
     299	'child care travel'
     301	'groceries, supermarket, shop for food'
     302	'other shopping for goods or clothes'
     311	'shop for goods, durables, appliances'
     312	'look to rent/purchase housing'
     329	'personal care services'
     339	'medical care, doctor, dentist'
     341	'financial services'
     342	'government services'
     351	'auto repair and related services'
     352	'clothes repair, cleaning services'
     353	'appliance repair services'
     354	'household repair services'
     379	'other services, go to the dump'
     389	'running errands'
     399	'travel related to goods or services'
     409	'wash, dress, get ready'
     411	'medical care of self at home'
     412	'medical care to adults in household'
     421	'non-medical care to adult from household'
     422	'help/care for adult from other household'
     423	'help/care for neighbours or friends'
     424	'help or care for unspecified adults'
     439	'meals & snacks at own home'
     449	'meal/snack away from home or workplace'
     459	'main sleep'
     469	'naps and resting'
     481	'time gap greater than 10 minutes'
     482	'personal, private, none of your business'
     483	'sex, make out'
     489	'other personal care'
     498	'travel related to adult care'
     499	'travel related to personal care'
     509	'ft student attend classes'
     519	'course/lecture'
     549	'homework, study, research'
     569	'other education'
     579	'end of diary activity'
     599	'other school-related travel'
     601	'union/professional group meetings'
     602	'other union/professional group activity'
     611	'meetings of identity groups'
     612	'other identity group activities'
     621	'meeting of political or civic group'
     622	'other political/civic activities'
     631	'attend meetings of voluntary group'
     632	'office volunteer'
     633	'fundraising activity for voluntary group'
     634	'direct help to persons as a member'
     635	'other voluntary activities for group'
     641	'religious charity group meeting'
     642	'other religious charity activity'
     643	'other religious group meetings'
     644	'other religious group act/social'
     651	'attend religious services'
     652	'private worship'
     661	'meetings of fraternal organisations'
     662	'other fraternal organisation activities'
     671	'meetings of family/youth organisations'
     672	'other family/youth group activities'
     689	'miscl volunteering'
     698	'travel related membership activities'
     699	'travel for other voluntary acts'
     709	'attend sports event'
     719	'other public event'
     729	'movies'
     739	'theater, concert, opera, ballet'
     749	'museum, gallery, zoo, exhibition'
     752	'visiting with others'
     769	'parties, receptions'
     771	'at bar, cocktail lounge'
     772	'dancing'
     789	'other socializing'
     799	'travel related to public events'
     801	'football, basket ball etc'
     802	'tennis, squash etc'
     803	'golf, miniature golf'
     804	'swim, water ski'
     805	'ski, skate'
     806	'bowl, ping-pong'
     807	'frisbee, catch'
     808	'exercise, yoga'
     811	'hunting'
     812	'fishing'
     813	'boat, sail, canoe'
     814	'camping'
     815	'snowmobile, dune buggy'
     816	'gliding, ballooning'
     817	'excursions'
     818    'picnic'
     821	'walking for pleasure'
     822	'hiking'
     823	'jogging, running'
     824	'cycling'
     825	'motorcycling'
     826	'horseback riding'
     831	'photography'
     832	'work on cars as hobby'
     833	'repair leisure equipment'
     834	'collections, scrapbooks'
     835	'carpentry/woodwork as hobby'
     841	'preserve foodstuffs'
     842	'knit, sew, needlework'
     843	'sewing'
     844	'care livestock/animals (not as farmer)'
     851	'sculpture, painting, drawing'
     852	'literature, write poetry'
     861	'play musical instrument'
     862	'sing'
     863	'act'
     864	'non-social dancing'
     871	'play card games'
     872	'play board games'
     873	'play social games'
     874	'puzzles'
     888	'sports classes or training'
     889	'other active leisure'
     899	'travel related to sport or leisure'
     909	'listen to radio'
     919	'watch TV'
     929	'listen to music, records'
     939	'read books'
     941	'read magazines, pamphlets'
     942	'read - not specified what'
     959	'read newspaper'
     961	'phone conversations'
     962	'face to face conversations'
     963	'conversation with hh members'
     979	'read or write letters'
     981	'relax'
     982	'think, plan, reflect'
     983	'do nothing, sit'
     984	'reported act of other, not self'
     989	'other passing leisure, smoke dope'
     999	'travel related to passive leisure'.
     val lab whr
       1  'own home'
       2  'in transit'
       3  'at work'
       4  'other home'
       5  'restaurant or bar'
       6  'indoor leisure place'
       7  'outdoor leisure place'
       8  'other place'.
     val lab wha whb
       0  'alone'
       1  'spouse/fiance'
       2  'close family'
       3  'other resident adult'
       4  'other friend/relation'
       5  'co-worker'
       6  'organisation member'
       7  'neighbour'
       8  'service personnel'
       9  'others'.
     xsave outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse1.sav'
    /keep = survey hhid pid pri secact whr wha whb str fin v7972 v7973 v7976.
end loop.
execute.

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse1.sav'.

recode pri (956=959) (sysmis=-8).
freq pri secact.

recode str fin whr (sysmis=-8).
do if str=-8 and fin>-1.
     compute str=0.
Else if str=-8 and hhid~=lag(hhid).
     compute str=0.
     compute fin=1440.
     compute pri=481.
end if.
desc str fin. 

temp.
select if str=0.
freq str.

*this select command just leaves the diaries.
select if pri>-8 and pri~=579.
execute.

sort cases by hhid pid str.

match files files=* 
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w1dspdem.sav'
     /BY hhid.
execute.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse1.sav'
   /keep survey wave hhid pid diaryday cday month year pri secact whr wha whb str fin agesp sexsp educsp 
    wkhrsp empstsp unempsp disrtsp students mwagesp v7972 v7973 v7976.
 
AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp1.sav'
  /BREAK=hhid pid
  /fin_1 = MEAN(fin).

match files 
   files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\testspid1.sav' /in=main
   files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp1.sav' /in=spouse
   /BY hhid.
cro main by spouse.

**********
**WAVE 2**
**********.

*********************************************
**demographic and day variables for spouses**
*********************************************.

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2 v7968 v2541.

rename variables (v2 v2541= hhid spempfr).

select if v7968=1.
desc hhid.

freq spempfr.

AGGREGATE outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\addemp.sav'
   /BREAK=hhid 
   /spempfr = MAX(spempfr). 

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\testspid1.sav'.
GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2 v1183 v1687 v2890 v2891 v2893 v3295 v7968
   v3654 v1596 v3300 v37 v41 v46 v3396 v3402 v3390 
   v3393 v3422 v3430 v3449 v2865.

freq v2890 v2891 v2893 v3295 v3396 v3402 v3390 
     v3393 v3422 v3430 v3449 v2865 v3300. 

rename variables (v2 v1183 v2890 v2891 v1596 v2865 v3654=
                  hhid pid month cday sexsp mwagesp agesp).

*note that there are cases where the spouse and respondent
*new ids later in the file don't lead to perfect matches -
*so the first value for these identifiers used and 
*subsequent ids only used when no value existed for a 
*previous wave.

recode pid v1687 (sysmis=-8).
Do if pid=-8.
   compute pid= v1687.
End if.
desc pid. 

temp.
select if hhid>1999.
desc pid.

match files files=* 
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\addemp.sav'
     /by hhid.
freq spempfr.

compute usualday =-8.
val lab usualday
    -8 missing
    -7 not asked of spouses
     0 usual day
     1 unusual day.
If v3295=5 usualday=0.
If v3295=1 usualday=1.
freq usualday.
cro usualday by v3295.

select if v7968=1 and pid>0.
desc hhid pid.

*rows now exist for 912 spouses; as there are 887 
*spouse diaries, these extra cases are be saved for 
*weighting probabilities later.

*correct age errors.
If hhid=992  agesp=98.
If hhid=1027 agesp=23.
If hhid=1202 agesp=64.
If hhid=1472 agesp=68.
If hhid=1480 agesp=29.
If pid=2531 agesp=51.
If pid=2059 agesp=74.
If pid=2803 agesp=68.
If pid=2351 agesp=72.
If pid=2698 agesp=73.
If pid=2518 agesp=60.
If pid=2873 agesp=50.
If pid=2662 agesp=68.
If pid=2668 agesp=45.
If pid=2165 agesp=55.
If pid=2713 agesp=54.
If pid=2036 agesp=69.
If pid=2512 agesp=55.
If pid=2852 agesp=55.
If pid=2645 agesp=69.
If pid=8136 agesp=48.
If pid=2334 agesp=47.
If pid=2385 agesp=44.
If pid=2297 agesp=47.
If pid=2342 agesp=46.
If pid=2837 agesp=45.
If pid=2237 agesp=48.
If pid=2429 agesp=41.
If pid=2212 agesp=41.
If hhid=928 agesp=41.
If hhid=883 agesp=26.
If hhid=833 agesp=43.
If hhid=58  agesp=37.
If hhid=1014 agesp=40.
If hhid=1144 agesp=30.
If hhid=355 agesp=37.
If hhid=823 agesp=33.
If hhid=1257 agesp=33.
If hhid=1420 agesp=29.
If hhid=985 agesp=31.
If hhid=1030 agesp=29.
If hhid=169 agesp=27.
If hhid=634 agesp=27.
If hhid=996 agesp=21.
If hhid=1430 agesp=26.
If hhid=1268 agesp=18.
If hhid=1085 agesp=46.
If hhid=95 agesp=18.
If hhid=12 agesp=74.
If hhid=214 agesp=83.
If hhid=246 agesp=58.
If hhid=521 agesp=50.
If hhid=575 agesp=51.
If hhid=652 agesp=34.
If hhid=800 agesp=70.
recode agesp (sysmis=-8).
freq agesp.

compute year=1976.
recode month cday (sysmis=-8).
recode v2893 (1=2) (2=3) (3=4) (4=5) (5=6) (6=7) (7=1) (ELSE=-8) 
   INTO diaryday.
compute educsp=-8.
compute wkhrsp=v3396.
compute empstsp=-8.
compute disrtsp=-9.
compute unempsp=0.
compute students=-9.
compute wave=2.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp1.sav'.

freq cday month year wave.
cro v2893 by diaryday.

recode v37 v46 v41 (sysmis=0).
Do if v37>0 and v37<96.
   compute educsp= v37.
Else if v46>0.
   compute educsp= v46.
Else if v41>0 and v41<96.
   compute educsp= v41.
End if.
Recode educsp (6=5) (5=4) (4=3).
freq educsp.
cro educsp by v37 v41 v46. 

cro v3396 by v3402.
*the two work hours variables do not overlap.
recode wkhrsp mwagesp (sysmis=-8). 
if wkhrsp=-8 and v3402>0 wkhrsp=v3402.
cro wkhrsp by v3402.
freq wkhrsp mwagesp.

means wkhrsp by spempfr
   /cells min max mean.    

If v3422=1 or v3430>0 or v3449=1 unempsp=1.
freq students unempsp disrtsp.
cro unempsp by v3422 v3430 v3449.

temp.
select if agesp>-8.
means agesp by unempsp
   /cells min max mean.

Do if wkhrsp>20.
   compute empstsp=1.
Else if wkhrsp>0 and wkhrsp<21.
   compute empstsp=2.
Else if spempfr=1.
   compute empstsp=3.
Else if spempfr=5 or mwagesp<0.
   compute empstsp=4.
End if.
If empstsp=-8 and agesp>65 empstsp=4.
freq empstsp.
cro empstsp by spempfr.
means wkhrsp by empstsp
   /cells min max mean.

temp.
select if agesp>-8.
means agesp by empstsp
   /cells min max mean.

If wkhrsp=-8 and empstsp=4 wkhrsp=0.
If mwagesp=-8 and empstsp=4 mwagesp=0.
freq wkhrsp mwagesp.

temp.
select if wkhrsp>-8.
means wkhrsp by empstsp
   /cells min max mean.

temp.
select if mwagesp>-8.
means mwagesp by empstsp
   /cells min max mean.

*correct errors with sex.
recode sexsp (sysmis=-8).
If hhid=1393 sexsp=2. 
If hhid=17   sexsp=1. 
If hhid=73   sexsp=1. 
If hhid=792  sexsp=1. 
If hhid=313  sexsp=2. 
If hhid=831  sexsp=1. 
If hhid=136  sexsp=1. 
If hhid=818  sexsp=2. 
If hhid=558  sexsp=1. 
If hhid=929  sexsp=1. 
If hhid=1023 sexsp=1. 
If hhid=1377 sexsp=1. 
If hhid=1511 sexsp=2. 
If hhid=528  sexsp=1. 
If hhid=791  sexsp=1. 
If hhid=1285 sexsp=2. 
If hhid=985  sexsp=1. 
If hhid=1030 sexsp=1. 
If hhid=102  sexsp=2. 
If hhid=1503 sexsp=1. 
If hhid=1263 sexsp=2. 
If hhid=1430 sexsp=1. 
If hhid=1347 sexsp=1. 
If hhid=425  sexsp=1. 
If hhid=1069 sexsp=1. 
If hhid=1085 sexsp=1. 
If hhid=833  sexsp=2. 
If hhid=928  sexsp=1. 
If hhid=1271 sexsp=1. 
If hhid=1341 sexsp=2. 
If hhid=204  sexsp=1. 
If hhid=379  sexsp=1. 
If hhid=226  sexsp=1. 
If hhid=901  sexsp=2. 
If hhid=1090 sexsp=1. 
If hhid=851  sexsp=1. 
freq sexsp.

sort cases by wave hhid pid.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w2dspdem.sav'
  /BREAK=wave hhid pid
  /agesp = MAX(agesp) /sexsp = MAX(sexsp) /educsp = MAX(educsp) 
  /wkhrsp = MAX(wkhrsp) /empstsp = MAX(empstsp) /unempsp = 
  MAX(unempsp) /disrtsp = MAX(disrtsp) /students = MAX(students) 
  /mwagesp = MAX(mwagesp) /diaryday = MAX(diaryday) /cday =
  MAX(cday) /month = MAX(month) /year = MAX(year).

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2  v1183 v1687 v7968
 v1693 v1701 v1709 v1717 v1725 v1733 v1741 v1749 v1757 v1765
 v1773 v1781 v1789 v1797 v1805 v1813 v1821 v1829 v1837 v1845
 v1853 v1861 v1869 v1877 v1885 v1893 v1901 v1909 v1917 v1925
 v1933 v1941 v1949 v1957 v1965 v1973 v1981 v1989 v1997 v2005
 v2013 v2021 v2029 v2037 v2045 v2053 v2061 v2069 v2077 v2085
 v2093 v2101 v2109 v2117 v2125 v2133 v2141 v2149 v2157 v2165
 v2173 v2181 v2189 v2197 v2205 v2213 v2221 v2229 v2237 v2245
 v2253 v2261 v2269 v2277 v2285 v2293 v2301 v2309 v2317 v2325
 v1696 v1704 v1712 v1720 v1728 v1736 v1744 v1752 v1760 v1768
 v1776 v1784 v1792 v1800 v1808 v1816 v1824 v1832 v1840 v1848
 v1856 v1864 v1872 v1880 v1888 v1896 v1904 v1912 v1920 v1928
 v1936 v1944 v1952 v1960 v1968 v1976 v1984 v1992 v2000 v2008
 v2016 v2024 v2032 v2040 v2048 v2056 v2064 v2072 v2080 v2088
 v2096 v2104 v2112 v2120 v2128 v2136 v2144 v2152 v2160 v2168
 v2176 v2184 v2192 v2200 v2208 v2216 v2224 v2232 v2240 v2248
 v2256 v2264 v2272 v2280 v2288 v2296 v2304 v2312 v2320 v2328
 v1694 v1702 v1710 v1718 v1726 v1734 v1742 v1750 v1758 v1766
 v1774 v1782 v1790 v1798 v1806 v1814 v1822 v1830 v1838 v1846
 v1854 v1862 v1870 v1878 v1886 v1894 v1902 v1910 v1918 v1926
 v1934 v1942 v1950 v1958 v1966 v1974 v1982 v1990 v1998 v2006
 v2014 v2022 v2030 v2038 v2046 v2054 v2062 v2070 v2078 v2086
 v2094 v2102 v2110 v2118 v2126 v2134 v2142 v2150 v2158 v2166
 v2174 v2182 v2190 v2198 v2206 v2214 v2222 v2230 v2238 v2246
 v2254 v2262 v2270 v2278 v2286 v2294 v2302 v2310 v2318 v2326
 v1695 v1703 v1711 v1719 v1727 v1735 v1743 v1751 v1759 v1767
 v1775 v1783 v1791 v1799 v1807 v1815 v1823 v1831 v1839 v1847
 v1855 v1863 v1871 v1879 v1887 v1895 v1903 v1911 v1919 v1927
 v1935 v1943 v1951 v1959 v1967 v1975 v1983 v1991 v1999 v2007
 v2015 v2023 v2031 v2039 v2047 v2055 v2063 v2071 v2079 v2087
 v2095 v2103 v2111 v2119 v2127 v2135 v2143 v2151 v2159 v2167
 v2175 v2183 v2191 v2199 v2207 v2215 v2223 v2231 v2239 v2247
 v2255 v2263 v2271 v2279 v2287 v2295 v2303 v2311 v2319 v2327
 v7972 v7973 v7976.

rename variables
(v1693 v1701 v1709 v1717 v1725 v1733 v1741 v1749 v1757 v1765
 v1773 v1781 v1789 v1797 v1805 v1813 v1821 v1829 v1837 v1845
 v1853 v1861 v1869 v1877 v1885 v1893 v1901 v1909 v1917 v1925
 v1933 v1941 v1949 v1957 v1965 v1973 v1981 v1989 v1997 v2005
 v2013 v2021 v2029 v2037 v2045 v2053 v2061 v2069 v2077 v2085
 v2093 v2101 v2109 v2117 v2125 v2133 v2141 v2149 v2157 v2165
 v2173 v2181 v2189 v2197 v2205 v2213 v2221 v2229 v2237 v2245
 v2253 v2261 v2269 v2277 v2285 v2293 v2301 v2309 v2317 v2325=
 pri1  pri2  pri3  pri4  pri5  pri6  pri7  pri8  pri9  pri10
 pri11 pri12 pri13 pri14 pri15 pri16 pri17 pri18 pri19 pri20
 pri21 pri22 pri23 pri24 pri25 pri26 pri27 pri28 pri29 pri30
 pri31 pri32 pri33 pri34 pri35 pri36 pri37 pri38 pri39 pri40
 pri41 pri42 pri43 pri44 pri45 pri46 pri47 pri48 pri49 pri50
 pri51 pri52 pri53 pri54 pri55 pri56 pri57 pri58 pri59 pri60
 pri61 pri62 pri63 pri64 pri65 pri66 pri67 pri68 pri69 pri70
 pri71 pri72 pri73 pri74 pri75 pri76 pri77 pri78 pri79 pri80).

vector secact(80) wha(80) whb(80).
Do repeat a=secact1 to whb80.
   compute a=-9.
End repeat.
freq secact1 secact80 wha1 whb80.

rename variables
(v1696 v1704 v1712 v1720 v1728 v1736 v1744 v1752 v1760 v1768
 v1776 v1784 v1792 v1800 v1808 v1816 v1824 v1832 v1840 v1848
 v1856 v1864 v1872 v1880 v1888 v1896 v1904 v1912 v1920 v1928
 v1936 v1944 v1952 v1960 v1968 v1976 v1984 v1992 v2000 v2008
 v2016 v2024 v2032 v2040 v2048 v2056 v2064 v2072 v2080 v2088
 v2096 v2104 v2112 v2120 v2128 v2136 v2144 v2152 v2160 v2168
 v2176 v2184 v2192 v2200 v2208 v2216 v2224 v2232 v2240 v2248
 v2256 v2264 v2272 v2280 v2288 v2296 v2304 v2312 v2320 v2328=
 whr1  whr2  whr3  whr4  whr5  whr6  whr7  whr8  whr9  whr10
 whr11 whr12 whr13 whr14 whr15 whr16 whr17 whr18 whr19 whr20
 whr21 whr22 whr23 whr24 whr25 whr26 whr27 whr28 whr29 whr30
 whr31 whr32 whr33 whr34 whr35 whr36 whr37 whr38 whr39 whr40
 whr41 whr42 whr43 whr44 whr45 whr46 whr47 whr48 whr49 whr50
 whr51 whr52 whr53 whr54 whr55 whr56 whr57 whr58 whr59 whr60
 whr61 whr62 whr63 whr64 whr65 whr66 whr67 whr68 whr69 whr70
 whr71 whr72 whr73 whr74 whr75 whr76 whr77 whr78 whr79 whr80).

rename variables
(v1694 v1702 v1710 v1718 v1726 v1734 v1742 v1750 v1758 v1766
 v1774 v1782 v1790 v1798 v1806 v1814 v1822 v1830 v1838 v1846
 v1854 v1862 v1870 v1878 v1886 v1894 v1902 v1910 v1918 v1926
 v1934 v1942 v1950 v1958 v1966 v1974 v1982 v1990 v1998 v2006
 v2014 v2022 v2030 v2038 v2046 v2054 v2062 v2070 v2078 v2086
 v2094 v2102 v2110 v2118 v2126 v2134 v2142 v2150 v2158 v2166
 v2174 v2182 v2190 v2198 v2206 v2214 v2222 v2230 v2238 v2246
 v2254 v2262 v2270 v2278 v2286 v2294 v2302 v2310 v2318 v2326=
 str1  str2  str3  str4  str5  str6  str7  str8  str9  str10
 str11 str12 str13 str14 str15 str16 str17 str18 str19 str20
 str21 str22 str23 str24 str25 str26 str27 str28 str29 str30
 str31 str32 str33 str34 str35 str36 str37 str38 str39 str40
 str41 str42 str43 str44 str45 str46 str47 str48 str49 str50
 str51 str52 str53 str54 str55 str56 str57 str58 str59 str60
 str61 str62 str63 str64 str65 str66 str67 str68 str69 str70
 str71 str72 str73 str74 str75 str76 str77 str78 str79 str80).

rename variables
(v1695 v1703 v1711 v1719 v1727 v1735 v1743 v1751 v1759 v1767
 v1775 v1783 v1791 v1799 v1807 v1815 v1823 v1831 v1839 v1847
 v1855 v1863 v1871 v1879 v1887 v1895 v1903 v1911 v1919 v1927
 v1935 v1943 v1951 v1959 v1967 v1975 v1983 v1991 v1999 v2007
 v2015 v2023 v2031 v2039 v2047 v2055 v2063 v2071 v2079 v2087
 v2095 v2103 v2111 v2119 v2127 v2135 v2143 v2151 v2159 v2167
 v2175 v2183 v2191 v2199 v2207 v2215 v2223 v2231 v2239 v2247
 v2255 v2263 v2271 v2279 v2287 v2295 v2303 v2311 v2319 v2327=
 fin1  fin2  fin3  fin4  fin5  fin6  fin7  fin8  fin9  fin10
 fin11 fin12 fin13 fin14 fin15 fin16 fin17 fin18 fin19 fin20
 fin21 fin22 fin23 fin24 fin25 fin26 fin27 fin28 fin29 fin30
 fin31 fin32 fin33 fin34 fin35 fin36 fin37 fin38 fin39 fin40
 fin41 fin42 fin43 fin44 fin45 fin46 fin47 fin48 fin49 fin50
 fin51 fin52 fin53 fin54 fin55 fin56 fin57 fin58 fin59 fin60
 fin61 fin62 fin63 fin64 fin65 fin66 fin67 fin68 fin69 fin70
 fin71 fin72 fin73 fin74 fin75 fin76 fin77 fin78 fin79 fin80).

rename variables (v2 v1183 =pid hhid).

recode hhid v1687 (sysmis=-8).
Do if hhid=-8.
   compute hhid= v1687.
End if.
desc hhid. 

select if v7968=2.
desc hhid.

compute survey=2.
freq survey.

sort cases by hhid pid.

vector pri = pri1 to pri80 /secact = secact1 to secact80 /whr = whr1 to whr80 
      /wha = wha1 to wha80 /whb = whb1 to whb80 /str = str1 to str80
      /fin = fin1 to fin80.

loop i=1 to 80.
     compute pri=pri(i).
     compute secact=secact(i).
     compute whr=whr(i).
     compute wha=wha(i).
     compute whb=whb(i).
     compute str=str(i).
     compute fin=fin(i).
     var lab pri main activity.
     var lab secact secondary activity.
     var lab whr location.
     var lab wha "with whom 1st mention".
     var lab whb "with whom 2nd mention".
     var lab str start time.
     var lab fin finish time.
     val lab pri secact
      -8  missing
       0	'no secondary activity'
      11	'normal work-main job inc work at home'
      12    'work at home'
      22	'job search, look for work'
      23	'apply for, collect unemployment benefit'
      24	'apply for/collect other welfare'
      59	'2nd job (& small jobs of FT students)'
      69	'meals at work'
      78	'time before or after work at workplace'
      79	'other work related activity'
      89	'work breaks'
      97	'travel related to job search'
      98	'travel to/from work making other stops'
      99	'travel directly to/from workplace'
     109	'meal preparation, cook or serve food'
     119	'meal clean-up, do dishes'
     129	'routine indoor cleaning & chores'
     139	'routine clean house (outside)'
     149	'laundry, iron, fold clothes'
     161	'repair vehicle, home'
     162	'exterior repairs or maintenance'
     163	'car care, cleaning, tune up'
     164	'home improvements, remodelling'
     171	'gardening'
     172    'care of pets, walk dogs'
     173	'care of house plants'
     191	'other domestic work'
     192	'putter in yard'
     193	'household paperwork, pay bills'
     197	'other household chores'
     209	'care of babies aged under 5 years old'
     218	'care for children of mixed ages'
     219	'care for child aged 5-17'
     221	'teach child skill, show how to do things'
     222	'help child with homework'
     239	'read to/talk with child, listen to child'
     249	'adult play with child inside'
     259	'sport, walk, outside with child'
     269	'medical care for child'
     278	'unpaid babysitting'
     279	'other child care'
     299	'child care travel'
     301	'groceries, supermarket, shop for food'
     302	'other shopping for goods or clothes'
     311	'shop for goods, durables, appliances'
     312	'look to rent/purchase housing'
     329	'personal care services'
     339	'medical care, doctor, dentist'
     341	'financial services'
     342	'government services'
     351	'auto repair and related services'
     352	'clothes repair, cleaning services'
     353	'appliance repair services'
     354	'household repair services'
     379	'other services, go to the dump'
     389	'running errands'
     399	'travel related to goods or services'
     409	'wash, dress, get ready'
     411	'medical care of self at home'
     412	'medical care to adults in household'
     421	'non-medical care to adult from household'
     422	'help/care for adult from other household'
     423	'help/care for neighbours or friends'
     424	'help or care for unspecified adults'
     439	'meals & snacks at own home'
     449	'meal/snack away from home or workplace'
     459	'main sleep'
     469	'naps and resting'
     481	'time gap greater than 10 minutes'
     482	'personal, private, none of your business'
     483	'sex, make out'
     489	'other personal care'
     498	'travel related to adult care'
     499	'travel related to personal care'
     509	'ft student attend classes'
     519	'course/lecture'
     549	'homework, study, research'
     569	'other education'
     579	'end of diary activity'
     599	'other school-related travel'
     601	'union/professional group meetings'
     602	'other union/professional group activity'
     611	'meetings of identity groups'
     612	'other identity group activities'
     621	'meeting of political or civic group'
     622	'other political/civic activities'
     631	'attend meetings of voluntary group'
     632	'office volunteer'
     633	'fundraising activity for voluntary group'
     634	'direct help to persons as a member'
     635	'other voluntary activities for group'
     641	'religious charity group meeting'
     642	'other religious charity activity'
     643	'other religious group meetings'
     644	'other religious group act/social'
     651	'attend religious services'
     652	'private worship'
     661	'meetings of fraternal organisations'
     662	'other fraternal organisation activities'
     671	'meetings of family/youth organisations'
     672	'other family/youth group activities'
     689	'miscl volunteering'
     698	'travel related membership activities'
     699	'travel for other voluntary acts'
     709	'attend sports event'
     719	'other public event'
     729	'movies'
     739	'theater, concert, opera, ballet'
     749	'museum, gallery, zoo, exhibition'
     752	'visiting with others'
     769	'parties, receptions'
     771	'at bar, cocktail lounge'
     772	'dancing'
     789	'other socializing'
     799	'travel related to public events'
     801	'football, basket ball etc'
     802	'tennis, squash etc'
     803	'golf, miniature golf'
     804	'swim, water ski'
     805	'ski, skate'
     806	'bowl, ping-pong'
     807	'frisbee, catch'
     808	'exercise, yoga'
     811	'hunting'
     812	'fishing'
     813	'boat, sail, canoe'
     814	'camping'
     815	'snowmobile, dune buggy'
     816	'gliding, ballooning'
     817	'excursions'
     818    'picnic'
     821	'walking for pleasure'
     822	'hiking'
     823	'jogging, running'
     824	'cycling'
     825	'motorcycling'
     826	'horseback riding'
     831	'photography'
     832	'work on cars as hobby'
     833	'repair leisure equipment'
     834	'collections, scrapbooks'
     835	'carpentry/woodwork as hobby'
     841	'preserve foodstuffs'
     842	'knit, sew, needlework'
     843	'sewing'
     844	'care livestock/animals (not as farmer)'
     851	'sculpture, painting, drawing'
     852	'literature, write poetry'
     861	'play musical instrument'
     862	'sing'
     863	'act'
     864	'non-social dancing'
     871	'play card games'
     872	'play board games'
     873	'play social games'
     874	'puzzles'
     888	'sports classes or training'
     889	'other active leisure'
     899	'travel related to sport or leisure'
     909	'listen to radio'
     919	'watch TV'
     929	'listen to music, records'
     939	'read books'
     941	'read magazines, pamphlets'
     942	'read - not specified what'
     959	'read newspaper'
     961	'phone conversations'
     962	'face to face conversations'
     963	'conversation with hh members'
     979	'read or write letters'
     981	'relax'
     982	'think, plan, reflect'
     983	'do nothing, sit'
     984	'reported act of other, not self'
     989	'other passing leisure, smoke dope'
     999	'travel related to passive leisure'.
     val lab whr
       1  'own home'
       2  'in transit'
       3  'at work'
       4  'other home'
       5  'restaurant or bar'
       6  'indoor leisure place'
       7  'outdoor leisure place'
       8  'other place'.
     val lab wha whb
       0  'alone'
       1  'spouse/fiance'
       2  'close family'
       3  'other resident adult'
       4  'other friend/relation'
       5  'co-worker'
       6  'organisation member'
       7  'neighbour'
       8  'service personnel'
       9  'others'.
     xsave outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse2.sav'
    /keep = survey hhid pid pri secact whr wha whb str fin v7972 v7973 v7976.
end loop.
execute.

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse2.sav'.

recode pri (sysmis=-8) (907=909).
freq pri secact.

recode str whr fin (sysmis=-8).
do if str=-8 and fin>-1.
     compute str=0.
Else if str=-8 and hhid~=lag(hhid).
     compute str=0.
     compute fin=1440.
     compute pri=481.
end if.
desc str fin. 

temp.
select if str=0.
freq str.

*this select command just leaves the diaries.

select if pri>-8 and pri~=579.
execute.

sort cases by hhid pid str.

match files files=* 
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w2dspdem.sav'
     /BY hhid.
execute.

recode whr (sysmis=-8). 

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse2.sav'
   /keep survey wave hhid pid diaryday cday month year pri secact whr wha whb str fin agesp sexsp 
    educsp wkhrsp empstsp unempsp disrtsp students mwagesp v7972 v7973 v7976.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp2.sav'
  /BREAK=hhid pid
  /fin_1 = MEAN(fin).

match files 
   files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\testspid2.sav' /in=main
   files'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp2.sav' /in=spouse
   /BY hhid.
cro main by spouse.

**********
**WAVE 3**
**********.

*********************************************
**demographic and day variables for spouses**
*********************************************.

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2 v1183 v1687 v7968 v4901 v4898 v4897 v5137 
    v5630 v5633 v37 v41 v46 v3654 v3834 v4900 v4901
    v4903 v4924 v5057 v1596.

freq v5137 v5630 v5633 v4898 v4897.
cro v5630 by v5633.

rename variables (v2 v1183 v4901 v4898 v4897 v3654 v1596 = 
                  hhid pid wkhrsp cday month agesp sexsp).

*note that there are cases where the spouse and respondent
*new ids later in the file don't lead to perfect matches -
*so the first value for these identifiers used and 
*subsequent ids only used when no value existed for a 
*previous wave.

recode pid v1687 (sysmis=-8).
Do if pid=-8.
   compute pid= v1687.
End if.
desc pid. 

compute usualday =0.
val lab usualday
    -8 missing
    -7 not asked of spouses
     0 usual day
     1 unusual day.
If v5630=1 or v5633=1 usualday=1.
freq usualday.
cro usualday by v5630 v5633.

*note that the spouse data is entered twice in the file - once on
*the rows of the main respondents and once again on separate rows
*for the spouse data. In this case spouse information from the
*respondent row is selected.

select if v7968=1 and pid>0.
desc hhid pid.

*rows now exist for 912 spouses; as there are 887 spouse diaries,
*these extra cases are be saved for weighting probabilities later.

*correct age errors.
If hhid=992  agesp=98.
If hhid=1027 agesp=23.
If hhid=1202 agesp=64.
If hhid=1472 agesp=68.
If hhid=1480 agesp=29.
If pid=2531 agesp=51.
If pid=2059 agesp=74.
If pid=2803 agesp=68.
If pid=2351 agesp=72.
If pid=2698 agesp=73.
If pid=2518 agesp=60.
If pid=2873 agesp=50.
If pid=2662 agesp=68.
If pid=2668 agesp=45.
If pid=2165 agesp=55.
If pid=2713 agesp=54.
If pid=2036 agesp=69.
If pid=2512 agesp=55.
If pid=2852 agesp=55.
If pid=2645 agesp=69.
If pid=8136 agesp=48.
If pid=2334 agesp=47.
If pid=2385 agesp=44.
If pid=2297 agesp=47.
If pid=2342 agesp=46.
If pid=2837 agesp=45.
If pid=2237 agesp=48.
If pid=2429 agesp=41.
If pid=2212 agesp=41.
If hhid=928 agesp=41.
If hhid=883 agesp=26.
If hhid=833 agesp=43.
If hhid=58  agesp=37.
If hhid=1014 agesp=40.
If hhid=1144 agesp=30.
If hhid=355 agesp=37.
If hhid=823 agesp=33.
If hhid=1257 agesp=33.
If hhid=1420 agesp=29.
If hhid=985 agesp=31.
If hhid=1030 agesp=29.
If hhid=169 agesp=27.
If hhid=634 agesp=27.
If hhid=996 agesp=21.
If hhid=1430 agesp=26.
If hhid=1268 agesp=18.
If hhid=1085 agesp=46.
If hhid=95 agesp=18.
If hhid=12 agesp=74.
If hhid=214 agesp=83.
If hhid=246 agesp=58.
If hhid=521 agesp=50.
If hhid=575 agesp=51.
If hhid=652 agesp=34.
If hhid=800 agesp=70.
recode agesp (sysmis=-8).
freq agesp.

compute year=1976.
recode wkhrsp month cday (sysmis=-8).
recode v5137 (1=2) (2=3) (3=4) (4=5) (5=6) (6=7) (7=1) (ELSE=-8) 
   INTO diaryday.
compute educsp=-8.
compute empstsp=-8.
compute disrtsp=-9.
compute unempsp=-8.
compute students=0.
compute mwagesp=-9.
compute wave=3.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp1.sav'.

freq cday month wkhrsp wave year.

cro v5137 by diaryday.

freq v5057.
if v5057>0 students=1.
cro students by v5057.

freq v4903 v4924.
recode v4903 v4924 (sysmis=-8).
Do if v4903=1 or v4924>0.
   compute unempsp=1.
Else if v4903=5.
   compute unempsp=0.
end if.
cro unempsp by v4903 v4924.
freq unempsp.

freq v3834 v4900 wkhrsp.
recode v3834 v4900 (sysmis=-8).

cro v3834 by v4900.

Do if wkhrsp>20.
   compute empstsp=1.
Else if wkhrsp>0 and wkhrsp<21.
   compute empstsp=2.
Else if v4900=1 or v3834=1.
   compute empstsp=3.
Else if v3834=5.
   compute empstsp=4.
End if.
If empstsp=-8 and agesp>65 empstsp=4.
freq empstsp.
means wkhrsp by empstsp
   /cells min max mean.

temp.
select if agesp>-8.
means agesp by unempsp
   /cells min max mean.

recode v37 v46 v41 (sysmis=0).
Do if v37>0 and v37<96.
   compute educsp= v37.
Else if v46>0.
   compute educsp= v46.
Else if v41>0 and v41<96.
   compute educsp= v41.
End if.
Recode educsp (6=5) (5=4) (4=3).
freq educsp.

temp.
select if agesp>-8.
means agesp by empstsp
   /cells min max mean.

If wkhrsp=-8 and empstsp=4 wkhrsp=0.
freq wkhrsp mwagesp.

temp.
select if wkhrsp>-8.
means wkhrsp by empstsp
   /cells min max mean.

*correct errors with sex.
recode sexsp (sysmis=-8).
If hhid=1393 sexsp=2. 
If hhid=17   sexsp=1. 
If hhid=73   sexsp=1. 
If hhid=792  sexsp=1. 
If hhid=313  sexsp=2. 
If hhid=831  sexsp=1. 
If hhid=136  sexsp=1. 
If hhid=818  sexsp=2. 
If hhid=558  sexsp=1. 
If hhid=929  sexsp=1. 
If hhid=1023 sexsp=1. 
If hhid=1377 sexsp=1. 
If hhid=1511 sexsp=2. 
If hhid=528  sexsp=1. 
If hhid=791  sexsp=1. 
If hhid=1285 sexsp=2. 
If hhid=985  sexsp=1. 
If hhid=1030 sexsp=1. 
If hhid=102  sexsp=2. 
If hhid=1503 sexsp=1. 
If hhid=1263 sexsp=2. 
If hhid=1430 sexsp=1. 
If hhid=1347 sexsp=1. 
If hhid=425  sexsp=1. 
If hhid=1069 sexsp=1. 
If hhid=1085 sexsp=1. 
If hhid=833  sexsp=2. 
If hhid=928  sexsp=1. 
If hhid=1271 sexsp=1. 
If hhid=1341 sexsp=2. 
If hhid=204  sexsp=1. 
If hhid=379  sexsp=1. 
If hhid=226  sexsp=1. 
If hhid=901  sexsp=2. 
If hhid=1090 sexsp=1. 
If hhid=851  sexsp=1. 
freq sexsp.

sort cases by wave hhid pid.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w3dspdem.sav'
  /BREAK=wave hhid pid
  /agesp = MAX(agesp) /sexsp = MAX(sexsp) /educsp = MAX(educsp) 
  /wkhrsp = MAX(wkhrsp) /empstsp = MAX(empstsp) /unempsp = 
  MAX(unempsp) /disrtsp = MAX(disrtsp) /students = MAX(students) 
  /mwagesp = MAX(mwagesp) /diaryday = MAX(diaryday) /cday =
  MAX(cday) /month = MAX(month) /year = MAX(year).

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2  v1183 v1687 v7968
 v4015 v4023 v4031 v4039 v4047 v4055 v4063 v4071 v4079 v4087
 v4095 v4103 v4111 v4119 v4127 v4135 v4143 v4151 v4159 v4167
 v4175 v4183 v4191 v4199 v4207 v4215 v4223 v4231 v4239 v4247
 v4255 v4263 v4271 v4279 v4287 v4295 v4303 v4311 v4319 v4327
 v4335 v4343 v4351 v4359 v4367 v4375 v4383 v4391 v4399 v4407
 v4415 v4423 v4431 v4439 v4447 v4455 v4463 v4471 v4479 v4487
 v4495 v4503 v4511 v4519 v4527 v4535 v4543 v4551 v4559 v4567
 v4575 v4583 v4591 v4599 v4607 v4615 v4623 v4631 v4639 v4647
 v4018 v4026 v4034 v4042 v4050 v4058 v4066 v4074 v4082 v4090
 v4098 v4106 v4114 v4122 v4130 v4138 v4146 v4154 v4162 v4170
 v4178 v4186 v4194 v4202 v4210 v4218 v4226 v4234 v4242 v4250
 v4258 v4266 v4274 v4282 v4290 v4298 v4306 v4314 v4322 v4330
 v4338 v4346 v4354 v4362 v4370 v4378 v4386 v4394 v4402 v4410
 v4418 v4426 v4434 v4442 v4450 v4458 v4466 v4474 v4482 v4490
 v4498 v4506 v4514 v4522 v4530 v4538 v4546 v4554 v4562 v4570
 v4578 v4586 v4594 v4602 v4610 v4618 v4626 v4634 v4642 v4650
 v4016 v4024 v4032 v4040 v4048 v4056 v4064 v4072 v4080 v4088
 v4096 v4104 v4112 v4120 v4128 v4136 v4144 v4152 v4160 v4168
 v4176 v4184 v4192 v4200 v4208 v4216 v4224 v4232 v4240 v4248
 v4256 v4264 v4272 v4280 v4288 v4296 v4304 v4312 v4320 v4328
 v4336 v4344 v4352 v4360 v4368 v4376 v4384 v4392 v4400 v4408
 v4416 v4424 v4432 v4440 v4448 v4456 v4464 v4472 v4480 v4488
 v4496 v4504 v4512 v4520 v4528 v4536 v4544 v4552 v4560 v4568
 v4576 v4584 v4592 v4600 v4608 v4616 v4624 v4632 v4640 v4648
 v4017 v4025 v4033 v4041 v4049 v4057 v4065 v4073 v4081 v4089
 v4097 v4105 v4113 v4121 v4129 v4137 v4145 v4153 v4161 v4169
 v4177 v4185 v4193 v4201 v4209 v4217 v4225 v4233 v4241 v4249
 v4257 v4265 v4273 v4281 v4289 v4297 v4305 v4313 v4321 v4329
 v4337 v4345 v4353 v4361 v4369 v4377 v4385 v4393 v4401 v4409
 v4417 v4425 v4433 v4441 v4449 v4457 v4465 v4473 v4481 v4489
 v4497 v4505 v4513 v4521 v4529 v4537 v4545 v4553 v4561 v4569
 v4577 v4585 v4593 v4601 v4609 v4617 v4625 v4633 v4641 v4649
 v7972 v7973 v7976.

rename variables
(v4015 v4023 v4031 v4039 v4047 v4055 v4063 v4071 v4079 v4087
 v4095 v4103 v4111 v4119 v4127 v4135 v4143 v4151 v4159 v4167
 v4175 v4183 v4191 v4199 v4207 v4215 v4223 v4231 v4239 v4247
 v4255 v4263 v4271 v4279 v4287 v4295 v4303 v4311 v4319 v4327
 v4335 v4343 v4351 v4359 v4367 v4375 v4383 v4391 v4399 v4407
 v4415 v4423 v4431 v4439 v4447 v4455 v4463 v4471 v4479 v4487
 v4495 v4503 v4511 v4519 v4527 v4535 v4543 v4551 v4559 v4567
 v4575 v4583 v4591 v4599 v4607 v4615 v4623 v4631 v4639 v4647=
 pri1  pri2  pri3  pri4  pri5  pri6  pri7  pri8  pri9  pri10
 pri11 pri12 pri13 pri14 pri15 pri16 pri17 pri18 pri19 pri20
 pri21 pri22 pri23 pri24 pri25 pri26 pri27 pri28 pri29 pri30
 pri31 pri32 pri33 pri34 pri35 pri36 pri37 pri38 pri39 pri40
 pri41 pri42 pri43 pri44 pri45 pri46 pri47 pri48 pri49 pri50
 pri51 pri52 pri53 pri54 pri55 pri56 pri57 pri58 pri59 pri60
 pri61 pri62 pri63 pri64 pri65 pri66 pri67 pri68 pri69 pri70
 pri71 pri72 pri73 pri74 pri75 pri76 pri77 pri78 pri79 pri80).

vector secact(80) wha(80) whb(80).
Do repeat a=secact1 to whb80.
   compute a=-9.
End repeat.
freq secact1 secact80 wha1 whb80.

rename variables
(v4018 v4026 v4034 v4042 v4050 v4058 v4066 v4074 v4082 v4090
 v4098 v4106 v4114 v4122 v4130 v4138 v4146 v4154 v4162 v4170
 v4178 v4186 v4194 v4202 v4210 v4218 v4226 v4234 v4242 v4250
 v4258 v4266 v4274 v4282 v4290 v4298 v4306 v4314 v4322 v4330
 v4338 v4346 v4354 v4362 v4370 v4378 v4386 v4394 v4402 v4410
 v4418 v4426 v4434 v4442 v4450 v4458 v4466 v4474 v4482 v4490
 v4498 v4506 v4514 v4522 v4530 v4538 v4546 v4554 v4562 v4570
 v4578 v4586 v4594 v4602 v4610 v4618 v4626 v4634 v4642 v4650=
 whr1  whr2  whr3  whr4  whr5  whr6  whr7  whr8  whr9  whr10
 whr11 whr12 whr13 whr14 whr15 whr16 whr17 whr18 whr19 whr20
 whr21 whr22 whr23 whr24 whr25 whr26 whr27 whr28 whr29 whr30
 whr31 whr32 whr33 whr34 whr35 whr36 whr37 whr38 whr39 whr40
 whr41 whr42 whr43 whr44 whr45 whr46 whr47 whr48 whr49 whr50
 whr51 whr52 whr53 whr54 whr55 whr56 whr57 whr58 whr59 whr60
 whr61 whr62 whr63 whr64 whr65 whr66 whr67 whr68 whr69 whr70
 whr71 whr72 whr73 whr74 whr75 whr76 whr77 whr78 whr79 whr80).

rename variables
(v4016 v4024 v4032 v4040 v4048 v4056 v4064 v4072 v4080 v4088
 v4096 v4104 v4112 v4120 v4128 v4136 v4144 v4152 v4160 v4168
 v4176 v4184 v4192 v4200 v4208 v4216 v4224 v4232 v4240 v4248
 v4256 v4264 v4272 v4280 v4288 v4296 v4304 v4312 v4320 v4328
 v4336 v4344 v4352 v4360 v4368 v4376 v4384 v4392 v4400 v4408
 v4416 v4424 v4432 v4440 v4448 v4456 v4464 v4472 v4480 v4488
 v4496 v4504 v4512 v4520 v4528 v4536 v4544 v4552 v4560 v4568
 v4576 v4584 v4592 v4600 v4608 v4616 v4624 v4632 v4640 v4648=
 str1  str2  str3  str4  str5  str6  str7  str8  str9  str10
 str11 str12 str13 str14 str15 str16 str17 str18 str19 str20
 str21 str22 str23 str24 str25 str26 str27 str28 str29 str30
 str31 str32 str33 str34 str35 str36 str37 str38 str39 str40
 str41 str42 str43 str44 str45 str46 str47 str48 str49 str50
 str51 str52 str53 str54 str55 str56 str57 str58 str59 str60
 str61 str62 str63 str64 str65 str66 str67 str68 str69 str70
 str71 str72 str73 str74 str75 str76 str77 str78 str79 str80).

rename variables
(v4017 v4025 v4033 v4041 v4049 v4057 v4065 v4073 v4081 v4089
 v4097 v4105 v4113 v4121 v4129 v4137 v4145 v4153 v4161 v4169
 v4177 v4185 v4193 v4201 v4209 v4217 v4225 v4233 v4241 v4249
 v4257 v4265 v4273 v4281 v4289 v4297 v4305 v4313 v4321 v4329
 v4337 v4345 v4353 v4361 v4369 v4377 v4385 v4393 v4401 v4409
 v4417 v4425 v4433 v4441 v4449 v4457 v4465 v4473 v4481 v4489
 v4497 v4505 v4513 v4521 v4529 v4537 v4545 v4553 v4561 v4569
 v4577 v4585 v4593 v4601 v4609 v4617 v4625 v4633 v4641 v4649=
 fin1  fin2  fin3  fin4  fin5  fin6  fin7  fin8  fin9  fin10
 fin11 fin12 fin13 fin14 fin15 fin16 fin17 fin18 fin19 fin20
 fin21 fin22 fin23 fin24 fin25 fin26 fin27 fin28 fin29 fin30
 fin31 fin32 fin33 fin34 fin35 fin36 fin37 fin38 fin39 fin40
 fin41 fin42 fin43 fin44 fin45 fin46 fin47 fin48 fin49 fin50
 fin51 fin52 fin53 fin54 fin55 fin56 fin57 fin58 fin59 fin60
 fin61 fin62 fin63 fin64 fin65 fin66 fin67 fin68 fin69 fin70
 fin71 fin72 fin73 fin74 fin75 fin76 fin77 fin78 fin79 fin80).

rename variables (v2 v1183 = pid hhid).

*note that there are cases where the spouse and respondent
*new ids later in the file don't lead to perfect matches -
*so the first value for these identifiers used and 
*subsequent ids only used when no value existed for a 
*previous wave.

recode hhid v1687 (sysmis=-8).
Do if hhid=-8.
   compute hhid= v1687.
End if.
desc hhid. 

compute survey=2.

*note that the spouse data is entered twice in the file - once on
*the rows of the main respondents and once again on separate rows
*for the spouse data. The spouse rows contain secondary activity
*and who with information even though the documentation says that
*this is not the case. The spouse row times match up with the spouse
*column times on the respondent rows, hence the spouse line diaries 
*now are selected.

select if v7968=2.
desc hhid.

sort cases by hhid pid.

vector pri = pri1 to pri80 /secact = secact1 to secact80 
      /whr = whr1 to whr80 /wha = wha1 to wha80 
      /whb = whb1 to whb80 /str = str1 to str80
      /fin = fin1 to fin80.

loop i=1 to 80.
     compute pri=pri(i).
     compute secact=secact(i).
     compute whr=whr(i).
     compute wha=wha(i).
     compute whb=whb(i).
     compute str=str(i).
     compute fin=fin(i).
     var lab pri main activity.
     var lab secact secondary activity.
     var lab whr location.
     var lab wha "with whom 1st mention".
     var lab whb "with whom 2nd mention".
     var lab str start time.
     var lab fin finish time.
     val lab pri secact
      -8  missing
       0	'no secondary activity'
      11	'normal work-main job inc work at home'
      12    'work at home'
      22	'job search, look for work'
      23	'apply for, collect unemployment benefit'
      24	'apply for/collect other welfare'
      59	'2nd job (& small jobs of FT students)'
      69	'meals at work'
      78	'time before or after work at workplace'
      79	'other work related activity'
      89	'work breaks'
      97	'travel related to job search'
      98	'travel to/from work making other stops'
      99	'travel directly to/from workplace'
     109	'meal preparation, cook or serve food'
     119	'meal clean-up, do dishes'
     129	'routine indoor cleaning & chores'
     139	'routine clean house (outside)'
     149	'laundry, iron, fold clothes'
     161	'repair vehicle, home'
     162	'exterior repairs or maintenance'
     163	'car care, cleaning, tune up'
     164	'home improvements, remodelling'
     171	'gardening'
     172    'care of pets, walk dogs'
     173	'care of house plants'
     191	'other domestic work'
     192	'putter in yard'
     193	'household paperwork, pay bills'
     197	'other household chores'
     209	'care of babies aged under 5 years old'
     218	'care for children of mixed ages'
     219	'care for child aged 5-17'
     221	'teach child skill, show how to do things'
     222	'help child with homework'
     239	'read to/talk with child, listen to child'
     249	'adult play with child inside'
     259	'sport, walk, outside with child'
     269	'medical care for child'
     278	'unpaid babysitting'
     279	'other child care'
     299	'child care travel'
     301	'groceries, supermarket, shop for food'
     302	'other shopping for goods or clothes'
     311	'shop for goods, durables, appliances'
     312	'look to rent/purchase housing'
     329	'personal care services'
     339	'medical care, doctor, dentist'
     341	'financial services'
     342	'government services'
     351	'auto repair and related services'
     352	'clothes repair, cleaning services'
     353	'appliance repair services'
     354	'household repair services'
     379	'other services, go to the dump'
     389	'running errands'
     399	'travel related to goods or services'
     409	'wash, dress, get ready'
     411	'medical care of self at home'
     412	'medical care to adults in household'
     421	'non-medical care to adult from household'
     422	'help/care for adult from other household'
     423	'help/care for neighbours or friends'
     424	'help or care for unspecified adults'
     439	'meals & snacks at own home'
     449	'meal/snack away from home or workplace'
     459	'main sleep'
     469	'naps and resting'
     481	'time gap greater than 10 minutes'
     482	'personal, private, none of your business'
     483	'sex, make out'
     489	'other personal care'
     498	'travel related to adult care'
     499	'travel related to personal care'
     509	'ft student attend classes'
     519	'course/lecture'
     549	'homework, study, research'
     569	'other education'
     579	'end of diary activity'
     599	'other school-related travel'
     601	'union/professional group meetings'
     602	'other union/professional group activity'
     611	'meetings of identity groups'
     612	'other identity group activities'
     621	'meeting of political or civic group'
     622	'other political/civic activities'
     631	'attend meetings of voluntary group'
     632	'office volunteer'
     633	'fundraising activity for voluntary group'
     634	'direct help to persons as a member'
     635	'other voluntary activities for group'
     641	'religious charity group meeting'
     642	'other religious charity activity'
     643	'other religious group meetings'
     644	'other religious group act/social'
     651	'attend religious services'
     652	'private worship'
     661	'meetings of fraternal organisations'
     662	'other fraternal organisation activities'
     671	'meetings of family/youth organisations'
     672	'other family/youth group activities'
     689	'miscl volunteering'
     698	'travel related membership activities'
     699	'travel for other voluntary acts'
     709	'attend sports event'
     719	'other public event'
     729	'movies'
     739	'theater, concert, opera, ballet'
     749	'museum, gallery, zoo, exhibition'
     752	'visiting with others'
     769	'parties, receptions'
     771	'at bar, cocktail lounge'
     772	'dancing'
     789	'other socializing'
     799	'travel related to public events'
     801	'football, basket ball etc'
     802	'tennis, squash etc'
     803	'golf, miniature golf'
     804	'swim, water ski'
     805	'ski, skate'
     806	'bowl, ping-pong'
     807	'frisbee, catch'
     808	'exercise, yoga'
     811	'hunting'
     812	'fishing'
     813	'boat, sail, canoe'
     814	'camping'
     815	'snowmobile, dune buggy'
     816	'gliding, ballooning'
     817	'excursions'
     818    'picnic'
     821	'walking for pleasure'
     822	'hiking'
     823	'jogging, running'
     824	'cycling'
     825	'motorcycling'
     826	'horseback riding'
     831	'photography'
     832	'work on cars as hobby'
     833	'repair leisure equipment'
     834	'collections, scrapbooks'
     835	'carpentry/woodwork as hobby'
     841	'preserve foodstuffs'
     842	'knit, sew, needlework'
     843	'sewing'
     844	'care livestock/animals (not as farmer)'
     851	'sculpture, painting, drawing'
     852	'literature, write poetry'
     861	'play musical instrument'
     862	'sing'
     863	'act'
     864	'non-social dancing'
     871	'play card games'
     872	'play board games'
     873	'play social games'
     874	'puzzles'
     888	'sports classes or training'
     889	'other active leisure'
     899	'travel related to sport or leisure'
     909	'listen to radio'
     919	'watch TV'
     929	'listen to music, records'
     939	'read books'
     941	'read magazines, pamphlets'
     942	'read - not specified what'
     959	'read newspaper'
     961	'phone conversations'
     962	'face to face conversations'
     963	'conversation with hh members'
     979	'read or write letters'
     981	'relax'
     982	'think, plan, reflect'
     983	'do nothing, sit'
     984	'reported act of other, not self'
     989	'other passing leisure, smoke dope'
     999	'travel related to passive leisure'.
     val lab whr
       1  'own home'
       2  'in transit'
       3  'at work'
       4  'other home'
       5  'restaurant or bar'
       6  'indoor leisure place'
       7  'outdoor leisure place'
       8  'other place'.
     val lab wha whb
       0  'alone'
       1  'spouse/fiance'
       2  'close family'
       3  'other resident adult'
       4  'other friend/relation'
       5  'co-worker'
       6  'organisation member'
       7  'neighbour'
       8  'service personnel'
       9  'others'.
     xsave outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse3.sav'
    /keep = survey hhid pid pri secact whr wha whb str fin v7972 v7973 v7976.
end loop.
execute.

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse3.sav'.

recode pri secact (973=963) (sysmis=-8).
freq pri secact.

recode str whr fin (sysmis=-8).
do if str=-8 and fin>-1.
     compute str=0.
Else if str=-8 and hhid~=lag(hhid).
     compute str=0.
     compute fin=1440.
     compute pri=481.
end if.
desc str fin. 

temp.
select if str=0.
freq str.

*this select command just leaves the diaries.

select if pri>-8 and pri~=579.
execute.

*fix one diary where the final episode recorded in 12-hour rather
*than 24-hour clock time in error.
Do if hhid=549 and pid=2296 and str=1120.
   compute str=2320.
   compute fin=2400.
End if.
execute.

sort cases by hhid pid str.

match files files=* 
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w3dspdem.sav'
     /BY hhid.
execute.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse3.sav'
   /keep survey wave hhid pid diaryday cday month year pri secact whr wha whb str fin agesp sexsp 
    educsp wkhrsp empstsp unempsp disrtsp students mwagesp v7972 v7973 v7976.
 
AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp3.sav'
  /BREAK=hhid pid
  /fin_1 = MEAN(fin).

match files 
   files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\testspid3.sav' /in=main
   files'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp3.sav' /in=spouse
   /BY hhid.
cro main by spouse.

**********
**WAVE 4**
**********.

*********************************************
**demographic and day variables for spouses**
*********************************************.

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2 v1183 v1687 v1596 v7756 v7264 v7263 v7262 v7968 v7099 v6941 v5845 v6940 v6943 v6964 v6973 
    v7103 v7097 v3654 v37 v46 v41 v7972 v7973 v7976.

rename variables (v2 v1183 v7263 v7264 v3654 v1596 = hhid pid month cday agesp sexsp).

*note that there are cases where the spouse and respondent
*new ids later in the file don't lead to perfect matches -
*so the first value for these identifiers used and 
*subsequent ids only used when no value existed for a 
*previous wave.

recode pid v1687 (sysmis=-8).
Do if pid=-8.
   compute pid= v1687.
End if.
desc pid. 

*note that the spouse data is entered twice in the file - once on
*the rows of the main respondents and once again on separate rows
*for the spouse data. In this case spouse information from the
*respondent row is selected.

select if v7968=1 and pid>0.
desc hhid pid.

*rows now exist for 912 spouses; as there are 887 spouse diaries,
*these extra cases are be saved for weighting probabilities later.

compute usualday =-8.
val lab usualday
    -8 missing
    -7 not asked of spouses
     0 usual day
     1 unusual day.
If v7756=5 usualday=0.
If v7756=1 usualday=1.
freq usualday.
cro usualday by v7756.

*correct age errors.
If hhid=992  agesp=98.
If hhid=1027 agesp=23.
If hhid=1202 agesp=64.
If hhid=1472 agesp=68.
If hhid=1480 agesp=29.
If pid=2531 agesp=51.
If pid=2059 agesp=74.
If pid=2803 agesp=68.
If pid=2351 agesp=72.
If pid=2698 agesp=73.
If pid=2518 agesp=60.
If pid=2873 agesp=50.
If pid=2662 agesp=68.
If pid=2668 agesp=45.
If pid=2165 agesp=55.
If pid=2713 agesp=54.
If pid=2036 agesp=69.
If pid=2512 agesp=55.
If pid=2852 agesp=55.
If pid=2645 agesp=69.
If pid=8136 agesp=48.
If pid=2334 agesp=47.
If pid=2385 agesp=44.
If pid=2297 agesp=47.
If pid=2342 agesp=46.
If pid=2837 agesp=45.
If pid=2237 agesp=48.
If pid=2429 agesp=41.
If pid=2212 agesp=41.
If hhid=928 agesp=41.
If hhid=883 agesp=26.
If hhid=833 agesp=43.
If hhid=58  agesp=37.
If hhid=1014 agesp=40.
If hhid=1144 agesp=30.
If hhid=355 agesp=37.
If hhid=823 agesp=33.
If hhid=1257 agesp=33.
If hhid=1420 agesp=29.
If hhid=985 agesp=31.
If hhid=1030 agesp=29.
If hhid=169 agesp=27.
If hhid=634 agesp=27.
If hhid=996 agesp=21.
If hhid=1430 agesp=26.
If hhid=1268 agesp=18.
If hhid=1085 agesp=46.
If hhid=95 agesp=18.
If hhid=12 agesp=74.
If hhid=214 agesp=83.
If hhid=246 agesp=58.
If hhid=521 agesp=50.
If hhid=575 agesp=51.
If hhid=652 agesp=34.
If hhid=800 agesp=70.
recode agesp (sysmis=-8).
freq agesp.

compute year=1976.
recode month cday (sysmis=-8).
recode v7262 (1=2) (2=3) (3=4) (4=5) (5=6) (6=7) (7=1) (ELSE=-8) 
   INTO diaryday.
compute wkhrsp=-8.
compute educsp=-8.
compute empstsp=-8.
compute disrtsp=0.
compute unempsp=-8.
compute students=0.
compute mwagesp=-9.
compute wave=4.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp1.sav'.

freq cday month wave year.

cro v7262 by diaryday.
freq diaryday.

freq v7097.
if v7097=1 students=1.
cro students by v7097 v6940.

freq v6943 v6964 v6973 v7103 v6940.
recode v6943 v6964 v6973 v7103 v6940 (sysmis=-8).
Do if v6943=1 or v6964>0 or v6940=2 or v6940=3.
   compute unempsp=1.
Else if v6943=5 or v6973>0 or v7103>0 or v6940>0.
   compute unempsp=0.
end if.
cro unempsp by v6943 v6964 v6973 v7103 v6940.
freq unempsp.

freq v6941 v7099.
cro v6941 by v7099.
*note these variables are not overlapping.
recode v6941 v7099 v5845 (sysmis=-8).

If v6941>0 wkhrsp=v6941.
If v7099>0 wkhrsp=v7099.
freq wkhrsp. 

cro v5845 by v6940.

Do if wkhrsp>20.
   compute empstsp=1.
Else if wkhrsp>0 and wkhrsp<21.
   compute empstsp=2.
Else if v6940=1 or v5845=1.
   compute empstsp=3.
Else if v6940>0 or v5845=5.
   compute empstsp=4.
End if.
If empstsp=-8 and agesp>65 empstsp=4.
freq empstsp.
cro empstsp by v5845 v6940.
means wkhrsp by empstsp
   /cells min max mean.

temp.
select if agesp>-8.
means agesp by unempsp
   /cells min max mean.

If v6940=4 and (agesp>0 and agesp<66) disrtsp=1.
cro v6940 by disrtsp.
freq disrtsp. 

recode v37 v46 v41 (sysmis=0).
Do if v37>0 and v37<96.
   compute educsp= v37.
Else if v46>0.
   compute educsp= v46.
Else if v41>0 and v41<96.
   compute educsp= v41.
End if.
Recode educsp (6=5) (5=4) (4=3).
freq educsp.

temp.
select if agesp>-8.
means agesp by empstsp
   /cells min max mean.

If wkhrsp=-8 and empstsp=4 wkhrsp=0.
freq wkhrsp mwagesp.

temp.
select if wkhrsp>-8.
means wkhrsp by empstsp
   /cells min max mean.

*correct errors with sex.
recode sexsp (sysmis=-8).
If hhid=1393 sexsp=2. 
If hhid=17   sexsp=1. 
If hhid=73   sexsp=1. 
If hhid=792  sexsp=1. 
If hhid=313  sexsp=2. 
If hhid=831  sexsp=1. 
If hhid=136  sexsp=1. 
If hhid=818  sexsp=2. 
If hhid=558  sexsp=1. 
If hhid=929  sexsp=1. 
If hhid=1023 sexsp=1. 
If hhid=1377 sexsp=1. 
If hhid=1511 sexsp=2. 
If hhid=528  sexsp=1. 
If hhid=791  sexsp=1. 
If hhid=1285 sexsp=2. 
If hhid=985  sexsp=1. 
If hhid=1030 sexsp=1. 
If hhid=102  sexsp=2. 
If hhid=1503 sexsp=1. 
If hhid=1263 sexsp=2. 
If hhid=1430 sexsp=1. 
If hhid=1347 sexsp=1. 
If hhid=425  sexsp=1. 
If hhid=1069 sexsp=1. 
If hhid=1085 sexsp=1. 
If hhid=833  sexsp=2. 
If hhid=928  sexsp=1. 
If hhid=1271 sexsp=1. 
If hhid=1341 sexsp=2. 
If hhid=204  sexsp=1. 
If hhid=379  sexsp=1. 
If hhid=226  sexsp=1. 
If hhid=901  sexsp=2. 
If hhid=1090 sexsp=1. 
If hhid=851  sexsp=1. 
freq sexsp.

sort cases by wave hhid pid.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w4dspdem.sav'
  /BREAK=wave hhid pid
  /agesp = MAX(agesp) /sexsp = MAX(sexsp) /educsp = MAX(educsp) 
  /wkhrsp = MAX(wkhrsp) /empstsp = MAX(empstsp) /unempsp = 
  MAX(unempsp) /disrtsp = MAX(disrtsp) /students = MAX(students) 
  /mwagesp = MAX(mwagesp) /diaryday = MAX(diaryday) /cday =
  MAX(cday) /month = MAX(month) /year = MAX(year) /v7972 =
  MAX(v7972) /v7973 = MAX(v7973) /v7976 = MAX(v7976).

GET FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\new1975long.sav'
   /keep v2 v1183 v1687  v7968
 v6033 v6041 v6049 v6057 v6065 v6073 v6081 v6089 v6097 v6105
 v6113 v6121 v6129 v6137 v6145 v6153 v6161 v6169 v6177 v6185
 v6193 v6201 v6209 v6217 v6225 v6233 v6241 v6249 v6257 v6265
 v6273 v6281 v6289 v6297 v6305 v6313 v6321 v6329 v6337 v6345
 v6353 v6361 v6369 v6377 v6385 v6393 v6401 v6409 v6417 v6425
 v6433 v6441 v6449 v6457 v6465 v6473 v6481 v6489 v6497 v6505
 v6513 v6521 v6529 v6537 v6545 v6553 v6561 v6569 v6577 v6585
 v6593 v6601 v6609 v6617 v6625 v6633 v6641 v6649 v6657 v6665
 v6036 v6044 v6052 v6060 v6068 v6076 v6084 v6092 v6100 v6108
 v6116 v6124 v6132 v6140 v6148 v6156 v6164 v6172 v6180 v6188
 v6196 v6204 v6212 v6220 v6228 v6236 v6244 v6252 v6260 v6268
 v6276 v6284 v6292 v6300 v6308 v6316 v6324 v6332 v6340 v6348
 v6356 v6364 v6372 v6380 v6388 v6396 v6404 v6412 v6420 v6428
 v6436 v6444 v6452 v6460 v6468 v6476 v6484 v6492 v6500 v6508
 v6516 v6524 v6532 v6540 v6548 v6556 v6564 v6572 v6580 v6588
 v6596 v6604 v6612 v6620 v6628 v6636 v6644 v6652 v6660 v6668
 v6034 v6042 v6050 v6058 v6066 v6074 v6082 v6090 v6098 v6106
 v6114 v6122 v6130 v6138 v6146 v6154 v6162 v6170 v6178 v6186
 v6194 v6202 v6210 v6218 v6226 v6234 v6242 v6250 v6258 v6266
 v6274 v6282 v6290 v6298 v6306 v6314 v6322 v6330 v6338 v6346
 v6354 v6362 v6370 v6378 v6386 v6394 v6402 v6410 v6418 v6426
 v6434 v6442 v6450 v6458 v6466 v6474 v6482 v6490 v6498 v6506
 v6514 v6522 v6530 v6538 v6546 v6554 v6562 v6570 v6578 v6586
 v6594 v6602 v6610 v6618 v6626 v6634 v6642 v6650 v6658 v6666
 v6035 v6043 v6051 v6059 v6067 v6075 v6083 v6091 v6099 v6107
 v6115 v6123 v6131 v6139 v6147 v6155 v6163 v6171 v6179 v6187
 v6195 v6203 v6211 v6219 v6227 v6235 v6243 v6251 v6259 v6267
 v6275 v6283 v6291 v6299 v6307 v6315 v6323 v6331 v6339 v6347
 v6355 v6363 v6371 v6379 v6387 v6395 v6403 v6411 v6419 v6427
 v6435 v6443 v6451 v6459 v6467 v6475 v6483 v6491 v6499 v6507
 v6515 v6523 v6531 v6539 v6547 v6555 v6563 v6571 v6579 v6587
 v6595 v6603 v6611 v6619 v6627 v6635 v6643 v6651 v6659 v6667
 v7972 v7973 v7976.

rename variables
(v6033 v6041 v6049 v6057 v6065 v6073 v6081 v6089 v6097 v6105
 v6113 v6121 v6129 v6137 v6145 v6153 v6161 v6169 v6177 v6185
 v6193 v6201 v6209 v6217 v6225 v6233 v6241 v6249 v6257 v6265
 v6273 v6281 v6289 v6297 v6305 v6313 v6321 v6329 v6337 v6345
 v6353 v6361 v6369 v6377 v6385 v6393 v6401 v6409 v6417 v6425
 v6433 v6441 v6449 v6457 v6465 v6473 v6481 v6489 v6497 v6505
 v6513 v6521 v6529 v6537 v6545 v6553 v6561 v6569 v6577 v6585
 v6593 v6601 v6609 v6617 v6625 v6633 v6641 v6649 v6657 v6665=
 pri1  pri2  pri3  pri4  pri5  pri6  pri7  pri8  pri9  pri10
 pri11 pri12 pri13 pri14 pri15 pri16 pri17 pri18 pri19 pri20
 pri21 pri22 pri23 pri24 pri25 pri26 pri27 pri28 pri29 pri30
 pri31 pri32 pri33 pri34 pri35 pri36 pri37 pri38 pri39 pri40
 pri41 pri42 pri43 pri44 pri45 pri46 pri47 pri48 pri49 pri50
 pri51 pri52 pri53 pri54 pri55 pri56 pri57 pri58 pri59 pri60
 pri61 pri62 pri63 pri64 pri65 pri66 pri67 pri68 pri69 pri70
 pri71 pri72 pri73 pri74 pri75 pri76 pri77 pri78 pri79 pri80).

vector secact(80) wha(80) whb(80).
Do repeat a=secact1 to whb80.
   compute a=-9.
End repeat.
freq secact1 secact80 wha1 whb80.

rename variables
(v6036 v6044 v6052 v6060 v6068 v6076 v6084 v6092 v6100 v6108
 v6116 v6124 v6132 v6140 v6148 v6156 v6164 v6172 v6180 v6188
 v6196 v6204 v6212 v6220 v6228 v6236 v6244 v6252 v6260 v6268
 v6276 v6284 v6292 v6300 v6308 v6316 v6324 v6332 v6340 v6348
 v6356 v6364 v6372 v6380 v6388 v6396 v6404 v6412 v6420 v6428
 v6436 v6444 v6452 v6460 v6468 v6476 v6484 v6492 v6500 v6508
 v6516 v6524 v6532 v6540 v6548 v6556 v6564 v6572 v6580 v6588
 v6596 v6604 v6612 v6620 v6628 v6636 v6644 v6652 v6660 v6668=
 whr1  whr2  whr3  whr4  whr5  whr6  whr7  whr8  whr9  whr10
 whr11 whr12 whr13 whr14 whr15 whr16 whr17 whr18 whr19 whr20
 whr21 whr22 whr23 whr24 whr25 whr26 whr27 whr28 whr29 whr30
 whr31 whr32 whr33 whr34 whr35 whr36 whr37 whr38 whr39 whr40
 whr41 whr42 whr43 whr44 whr45 whr46 whr47 whr48 whr49 whr50
 whr51 whr52 whr53 whr54 whr55 whr56 whr57 whr58 whr59 whr60
 whr61 whr62 whr63 whr64 whr65 whr66 whr67 whr68 whr69 whr70
 whr71 whr72 whr73 whr74 whr75 whr76 whr77 whr78 whr79 whr80).

rename variables
(v6034 v6042 v6050 v6058 v6066 v6074 v6082 v6090 v6098 v6106
 v6114 v6122 v6130 v6138 v6146 v6154 v6162 v6170 v6178 v6186
 v6194 v6202 v6210 v6218 v6226 v6234 v6242 v6250 v6258 v6266
 v6274 v6282 v6290 v6298 v6306 v6314 v6322 v6330 v6338 v6346
 v6354 v6362 v6370 v6378 v6386 v6394 v6402 v6410 v6418 v6426
 v6434 v6442 v6450 v6458 v6466 v6474 v6482 v6490 v6498 v6506
 v6514 v6522 v6530 v6538 v6546 v6554 v6562 v6570 v6578 v6586
 v6594 v6602 v6610 v6618 v6626 v6634 v6642 v6650 v6658 v6666=
 str1  str2  str3  str4  str5  str6  str7  str8  str9  str10
 str11 str12 str13 str14 str15 str16 str17 str18 str19 str20
 str21 str22 str23 str24 str25 str26 str27 str28 str29 str30
 str31 str32 str33 str34 str35 str36 str37 str38 str39 str40
 str41 str42 str43 str44 str45 str46 str47 str48 str49 str50
 str51 str52 str53 str54 str55 str56 str57 str58 str59 str60
 str61 str62 str63 str64 str65 str66 str67 str68 str69 str70
 str71 str72 str73 str74 str75 str76 str77 str78 str79 str80).

rename variables
(v6035 v6043 v6051 v6059 v6067 v6075 v6083 v6091 v6099 v6107
 v6115 v6123 v6131 v6139 v6147 v6155 v6163 v6171 v6179 v6187
 v6195 v6203 v6211 v6219 v6227 v6235 v6243 v6251 v6259 v6267
 v6275 v6283 v6291 v6299 v6307 v6315 v6323 v6331 v6339 v6347
 v6355 v6363 v6371 v6379 v6387 v6395 v6403 v6411 v6419 v6427
 v6435 v6443 v6451 v6459 v6467 v6475 v6483 v6491 v6499 v6507
 v6515 v6523 v6531 v6539 v6547 v6555 v6563 v6571 v6579 v6587
 v6595 v6603 v6611 v6619 v6627 v6635 v6643 v6651 v6659 v6667=
 fin1  fin2  fin3  fin4  fin5  fin6  fin7  fin8  fin9  fin10
 fin11 fin12 fin13 fin14 fin15 fin16 fin17 fin18 fin19 fin20
 fin21 fin22 fin23 fin24 fin25 fin26 fin27 fin28 fin29 fin30
 fin31 fin32 fin33 fin34 fin35 fin36 fin37 fin38 fin39 fin40
 fin41 fin42 fin43 fin44 fin45 fin46 fin47 fin48 fin49 fin50
 fin51 fin52 fin53 fin54 fin55 fin56 fin57 fin58 fin59 fin60
 fin61 fin62 fin63 fin64 fin65 fin66 fin67 fin68 fin69 fin70
 fin71 fin72 fin73 fin74 fin75 fin76 fin77 fin78 fin79 fin80).

rename variables (v2 v1183 = pid hhid).

*note that there are cases where the spouse and respondent
*new ids later in the file don't lead to perfect matches -
*so the first value for these identifiers used and 
*subsequent ids only used when no value existed for a 
*previous wave.

recode hhid v1687 (sysmis=-8).
Do if hhid=-8.
   compute hhid= v1687.
End if.
desc hhid. 

compute survey=2.

*note that the spouse data is entered twice in the file - once on
*the rows of the main respondents and once again on separate rows
*for the spouse data. The spouse rows contain secondary activity
*and who with information even though the documentation says that
*this is not the case. The spouse row times match up with the spouse
*column times on the respondent rows, hence the spouse line diaries 
*now are selected.

select if v7968=2.
desc hhid.

sort cases by hhid pid.

vector pri = pri1 to pri80 /secact = secact1 to secact80 /whr = whr1 to whr80 
      /wha = wha1 to wha80 /whb = whb1 to whb80 /str = str1 to str80
      /fin = fin1 to fin80.

loop i=1 to 80.
     compute pri=pri(i).
     compute secact=secact(i).
     compute whr=whr(i).
     compute wha=wha(i).
     compute whb=whb(i).
     compute str=str(i).
     compute fin=fin(i).
     var lab pri main activity.
     var lab secact secondary activity.
     var lab whr location.
     var lab wha "with whom 1st mention".
     var lab whb "with whom 2nd mention".
     var lab str start time.
     var lab fin finish time.
     val lab pri secact
      -8  missing
       0	'no secondary activity'
      11	'normal work-main job inc work at home'
      12    'work at home'
      22	'job search, look for work'
      23	'apply for, collect unemployment benefit'
      24	'apply for/collect other welfare'
      59	'2nd job (& small jobs of FT students)'
      69	'meals at work'
      78	'time before or after work at workplace'
      79	'other work related activity'
      89	'work breaks'
      97	'travel related to job search'
      98	'travel to/from work making other stops'
      99	'travel directly to/from workplace'
     109	'meal preparation, cook or serve food'
     119	'meal clean-up, do dishes'
     129	'routine indoor cleaning & chores'
     139	'routine clean house (outside)'
     149	'laundry, iron, fold clothes'
     161	'repair vehicle, home'
     162	'exterior repairs or maintenance'
     163	'car care, cleaning, tune up'
     164	'home improvements, remodelling'
     171	'gardening'
     172    'care of pets, walk dogs'
     173	'care of house plants'
     191	'other domestic work'
     192	'putter in yard'
     193	'household paperwork, pay bills'
     197	'other household chores'
     209	'care of babies aged under 5 years old'
     218	'care for children of mixed ages'
     219	'care for child aged 5-17'
     221	'teach child skill, show how to do things'
     222	'help child with homework'
     239	'read to/talk with child, listen to child'
     249	'adult play with child inside'
     259	'sport, walk, outside with child'
     269	'medical care for child'
     278	'unpaid babysitting'
     279	'other child care'
     299	'child care travel'
     301	'groceries, supermarket, shop for food'
     302	'other shopping for goods or clothes'
     311	'shop for goods, durables, appliances'
     312	'look to rent/purchase housing'
     329	'personal care services'
     339	'medical care, doctor, dentist'
     341	'financial services'
     342	'government services'
     351	'auto repair and related services'
     352	'clothes repair, cleaning services'
     353	'appliance repair services'
     354	'household repair services'
     379	'other services, go to the dump'
     389	'running errands'
     399	'travel related to goods or services'
     409	'wash, dress, get ready'
     411	'medical care of self at home'
     412	'medical care to adults in household'
     421	'non-medical care to adult from household'
     422	'help/care for adult from other household'
     423	'help/care for neighbours or friends'
     424	'help or care for unspecified adults'
     439	'meals & snacks at own home'
     449	'meal/snack away from home or workplace'
     459	'main sleep'
     469	'naps and resting'
     481	'time gap greater than 10 minutes'
     482	'personal, private, none of your business'
     483	'sex, make out'
     489	'other personal care'
     498	'travel related to adult care'
     499	'travel related to personal care'
     509	'ft student attend classes'
     519	'course/lecture'
     549	'homework, study, research'
     569	'other education'
     579	'end of diary activity'
     599	'other school-related travel'
     601	'union/professional group meetings'
     602	'other union/professional group activity'
     611	'meetings of identity groups'
     612	'other identity group activities'
     621	'meeting of political or civic group'
     622	'other political/civic activities'
     631	'attend meetings of voluntary group'
     632	'office volunteer'
     633	'fundraising activity for voluntary group'
     634	'direct help to persons as a member'
     635	'other voluntary activities for group'
     641	'religious charity group meeting'
     642	'other religious charity activity'
     643	'other religious group meetings'
     644	'other religious group act/social'
     651	'attend religious services'
     652	'private worship'
     661	'meetings of fraternal organisations'
     662	'other fraternal organisation activities'
     671	'meetings of family/youth organisations'
     672	'other family/youth group activities'
     689	'miscl volunteering'
     698	'travel related membership activities'
     699	'travel for other voluntary acts'
     709	'attend sports event'
     719	'other public event'
     729	'movies'
     739	'theater, concert, opera, ballet'
     749	'museum, gallery, zoo, exhibition'
     752	'visiting with others'
     769	'parties, receptions'
     771	'at bar, cocktail lounge'
     772	'dancing'
     789	'other socializing'
     799	'travel related to public events'
     801	'football, basket ball etc'
     802	'tennis, squash etc'
     803	'golf, miniature golf'
     804	'swim, water ski'
     805	'ski, skate'
     806	'bowl, ping-pong'
     807	'frisbee, catch'
     808	'exercise, yoga'
     811	'hunting'
     812	'fishing'
     813	'boat, sail, canoe'
     814	'camping'
     815	'snowmobile, dune buggy'
     816	'gliding, ballooning'
     817	'excursions'
     818    'picnic'
     821	'walking for pleasure'
     822	'hiking'
     823	'jogging, running'
     824	'cycling'
     825	'motorcycling'
     826	'horseback riding'
     831	'photography'
     832	'work on cars as hobby'
     833	'repair leisure equipment'
     834	'collections, scrapbooks'
     835	'carpentry/woodwork as hobby'
     841	'preserve foodstuffs'
     842	'knit, sew, needlework'
     843	'sewing'
     844	'care livestock/animals (not as farmer)'
     851	'sculpture, painting, drawing'
     852	'literature, write poetry'
     861	'play musical instrument'
     862	'sing'
     863	'act'
     864	'non-social dancing'
     871	'play card games'
     872	'play board games'
     873	'play social games'
     874	'puzzles'
     888	'sports classes or training'
     889	'other active leisure'
     899	'travel related to sport or leisure'
     909	'listen to radio'
     919	'watch TV'
     929	'listen to music, records'
     939	'read books'
     941	'read magazines, pamphlets'
     942	'read - not specified what'
     959	'read newspaper'
     961	'phone conversations'
     962	'face to face conversations'
     963	'conversation with hh members'
     979	'read or write letters'
     981	'relax'
     982	'think, plan, reflect'
     983	'do nothing, sit'
     984	'reported act of other, not self'
     989	'other passing leisure, smoke dope'
     999	'travel related to passive leisure'.
     val lab whr
       1  'own home'
       2  'in transit'
       3  'at work'
       4  'other home'
       5  'restaurant or bar'
       6  'indoor leisure place'
       7  'outdoor leisure place'
       8  'other place'.
     val lab wha whb
       0  'alone'
       1  'spouse/fiance'
       2  'close family'
       3  'other resident adult'
       4  'other friend/relation'
       5  'co-worker'
       6  'organisation member'
       7  'neighbour'
       8  'service personnel'
       9  'others'.
     xsave outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse4.sav'
    /keep = survey hhid pid pri secact whr wha whb str fin v7972 v7973 v7976.
end loop.
execute.

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse4.sav'.

recode pri secact (sysmis=-8).
freq pri secact.

recode str whr fin (sysmis=-8).
do if str=-8 and fin>-1.
     compute str=0.
Else if str=-8 and hhid~=lag(hhid).
     compute str=0.
     compute fin=1440.
     compute pri=481.
end if.
desc str fin. 

temp.
select if str=0.
freq str.

*this select command just leaves the diaries.

select if pri>-8 and pri~=579.
execute.

sort cases by hhid pid str.

match files files=* 
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\w4dspdem.sav'
     /BY hhid.
execute.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse4.sav'
   /keep survey wave hhid pid diaryday cday month year pri secact whr wha whb str fin agesp sexsp educsp 
    wkhrsp empstsp unempsp disrtsp students mwagesp v7972 v7973 v7976.
 
AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp4.sav'
  /BREAK=hhid pid
  /fin_1 = MEAN(fin).

match files 
   files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\testspid4.sav' /in=main
   files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agsp4.sav' /in=spouse
   /BY hhid.
cro main by spouse.

***************************************
**merge files into 1 1975 spouse file**
***************************************.

ADD FILES 
 /FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse1.sav'
 /FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse2.sav'
 /FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse3.sav'
 /FILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spouse4.sav'.
EXECUTE.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\allspouse.sav'.

*****************************************************
**finish transformation into harmonised file format**
*****************************************************.

Get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\allspouse.sav'.

missing values all ().

compute spouse=1.

*this sort can be made by hhid as there is only a maximum of
*one spouse per household.

sort cases by hhid wave str. 

freq str fin.

*there are 34 impossible time codes, two finish times of -8, one
*start time of 999, one start time of 2400. The impossible times 
*were manually investigated then changed or eliminated. For 
*instance, the 999 start times & -8 finish times appear to be 
*typing errors during the entry of one diary with the correct 
*lines also entered after the error lines. Subsequently revealed 
*bad lines also are eliminated in the next step.

compute drop=0.
If fin=-8 or str=999 drop=1. 
select if str>-8 and drop=0.
freq spouse.

Compute epnum=1.
Do if hhid=lag(hhid) and wave=lag(wave).
   compute epnum=lag(epnum)+1.
end if.
freq epnum.

*Fix finish time and related errors.

If wave=3 and pid=2249 and (epnum=1 or epnum=2 or epnum=4 or 
   epnum=6 or epnum=8  or epnum=10 or epnum=12 or epnum=14 or
   epnum=16 or epnum=18 or epnum=20 or epnum=22 or epnum=24 
   or epnum=26 or epnum=28) drop=1.
If wave=2 and pid=2250 and epnum=22 drop=1.
select if drop=0.
execute.

Do if wave=3 and pid=2774 and epnum=2.
   compute str=1600.
End if.

Do if wave=3 and pid=2540 and str=0.
   compute fin=810.
Else if wave=3 and pid=2540 and str=810.
   compute fin=815.
Else if wave=3 and pid=2540 and str=815.
   compute fin=825.
End if.

If wave=3 and pid=2801 and str=945 fin=1045.

Do if wave=4 and pid=2146 and str=2230.
   compute fin=2350.
Else if wave=4 and pid=2146 and str=2400.
   compute str=2350.
End if.

Do if wave=1 and pid=2314 and str=0.
   compute fin=415.
Else if wave=1 and pid=2314 and str=415.
   compute fin=430.
Else if wave=1 and pid=2314 and str=430.
   compute fin=500.
End if.

Do if wave=4 and pid=2848 and str=1702.
   compute fin=1745.
Else if wave=4 and pid=2848 and str=1745.
   compute fin=1853.
Else if wave=4 and pid=2848 and str=1853.
   compute fin=1858.
Else if wave=4 and pid=2848 and str=1920.
   compute fin=2000.
Else if wave=4 and pid=2848 and str=2030.
   compute fin=2130.
End if.

Do if wave=2 and pid=2250 and str=1130.
     compute fin=1205.
Else if wave=2 and pid=2250 and str=1250.
     compute fin=1300.
Else if wave=2 and pid=2250 and str=1300.
     compute fin=1315.
Else if wave=2 and pid=2250 and str=1325.
     compute fin=1330.
Else if wave=2 and pid=2250 and str=1330.
     compute fin=1400.
Else if wave=2 and pid=2250 and str=1400.
     compute fin=1515.
Else if wave=2 and pid=2250 and str=1515.
     compute fin=1530.
Else if wave=2 and pid=2250 and str=1530.
     compute fin=1700.
Else if wave=2 and pid=2250 and str=1800.
     compute fin=1830.
Else if wave=2 and pid=2250 and str=1900.
     compute fin=1930.
End if.

Do if wave=2 and pid=2636 and str=940.
     compute fin=1223.
Else if wave=2 and pid=2636 and str=1223.
     compute fin=1230.
Else if wave=2 and pid=2636 and str=1230.
     compute fin=1338.
End if.

Do if wave=2 and pid=2687 and str=620.
     compute fin=635.
Else if wave=2 and pid=2687 and str=635.
     compute fin=650.
Else if wave=2 and pid=2687 and str=650.
     compute fin=1000.
End if.
 
Do if wave=2 and pid=2407 and str=1700.
     compute fin=2000.
Else if wave=2 and pid=2407 and epnum=10.
     compute fin=2300.
Else if wave=2 and pid=2407 and epnum=11.
     compute str=2300.
Else if wave=2 and pid=2407 and epnum=8.
     compute fin=2215.
Else if wave=2 and pid=2407 and epnum=9.
     compute str=2215.
Else if wave=2 and pid=2407 and epnum=1.
     compute fin=1300.
Else if wave=2 and pid=2407 and epnum=2.
     compute str=1300.
     compute fin=1400.
End if.
execute.

Compute start=trunc(str/100)*60+(str-(trunc(str/100))*100).
Compute end=trunc(fin/100)*60+(fin-(trunc(fin/100))*100).
compute clockst= str.
Execute.

temp.
select if start>0 and start<61.
cro start by str.

temp.
select if end>0 and end<61.
cro end by fin.
desc end start.

sort cases by wave hhid str. 

*create duration variable and recreate episode number
*to address fixed problem cases.

Compute epnum=1.
Do if hhid=lag(hhid) and wave=lag(wave).
   compute epnum=lag(epnum)+1.
end if.
freq epnum.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\aggr.sav'
  /BREAK=wave hhid
  /maxep = MAX(epnum).

match files files=* table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\aggr.sav'
   /by wave hhid.
compute lastep=0.
if maxep=epnum lastep=1.
freq lastep.

*put in one more fix for bad single episode lines.

If epnum=1 and lastep=1 and end=880 end=1440.
If epnum=1 and lastep=1 and fin=1440 fin=2400.
compute time=end-start.
means time
   /cells mean min max.

temp.
select if time=1440.
freq wave epnum pri agesp.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'.

get file='C:\Users\Kimberly Fisher\Documents\MTUS-archive\USA\1975-76\MTUS\usa1975w552.sav'.

rename variables (age2 swave persid=mtusage wave pid).
execute.

missing values all ().

freq mtusage.

sort cases by wave pid.

SAVE OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\basicdem.sav'
   /keep wave pid mtusage ocombwt.   

Get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'.
sort cases by wave pid.

match files files=*
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\basicdem.sav'
   /by wave pid.
freq mtusage agesp.
recode mtusage (sysmis=-8).

if agesp=-8 agesp=mtusage.
freq agesp. 

sort cases by wave hhid str. 

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'.

*************************************
**create heritage files for spouses**
*************************************.

Get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'.

*create time use variables - note that in this case -7 codes
*are used for elements of the diary not included on the spouse
*diaries but included on the main respondent diaries. Where
*who else is present coding can be imputed from the main
*respondent diary (where the main respondent reported that the 
*spouse was present), and where secondary imputed travel can
*be imputed as the spouse diarist recorded a main activity 
*which is not travel and a location of travelling or a
*valid location code for both the activity and the previous 
*activity where the location of the activity differs from 
*the location of the previous activity, codes are imputed, but
*where codes cannot be imputed, the values for some who else
*is present markers and for secondary activity are coded as -7.

compute main=-5.
compute sec=-7.
compute inout=-5.
compute eloc=-5.
compute mtrav=-9.
compute alone=-7.
compute infant=0.
compute child=0.
compute sppart=0.
compute clsfam=-7.
compute hhadult=-7.
compute animal=0.
compute shoprof=0.
compute cowork=-7.
compute wellknw=0.
compute otherp=0.
compute unknwp=-9.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp1.sav'.
execute.

If pri=209 or pri=218 infant=1.
freq infant. 

If pri=218 or pri=221 or pri=222 or pri=239 or pri=249 or
   pri=259 or pri=269 or pri=278 or pri=209 child=1.
freq child.

match files files=* 
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\spousepresent.sav'
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\sppresag.sav'
   /BY wave hhid.
cro mainmax by epsppr.

Do if mainmax= epsppr.
   compute sppart=1.
Else if start<wspend1 and end>wspstr1.
   compute sppart=1.
Else if start<wspend2 and end>wspstr2.
   compute sppart=1.
Else if start<wspend3 and end>wspstr3.
   compute sppart=1.
Else if start<wspend4 and end>wspstr4.
   compute sppart=1.
Else if start<wspend5 and end>wspstr5.
   compute sppart=1.
Else if start<wspend6 and end>wspstr6.
   compute sppart=1.
Else if start<wspend7 and end>wspstr7.
   compute sppart=1.
Else if start<wspend8 and end>wspstr8.
   compute sppart=1.
Else if start<wspend9 and end>wspstr9.
   compute sppart=1.
Else if start<wspend10 and end>wspstr10.
   compute sppart=1.
End if.
freq sppart.

if pri=172 or pri=826 or pri=844 animal=1.
freq animal.

if ((pri=301 or pri=302) and whr>1) or pri=311 or pri=312 or
     pri=329 or pri=339 or pri=341 or pri=342 or pri=351 or
     pri=352 or pri=353 or pri=354 or pri=379 or pri=709 or
     pri=729 or pri=739 or pri=749 or pri=719 or pri=771
     shoprof=1.
freq shoprof.

temp.
select if shoprof=1.
freq pri. 

If pri=412 or pri=421 or pri=422 or pri=423 or pri=424 or
   pri=752 or pri=769 or pri=962 or pri=963 or pri=984 or
   sppart=1 wellknw=1.
freq wellknw.

If pri=509 or pri=519 or pri=601 or pri=611 or pri=621 or 
   pri=631 or pri=634 or pri=641 or pri=643 or pri=651 or
   pri=661 or pri=671 or pri=709 or pri=771 or pri=772 or 
   pri=801 or pri=802 or pri=873 or pri=888 or whr=5 otherp=1.
freq otherp.

temp.
select if otherp=1.
freq pri.   

*this coding syntax has a hierarchy - coded as outside if possible 
*first, and if not possible to code as outside, then if possible to 
*code as in transit, and if not possible, then to code as inside, 
*and residual set to -8.

Do if whr=7 or pri=139 or pri=162 or pri=164 or pri=171 or pri=192 
    or pri=259 or pri=811 or pri=812 or pri=813 or pri=814 or pri=815 
    or pri=816 or pri=818 or pri=822 or pri=824 or pri=825 or pri=826 
    or ((pri>800 and pri<810) and whr=8) or ((pri=709 or pri=789) and 
    whr~=6).
        compute inout=1.
Else if whr=2 or (pri>96 and pri<100) or pri=299 or pri=399 or pri=498 
    or pri=499 or pri=599 or pri=698 or pri=699 or pri=799 or pri=817 
    or pri=899 or pri=999.
        compute inout=3.
Else if whr=1 or (whr>2 and whr<7) or whr=8 or pri=69 or pri=78 or 
    pri=89 or pri=129 or pri=161 or pri=173 or pri=191 or pri=249 or 
    pri=302 or pri=312 or pri=329 or pri=339 or pri=341 or pri=342 or 
    pri=351 or pri=509 or pri=519 or pri=709 or pri=719 or pri=729 or 
    pri=739 or pri=749 or pri=771 or pri=803 or pri=805.
        compute inout=2.
Else.
        compute inout=-8.
End if.
freq inout.

temp.
select if inout=1.
freq pri whr.

temp.
select if inout=2.
freq pri whr.

temp.
select if inout=3.
freq pri whr.

temp.
select if inout=-8.
freq pri whr.

Do if pri=482 or pri=483 or pri=489.
   Compute main=1.
Else if pri=459.
   Compute main=3.
Else if pri=469.
   Compute main=5.
Else if pri=409.
   Compute main=6.
Else if pri=411.
   Compute main=7.
Else if pri=69.
   Compute main=8.
Else if pri=439 or pri=449.
   Compute main=9.
Else if (pri=11 and (whr>1 or whr=-8)) or (pri=79 
   and (whr>1 or whr=-8)). 
   Compute main=10.
Else if (pri=11 and whr=1) or (pri=79 and whr=1)
     or pri=12.
   Compute main=11.
Else if pri=59.
   Compute main=12.
Else if pri=89.
   Compute main=13.
Else if pri=78.
   Compute main=14.
Else if pri>21 and pri<25.
   Compute main=15.
Else if pri=509.
   Compute main=16.
Else if pri=549.
   Compute main=17.
Else if pri=519.
   Compute main=18.
Else if pri=569.
   Compute main=19.
Else if pri=109.
   Compute main=20.
Else if pri=119.
   Compute main=21.
Else if pri=129 or pri=139.
   Compute main=22.
Else if pri=149.
   Compute main=23.
Else if pri>160 and pri<165.
   Compute main=24.
Else if pri=191 or pri=193 or pri=197 or pri=389.
   Compute main=25.
Else if pri=301 or pri=302.
   Compute main=26.
Else if pri=311 or pri=312.
   Compute main=27.
Else if pri=329.
   Compute main=28.
Else if pri=339.
   Compute main=29.
Else if pri>350 and pri<355.
   Compute main=30.
Else if pri=341 or pri=342.
   Compute main=31.
Else if pri=379.
   Compute main=32.
Else if pri=209.
   Compute main=33.
Else if pri=218 or pri=219.
   Compute main=34.
Else if pri=269.
   Compute main=35.
Else if pri=249.
   Compute main=36.
Else if pri=221 or pri=222.
   Compute main=37.
Else if pri=239.
   Compute main=38.
Else if pri=278 or pri=279.
   Compute main=39.
Else if pri=412 or (pri>420 and pri<425).
   Compute main=40.
Else if pri=689.
   Compute main=41.
Else if pri=621 or pri=622.
   Compute main=42.
Else if pri=601 or pri=602.
   Compute main=43.
Else if pri=671 or pri=672.
   Compute main=44.
Else if pri=661 or pri=662.
   Compute main=45.
Else if pri=611 or pri=612 or (pri>630 and pri<636).
   Compute main=46.
Else if pri>640 and pri<645.
   Compute main=48.
Else if pri=651 or pri=652.
   Compute main=49.
Else if pri=789.
   Compute main=50.
Else if pri=709.
   Compute main=51.
Else if pri=729.
   Compute main=52.
Else if pri=739.
   Compute main=53.
Else if pri=749.
   Compute main=54.
Else if pri=719.
   Compute main=55.
Else if pri=771.
   Compute main=56.
Else if pri=769 or pri=772.
   Compute main=57.
Else if (pri>800 and pri<809) or pri=815 or pri=816
   or pri=823 or pri=825 or pri=826 or pri=888.
   Compute main=60.
Else if pri=821.
   Compute main=62.
Else if pri=824.
   Compute main=63.
Else if pri=192 or pri=814 or pri=817 or pri=818.
   Compute main=64.
Else if pri=259.
   Compute main=65.
Else if (pri>810 and pri<814) or pri=822.
   Compute main=66.
Else if pri=171 or pri=173.
   Compute main=67.
Else if pri=172 or pri=844.
   Compute main=68.
Else if pri=889.
   Compute main=70.
Else if pri=984.
   Compute main=71.
Else if pri=752.
   Compute main=72.
Else if pri>870 and pri<875.
   Compute main=73.
Else if pri>860 and pri<865.
   Compute main=74.
Else if pri=851 or pri=852 or pri=831.
   Compute main=75.
Else if (pri>840 and pri<844) or pri=835.
   Compute main=76.
Else if pri>831 and pri<835.
   Compute main=77.
Else if pri=981 or pri=982 or pri=983 or pri=989.
   Compute main=78.
Else if pri=939.
   Compute main=81.
Else if pri=941 or pri=942.
   Compute main=82.
Else if pri=959.
   Compute main=83.
Else if pri=929.
   Compute main=84.
Else if pri=909.
   Compute main=85.
Else if pri=919.
   Compute main=86.
Else if pri=979.
   Compute main=87.
Else if pri>960 and pri<964.
   Compute main=88.
Else if pri=499.
   Compute main=91.
Else if pri>96 and pri<100.
   Compute main=93.
Else if pri=599.
   Compute main=94.
Else if pri=399.
   Compute main=95.
Else if pri=299.
   Compute main=96.
Else if pri=698 or pri=699 or pri=498.
   Compute main=97.
Else if pri=799 or pri=899 or pri=999.
   Compute main=98.
Else if pri=0 or pri=481 or pri=579.
   Compute main=-8.
end if.
freq main.

temp.
select if main<15.
cro pri by main.

temp.
select if main>14 and main<28.
cro pri by main.

temp.
select if main>27 and main<42.
cro pri by main.

temp.
select if main>41 and main<56.
cro pri by main.

temp.
select if main>55 and main<70.
cro pri by main.

temp.
select if main>69 and main<84.
cro pri by main.

temp.
select if main>83.
cro pri by main.

temp.
select if main=-8.
desc time.

*note that medical services are not treated like other 
*services as a marker of at services when the location 
*is other or missing. The reason is that in some cases
*diarists appear to have completed diaries in hospital,
*and this recoding creates a false impression of a
*change of location when the main activity in the
*hospital changes.

Do if whr=1.
   compute eloc=1.
Else if whr=4.
   compute eloc=2.
Else if  pri=12 or pri=439.
   compute eloc=1.
Else if whr=3 or pri=69 or pri=78 or pri=89.
   compute eloc=3.
Else if whr=5 or pri=771.
   compute eloc=6.
Else if whr=2 or pri=97 or pri=98 or pri=99 or pri=299 
   or pri=399 or pri=498 or pri=499 or pri=599 or 
   pri=698 or pri=699 or pri=799 or pri=817 or pri=899
   or pri=999.
   compute eloc=8.
Else if pri=509 or pri=519.
   compute eloc=4.
Else if (pri>300 and pri<339) or (pri>339 and pri<353)
   or pri=379.
   compute eloc=5.
Else if whr>0.
   compute eloc=9.
Else.
   compute eloc=-8.
End if.
freq eloc.
cro whr by eloc.

*add imputation codes to activity variables.

temp.
select if main=-8.
freq main.

vector dqcheck(3).
Loop i=1 to 3.
   compute dqcheck(i)=0.
end loop.
var lab dqcheck1 "miss main, mode of transport".
var lab dqcheck2 "miss main, 2nd act reported".
var lab dqcheck3 "miss 20 min before/after travel".
val lab dqcheck1 to dqcheck3
   0 ordinary diary
   1 includes pattern.
freq dqcheck1 to dqcheck3.

*if main activity is missing and 
*   a) the location is travelling
*   b) the location is valid and not at home or 
*      another home and the previous location is
*      valid, not travelling, and different from 
*      the present location
*the main activity is coded to impute travel
*
*if the main activity is valid and not travel and
*the location is travelling or both the current and
*previous locations are valid and the previous location
*is not travelling and the current and previous location
*differ, the secondary activity is coded as imputed 
*travel
*
*if the main activity is missing and the location is
*at home or another home and the previous location is
*travel, main activity is coded as unknown personal
*or household care
*
*if the main activity is missing and the previous location
*is travel and the present location is valid but not at
*a home, the main activity is coded as imputed out of
*home activity.

Do if hhid=lag(hhid) and wave=lag(wave).
   Do if main<0 and eloc=8.
      compute main=90.
      compute dqcheck1=1. 
   Else if main<0 and ((eloc=1 or eloc=2) and lag(eloc)=8).
      compute main=2.
      compute dqcheck3=1. 
   Else if main<0 and eloc>0 and lag(eloc)=8.
      compute main=58.
   Else if main<0 and ((eloc>0 and lag(eloc)>0) and 
      eloc~=lag(eloc)).
      compute main=90.
      compute dqcheck1=1. 
   Else if (main>0 and main<90) and (eloc=8 or (((eloc>0 
      and eloc<8) and (lag(eloc)>0 and lag(eloc)<8)) and 
      eloc~=lag(eloc) and (lag(pri)<801 or lag(pri)>826))).
      compute sec=90.
   End if.
End if.
freq sec dqcheck1 dqcheck3.

temp.
select if main=-8 or main=2 or main=58 or main=90.
freq main.

*if main activity still missing and the location is
*valid and not at home, code the main activity as
*imputed activity away from home.

If main<0 and eloc>2 main=58.

temp.
select if main=-8 or main=58.
freq main.

compute test=0.
if lastep=1 and epnum>3 and main=-8 and lag(main)>0 test=1.

temp.
select if test=1.
freq time eloc.

compute test2=0.
if test=1 and eloc=-8 test2=lag(eloc).
freq test2.

temp.
select if test2>2.
freq time.

*if the missing time gap is the last episode of the diary,
*the diary has at least 4 episodes, the activity before
*the last time slot is not missing, and the location of 
*the last time slot is at home or someone else's home,
*or the location of the last time slot is missing but the
*location of the previous time slot is own home or 
*another home, the last time slot is recorded as imputed 
*sleep. For these cases where the last location is missing,
*the last location is set to the previous location.

If test=1 and test2<3 main=4.
If test=1 and test2<3 and eloc=-8 eloc=lag(eloc).

*if the time slot before the last time slot is travelling
*to home and the last time slot and the last location are
*missing, the last location is set to home and the last
*activity to imputed unknown personal care.

If test=1 and test2=8 main=2.
If test=1 and test2=8 dqcheck3=1.
If test=1 and test2=8 and eloc=-8 eloc=1.

*if the last time slot is missing and the last location
*is missing and the activity and location in the previous
*time slot are paid work at work, and the length of the 
*last time slot is less than 10 hours, the last activity
*is set to imputed unknown personal care and the last
*location set to home.

If test=1 and test2=3 and time<600 main=2.
If test=1 and test2=3 and eloc=-8 and time<600 eloc=1.

temp.
select if main=-8 or main=2 or main=4.
freq main.

compute test=0.
If maxep>3 and epnum=1 and main=-8 test=1.
freq test.

temp.
select if test=1.
freq time eloc.

*If the first time slot is missing and the diary has at
*least 4 episodes the first activity is set to imputed
*sleep; for the two diaries where the first location also
*is missing, the location is amended based on subsequent
*location.

If test=1 main=4.
If test=1 and eloc=-8 and hhid=665 eloc=1.
If test=1 and eloc=-8 and hhid=1398 eloc=2.

temp.
select if main=-8 or main=2 or main=4.
freq main.

compute test=0.
if hhid=lag(hhid) and wave=lag(wave) and main=-8 and 
   lag(main)=3 and maxep>3 test=1.

temp.
select if test=1.
freq eloc time.

*all 22 cases where there are 4 or more activities
*and a time gap follows sleep have missing location,
*but location appears to be at home as the location before
*is at home and the location following is at home or
*travelling. In these cases, the location recoded to at
*home; for all except one very long time gap have the
*main activity imputed as unknown personal care.

If test=1 eloc=1.
If test=1 and time<600 main=2.
If test=1 and time<600 dqcheck3=1.

temp.
select if main=-8 or main=2 or main=4.
freq main.

compute test=0.
if main=-8 and maxep>3 and (lag(main)=9 or 
   lag(main)=20 or lag(main)=21) test=1.

temp.
select if test=1.
freq time eloc.

compute test2=0.
if test=1 and eloc=-8 test2=lag(eloc).
freq test2.

*where the time gap in a diary with four or more
*activities follows eating a meal or food 
*preparation of setting table/putting away dishes 
*and the location is missing but the previous 
*location is at home or at another home, location 
*is set to the previous location. in these same 
*cases and cases where the stated location is home, 
*main is set to unknown imputed personal or 
*household care.

If eloc=-8 and (test2>0 and test2<3) eloc=test2.
If test=1 and test2<3 main=2.

temp.
select if main=-8 or main=2 or main=4.
freq main.

compute test=0.
if main=-8 and maxep>3 and lag(pri)=99 test=1.
freq test.

*cases where main is missing and the number of activities
*is 4 or more and the previous activity is travel to or
*from work, if the subsequent destination is home, main
*is set to imputed personal or home care; if the subsequent
*destination is work, main is set to imputed time away from
*home.

Do If test=1 and ((wave=1 and hhid=1145) or (wave=2 and hhid=157)
   or (wave=2 and hhid=1008) or (wave=3 and hhid=1088)).
   compute main=2.
   compute dqcheck3=1. 
Else if test=1.
   compute main=58.
End if.

temp.
select if main=-8 or main=2 or main=58.
freq main.

if wave=1 and hhid=1455 and epnum=3 eloc=8.

compute test=0.
if wave=lag(wave) and hhid=lag(hhid) and main=-8 and 
   maxep>3 and lastep=0 test=1.
freq test.

compute ep2=epnum-1.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\aggr.sav'
  /BREAK=wave hhid ep2
  /nextact=MAX(main)
  /nextloc=MAX(eloc)
  /epnum=max(ep2).

match files files=* table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\aggr.sav'
   /by wave hhid epnum.
execute.

compute test2=0.
If test=1 and eloc=1 test2=1.
freq test2.

temp.
select if test2=1.
freq time.

If test2=1 and time<121 main=2.

temp.
select if main=-8.
freq main.

compute eatdr=0.
If main=8 or main=9 or main=56 or sec=8 or 
   sec=9 or sec=20 or sec=21 or sec=56 eatdr=time. 

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\aggr2.sav'
  /BREAK=wave hhid
  /anyeat = SUM(eatdr).

match files files=* table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\aggr2.sav'
   /by wave hhid.
freq anyeat.

temp.
select if anyeat=0.
freq maxep main.
*some really low episode diaries with missing eating.

Do if anyeat=0 and (main=20 or main=21) and sec=-7 and maxep>9.
   compute sec=2.
End if.
freq sec.

compute test2=0.
If lag(eloc)=nextloc and test=1 and eloc=-8 test2=1.
freq test2. 

Do if test2=1 and time<121.
   compute eloc=lag(eloc).
   Do if lag(eloc)=1.
      compute main=2.
   Else if lag(eloc)>1.
      compute main=58.
   End if.
End if.

temp.
select if main=-8 or main=2 or main=58.
freq main.

compute test2=0.
If lag(eloc)=1 and nextloc=8 and test=1 and eloc=-8 test2=1.
freq test2. 

If test2=1 and time<121 eloc=1.
If test2=1 and time<121 main=2.

temp.
select if main=-8 or main=2 or main=58.
freq main.

compute test2=0.
If (lag(eloc)>1 and lag(eloc)~=8) and nextloc=8 and test=1 
   and eloc=-8 test2=1.
freq test2. 

If test2=1 and time<121 eloc=lag(eloc).
If test2=1 and time<121 main=58.

temp.
select if main=-8 or main=2 or main=58.
freq main.

compute test2=0.
If lag(eloc)=8 and (nextloc>1 and nextloc~=8) and test=1 
   and eloc=-8 test2=1.
freq test2. 

If test2=1 and time<121 eloc=nextloc.
If test2=1 and time<121 main=58.

*as the spouse diaries do not include a who else
*was present column, imputed social activity
*is added in place of missing main activity in
*diaries with 4 or more activities where the
*main respondent indicated being with the spouse 
*during the time frame.
If sppart=1 and main=-8 and maxep>3 main=71. 

temp.
select if main=-8 or main=2 or main=71 or main=58.
freq main.

cro inout by eloc.

*amend inout to reflect further corrections to eloc.

If inout=-8 and eloc=8 inout=3.

temp.
select if eloc=-8.
freq main.

if eloc=-8 and (main=62 or main=64) inout=1.
if eloc=-8 and (main>49 and main<57) eloc=5.

temp.
select if epnum=1.
freq eloc.

temp.
select if epnum=2.
freq eloc.

compute prevloc=lag(eloc).

temp.
select if eloc=-8.
cro main by prevloc.

If wave=lag(wave) and pid=lag(pid) and eloc=-8 and (prevloc=1
   or prevloc=2) and (main>0 and main<41) eloc=prevloc.
freq eloc.

temp.
select if mtrav=-7.
freq main sec.
 
Do if mtrav=-7 and (main>89 or sec>89).
   compute mtrav=5.
End if.
freq mtrav.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'
   /KEEP survey wave hhid pid diaryday cday month year time clockst start end epnum main sec inout eloc mtrav
         alone infant child sppart clsfam hhadult animal shoprof cowork wellknw otherp unknwp agesp sexsp 
         educsp wkhrsp empstsp unempsp disrtsp students mwagesp spouse maxep v7972 v7973 v7976. 

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousemarker.SAV'
  /BREAK=survey wave hhid pid
  /dqcheck1=MAX(dqcheck1)
  /dqcheck2=MAX(dqcheck2)
  /dqcheck3=MAX(dqcheck3).

Get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'.

freq main.

temp.
select if maxep>1 or (maxep=1 and main>-8).
freq main.

*1.9% of main activity time missing in this file, though only
*23 of the missing 1065 episodes in spouse diaries come from
*actual diaries rather than from non-response.

Compute t0pcare=0.
Compute t1paidw=0.
Compute t2ed=0.
compute t3unpaid=0.
compute t4acvol=0.
compute t5outhm=0.
compute t6exerc=0.
compute t7inhm=0.
compute t8media=0.
compute t9trav=0.
compute tmiss=0.
vector tmain(98) tsc(98).
compute outside=0.
compute inveh=0.
compute inside=0.
compute locunk=0.
compute athome=0.
compute atwrksc=0.
compute elsewhr=0.
compute lunk=0.
compute walone=-7.
compute wchild=0.
compute wsppart=0.
compute wclsfam=-7.
compute wother=0.
compute withunk=-7.
compute eatdr=0.
compute sleep=0.
compute perscare=0.
compute mstrav=0.
compute anycare=0.

If main>-1 and main<10 t0pcare  =time.
If main>9 and main<16 t1paidw   =time.
If main>15 and main<20 t2ed     =time.
If main>19 and main<40 t3unpaid =time.
If main>39 and main<50 t4acvol  =time.
If main>49 and main<60 t5outhm  =time.
If main>59 and main<70 t6exerc  =time.
If main>69 and main<80 t7inhm   =time.
If main>79 and main<90 t8media  =time.
If main>89 and main<100 t9trav  =time.
If main=-8 tmiss                =time.

If main=8 or main=9 or main=20 or main=21 or
   main=56 or sec=2 or sec=8 or sec=9 or 
   sec=20 or sec=21 or sec=56 eatdr =time. 
If main=3 or main=4 or main=5 or main=13 or
   main=78 or sec=3 or sec=5 or sec=13 or
   sec=78 sleep                 =time.
If main=1 or main=2 or main=6 or 
   main=7 or sec=1 or sec=6 or sec=7 
                       perscare =time.
If (main>89 and main<99) or (main>58 and
   main<68) or (sec>89 and sec<99) or 
   (sec>58 and sec<68) mstrav   =time.
If (main>32 and main<41) or main=68 or
   (sec>32 and sec<41) or sec=68 anycare=1.

If inout=1 outside              =time.
if inout=2 inside               =time.
if inout=3 inveh                =time.
if inout=-8 locunk              =time.
if eloc=1 athome                =time.
if eloc=3 or eloc=4 atwrksc     =time.
if eloc=2 or eloc>4 elsewhr     =time.
If eloc=-8 lunk                 =time.
*If alone=1 walone               =time.
If child=1 wchild               =time.
If sppart=1 wsppart             =time.
*If clsfam=1 wclsfam             =time.
If shoprof=1 or otherp=1 or (wellknw=1 and
   clsfam=0) wother             =time.

Do repeat a=tmain1 to tmain98 /b=tsc1 to tsc98 /i=1 to 98.
   compute a=0.
   compute b=-7.
   Do if main=i.
      compute a=time.
   End if.
End repeat.
apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp2.sav'.

desc t0pcare t1paidw t2ed t3unpaid t4acvol t5outhm 
     t6exerc t7inhm t8media t9trav tmiss eatdr sleep 
     perscare mstrav outside inside inveh locunk 
     athome atwrksc elsewhr lunk walone wchild 
     wsppart wclsfam wother withunk anycare.

compute t1dig = SUM(t0pcare to tmiss).
compute t2dig = SUM (tmain1 to tmain98).
compute t2dig = t2dig + tmiss.
execute.

*set all variable codes which could not be constructed to -9 for
*missing.

recode tmain89 tsc89 tmain92 tsc92 (0=-9).
execute.

sort cases by survey wave hhid pid.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'
  /BREAK=survey wave hhid pid
  /diaryday = MAX(diaryday) /cday = MAX(cday)
  /month = MAX(month)       /year = MAX(year)
  /tottime "total minutes recorded in diary" = SUM(time) 
  /numep 'total original episodes recorded' = MAX(epnum) 
  /t0pcare = SUM(t0pcare)   /t1paid = SUM(t1paidw)   /t2ed = SUM(t2ed)       
  /t3unpaid = SUM(t3unpaid) /t4acvol = SUM(t4acvol)  /t5outhm = SUM(t5outhm) 
  /t6exerc = SUM(t6exerc)   /t7inhm = SUM(t7inhm)    /t8media = SUM(t8media) 
  /t9trav = SUM(t9trav)     /tmiss = SUM(tmiss)
  /tmain1  = SUM(tmain1)    /tmain2  = SUM(tmain2)   /tmain3  = SUM(tmain3)
  /tmain4  = SUM(tmain4)    /tmain5  = SUM(tmain5)   /tmain6  = SUM(tmain6)
  /tmain7  = SUM(tmain7)    /tmain8  = SUM(tmain8)   /tmain9  = SUM(tmain9)
  /tmain10 = SUM(tmain10)   /tmain11 = SUM(tmain11)  /tmain12 = SUM(tmain12)
  /tmain13 = SUM(tmain13)   /tmain14 = SUM(tmain14)  /tmain15 = SUM(tmain15)
  /tmain16 = SUM(tmain16)   /tmain17 = SUM(tmain17)  /tmain18 = SUM(tmain18)
  /tmain19 = SUM(tmain19)   /tmain20 = SUM(tmain20)  /tmain21 = SUM(tmain21)
  /tmain22 = SUM(tmain22)   /tmain23 = SUM(tmain23)  /tmain24 = SUM(tmain24)
  /tmain25 = SUM(tmain25)   /tmain26 = SUM(tmain26)  /tmain27 = SUM(tmain27)
  /tmain28 = SUM(tmain28)   /tmain29 = SUM(tmain29)  /tmain30 = SUM(tmain30)
  /tmain31 = SUM(tmain31)   /tmain32 = SUM(tmain32)  /tmain33 = SUM(tmain33)         
  /tmain34 = SUM(tmain34)   /tmain35 = SUM(tmain35)  /tmain36 = SUM(tmain36)
  /tmain37 = SUM(tmain37)   /tmain38 = SUM(tmain38)  /tmain39 = SUM(tmain39)
  /tmain40 = SUM(tmain40)   /tmain41 = SUM(tmain41)  /tmain42 = SUM(tmain42)         
  /tmain43 = SUM(tmain43)   /tmain44 = SUM(tmain44)  /tmain45 = SUM(tmain45)
  /tmain46 = SUM(tmain46)   /tmain48 = SUM(tmain48)  /tmain49 = SUM(tmain49)         
  /tmain50 = SUM(tmain50)   /tmain51 = SUM(tmain51)  /tmain52 = SUM(tmain52)
  /tmain53 = SUM(tmain53)   /tmain54 = SUM(tmain54)  /tmain55 = SUM(tmain55)         
  /tmain56 = SUM(tmain56)   /tmain57 = SUM(tmain57)  /tmain58 = SUM(tmain58)         
  /tmain60 = SUM(tmain60)   /tmain62 = SUM(tmain62)  /tmain63 = SUM(tmain63)
  /tmain64 = SUM(tmain64)   /tmain65 = SUM(tmain65)  /tmain66 = SUM(tmain66)
  /tmain67 = SUM(tmain67)   /tmain68 = SUM(tmain68)  /tmain70 = SUM(tmain70)
  /tmain71 = SUM(tmain71)   /tmain72 = SUM(tmain72)  /tmain73 = SUM(tmain73)
  /tmain74 = SUM(tmain74)   /tmain75 = SUM(tmain75)  /tmain76 = SUM(tmain76)         
  /tmain77 = SUM(tmain77)   /tmain78 = SUM(tmain78)  /tmain81 = SUM(tmain81)
  /tmain82 = SUM(tmain82)   /tmain83 = SUM(tmain83)  /tmain84 = SUM(tmain84)
  /tmain85 = SUM(tmain85)   /tmain86 = SUM(tmain86)  /tmain87 = SUM(tmain87)
  /tmain88 = SUM(tmain88)   /tmain89 = MAX(tmain89)  /tmain90 = SUM(tmain90)
  /tmain91 = SUM(tmain91)   /tmain92 = MAX(tmain92)  /tmain93 = SUM(tmain93)
  /tmain94 = SUM(tmain94)   /tmain95 = SUM(tmain95)  /tmain96 = SUM(tmain96)         
  /tmain97 = SUM(tmain97)   /tmain98 = SUM(tmain98)  /tsc1 = MAX(tsc1)
  /tsc2 = MAX(tsc2)         /tsc3 = MAX(tsc3)        /tsc4 = MAX(tsc4)
  /tsc5 = MAX(tsc5)         /tsc6 = MAX(tsc6)        /tsc7 = MAX(tsc7)
  /tsc8 = MAX(tsc8)         /tsc9 = MAX(tsc9)        /tsc10= MAX(tsc10) 
  /tsc11= MAX(tsc11)        /tsc12= MAX(tsc12)       /tsc13= MAX(tsc13)       
  /tsc14= MAX(tsc14)        /tsc15= MAX(tsc15)       /tsc16= MAX(tsc16)
  /tsc17= MAX(tsc17)        /tsc18= MAX(tsc18)       /tsc19= MAX(tsc19)
  /tsc20= MAX(tsc20)        /tsc21= MAX(tsc21)       /tsc22= MAX(tsc22)       
  /tsc23= MAX(tsc23)        /tsc24= MAX(tsc24)       /tsc25= MAX(tsc25)       
  /tsc26= MAX(tsc26)        /tsc27= MAX(tsc27)       /tsc28= MAX(tsc28)
  /tsc29= MAX(tsc29)        /tsc30= MAX(tsc30)       /tsc31= MAX(tsc31)       
  /tsc32= MAX(tsc32)        /tsc33= MAX(tsc33)       /tsc34= MAX(tsc34)
  /tsc35= MAX(tsc35)        /tsc36= MAX(tsc36)       /tsc37= MAX(tsc37)
  /tsc38= MAX(tsc38)        /tsc39= MAX(tsc39)       /tsc40= MAX(tsc40)       
  /tsc41= MAX(tsc41)        /tsc42= MAX(tsc42)       /tsc43= MAX(tsc43)       
  /tsc44= MAX(tsc44)        /tsc45= MAX(tsc45)       /tsc46= MAX(tsc46)
  /tsc48= MAX(tsc48)        /tsc49= MAX(tsc49)       /tsc50= MAX(tsc50)
  /tsc51= MAX(tsc51)        /tsc52= MAX(tsc52)       /tsc53= MAX(tsc53)
  /tsc54= MAX(tsc54)        /tsc55= MAX(tsc55)       /tsc56= MAX(tsc56)
  /tsc57= MAX(tsc57)        /tsc58= MAX(tsc58)       /tsc60= MAX(tsc60)
  /tsc62= MAX(tsc62)        /tsc63= MAX(tsc63)       /tsc64= MAX(tsc64)
  /tsc65= MAX(tsc65)        /tsc66= MAX(tsc66)       /tsc67= MAX(tsc67)
  /tsc68= MAX(tsc68)        /tsc70= MAX(tsc70)       /tsc71= MAX(tsc71)
  /tsc72= MAX(tsc72)        /tsc73= MAX(tsc73)       /tsc74= MAX(tsc74)
  /tsc75= MAX(tsc75)        /tsc76= MAX(tsc76)       /tsc77= MAX(tsc77)
  /tsc78= MAX(tsc78)        /tsc81= MAX(tsc81)       /tsc82= MAX(tsc82)
  /tsc83= MAX(tsc83)        /tsc84= MAX(tsc84)       /tsc85= MAX(tsc85)
  /tsc86= MAX(tsc86)        /tsc87= MAX(tsc87)       /tsc88= MAX(tsc88)
  /tsc89= MAX(tsc89)        /tsc90= MAX(tsc90)       /tsc91= MAX(tsc91)       
  /tsc92= MAX(tsc92)        /tsc93= MAX(tsc93)       /tsc94= MAX(tsc94)
  /tsc95= MAX(tsc95)        /tsc96= MAX(tsc96)       /tsc97= MAX(tsc97)       
  /tsc98= MAX(tsc98)        /outside = SUM(outside)  /inside = SUM(inside)
  /inveh = SUM(inveh)       /locunk = SUM(locunk)    /athome = SUM(athome)
  /atwrksc = SUM(atwrksc)   /elsewhr = SUM(elsewhr)  /lunk = SUM(lunk)
  /walone = MAX(walone)     /wchild = SUM(wchild)    /wsppart = SUM(wsppart)
  /wclsfam = MAX(wclsfam)   /wother = SUM(wother)    /withunk = MAX(withunk)  
  /eatdr = SUM(eatdr)       /sleep = SUM(sleep)      /perscare = SUM(perscare)
  /mstrav = SUM(mstrav)     /agesp = MAX(agesp)      /sexsp = MAX(sexsp)
  /educsp = MAX(educsp)     /wkhrsp = MAX(wkhrsp)    /empstsp = MAX(empstsp)
  /unempsp = MAX(unempsp)   /disrtsp = MAX(disrtsp)  /students = MAX(students)
  /mwagesp = MAX(mwagesp)   /spouse = MAX(spouse)    /t1dig = SUM(t1dig)       
  /t2dig = SUM(t2dig)       /anycare=MAX(anycare)    /v7972 = MAX(v7972)
  /v7973 = MAX(v7973)       /v7976 = MAX(v7976).

Get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'.

*check that variables sum to 1440 in aggregated file.

freq t1dig t2dig tottime.

*this reveals 5 further problem cases, wave 2 hhid 723; wave 3 
*hhid 1339; wave 3 hhid 1384; wave 3 hhid 2392; wave 4 hhid 
*1458.
*select if t1dig~=1440.
*execute.  
*these cases now addressed earlier in the file.

compute muchmiss=0.
If tmiss>90 muchmiss=1.
var lab muchmiss missing more than 90 minutes.
val lab muchmiss 
   0 no more than 90 minutes missing
   1 more than 90 minutes missing.
*note there are a number of non-diaries that are lines of 
*non-responding spouses. These cases are kept for purposes
*of future examination of non-response, however these cases
*are not considered when calculating the number of bad diaries.

temp.
select if numep>1 or (numep=1 and tmiss=0).  
freq muchmiss.

compute lowep=0.
If numep<7 lowep=1.
var lab lowep "<7 episodes".
cro lowep by numep.

temp.
select if numep>1 or (numep=1 and tmiss=0).  
freq lowep.

compute misbasic=0.
If mstrav=0 misbasic=misbasic+1.
If eatdr=0 misbasic=misbasic+1.
If sleep=0 misbasic=misbasic+1.
If perscare=0 misbasic=misbasic+1.
var lab misbasic number basic activites not recorded.
freq misbasic. 
cro misbasic by anycare.

temp.
select if numep>1 or (numep=1 and tmiss=0).  
freq misbasic. 
cro misbasic by anycare.

temp.
select if anycare=1 and misbasic>1.
freq numep.

*some missing 2 basic activities but performed care,
*but 3 of these 29 have low episodes.
compute caremflg=0.
if anycare=1 and misbasic>1 and numep>9 caremflg=1.
cro caremflg by anycare by misbasic.

temp.
select if misbasic=2.
freq numep athome.

*determine additional cases where we will not drop cases if
*they miss two basic activities only.
compute keep=0.
if misbasic=2 and numep>14 keep=1.
if misbasic=2 and athome>999 and numep>11 keep=1.
freq keep.
cro keep by caremflg.

compute lowqual=0.
If muchmiss=1 or lowep=1 or (misbasic>1 and caremflg=0 and keep=0)
   lowqual=1.
freq lowqual.

compute baddem=0.
compute owghtflg=3.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp2.sav'.

cro lowqual by muchmiss lowep misbasic.
cro lowqual by misbasic by caremflg.

temp.
select if numep>1 or (numep=1 and tmiss=0).  
freq lowqual.

cro wave by sexsp educsp empstsp unempsp disrtsp students.
 
MEANS TABLES=agesp wkhrsp mwagesp BY wave
  /CELLS MEAN MIN MAX.
 
temp.
select if agesp>0.
MEANS TABLES=agesp BY wave
  /CELLS MEAN MIN MAX.
 
temp.
select if wkhrsp>0.
MEANS TABLES=wkhrsp BY wave
  /CELLS MEAN MIN MAX.
 
temp.
select if mwagesp>0.
MEANS TABLES=mwagesp BY wave
  /CELLS MEAN MIN MAX.

If agesp=-8 or sexsp=-8 or diaryday=-8 baddem=1.
compute baddem2=0.
var lab baddem2 "age, sex or empstat missing (0 weighed)".
val lab baddem2
   0 no
   1 yes.
If agesp=-8 or sexsp=-8 or empstsp=-8 or diaryday=-8 baddem2=1.

temp.
select if numep>1 or (numep=1 and tmiss=0).  
cro baddem baddem2 by lowqual.

compute drop=0.
if numep=1 and tmiss=1440 drop=1.
freq drop.

vector particp(4) goodr(4) goodd(4) goodba(4) goodbb(4).

Loop i=1 to 4.
   compute particp(i)=-1.
   compute goodr(i)=-1.
   compute goodd(i)=-1.
   compute goodba(i)=-1.
   compute goodbb(i)=-1.
If wave=i and numep=1 and tmiss=1440 particp(i)=0.
If wave=i and lowqual=1 or baddem=1 goodr(i)=0.
If wave=i and lowqual=1 goodd(i)=0.
if wave=i and baddem=1 goodba(i)=0.
if wave=i and baddem2=1 goodbb(i)=0.
If wave=i and numep>1 or (numep=1 and tmiss<1440) particp(i)=1.
If wave=i and lowqual=0 and baddem=0 goodr(i)=1.
If wave=i and lowqual=0 goodd(i)=1.
if wave=i and baddem=0 goodba(i)=1.
if wave=i and baddem2=0 goodbb(i)=1.
End loop.

var lab particp1 participated wave 1.
var lab particp2 participated wave 2.
var lab particp3 participated wave 3.
var lab particp4 participated wave 4.
var lab goodr1 good diary & dem wave 1.
var lab goodr2 good diary & dem wave 2.
var lab goodr3 good diary & dem wave 3.
var lab goodr4 good diary & dem wave 4.
var lab goodd1 good diary wave 1.
var lab goodd2 good diary wave 2.
var lab goodd3 good diary wave 3.
var lab goodd4 good diary wave 4.
var lab goodba1 good age & sex wave 1.
var lab goodba2 good age & sex wave 2.
var lab goodba3 good age & sex wave 3.
var lab goodba4 good age & sex wave 4.
var lab goodbb1 good empstat, age & sex wave 1.
var lab goodbb2 good empstat, age & sex wave 2.
var lab goodbb3 good empstat, age & sex wave 3.
var lab goodbb4 good empstat, age & sex wave 4.
val lab particp1 to goodbb4
   0 no
   1 yes.
execute.

AGGREGATE
  /OUTFILE='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\agspouse.sav'
  /BREAK=survey hhid pid spouse
  /sex = MAX(sexsp) /age = MAX(agesp) /particp1 = MAX(particp1) /particp2 = MAX(particp2) 
  /particp3 = MAX(particp3) /particp4 = MAX(particp4) /goodr1 = MAX(goodr1) /goodr2 = MAX(goodr2) 
  /goodr3 = MAX(goodr3) /goodr4 = MAX(goodr4) /goodd1 = MAX(goodd1) /goodd2 = MAX(goodd2) 
  /goodd3 = MAX(goodd3) /goodd4 = MAX(goodd4) /goodba1 = MAX(goodba1) /goodba2 = MAX(goodba2) 
  /goodba3 = MAX(goodba3) /goodba4 = MAX(goodba4) /goodbb1 = MAX(goodbb1) /goodbb2 = MAX(goodbb2) 
  /goodbb3 = MAX(goodbb3) /goodbb4 = MAX(goodbb4) /v7972 = MAX(v7972) /v7973 = MAX(v7973)
  /v7976 = MAX(v7976).

select if drop=0.

freq muchmiss lowep lowqual.

cro lowqual by misbasic.
cro lowqual by baddem.

sort cases by wave hhid.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\addwght75spouse.sav'
   /keep wave hhid pid diaryday year tottime numep t0pcare t1paid t2ed t3unpaid t4acvol t5outhm t6exerc t7inhm 
    t8media t9trav tmiss lowqual caremflg baddem baddem2 sexsp agesp empstsp v7972 v7973 v7976.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'
   /drop eatdr sleep perscare mstrav anycare muchmiss lowep misbasic t1dig t2dig baddem2 particp1 particp2 particp3 
         particp4 goodr1 goodr2 goodr3 goodr4 goodd1 goodd2 goodd3 goodd4 goodba1 goodba2 goodba3 goodba4 goodbb1 
         goodbb2 goodbb3 goodbb4 i v7972 v7973 v7976.
 
***************************************************************
At this point, need to run convertUSA75TUV-part 3, then return*
*to this point - START HERE                                   *
***************************************************************.

add files 
    files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'
    files='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975hfsum.sav'
   /keep wave hhid pid diaryday.
sort cases by wave hhid pid.

match files files=* /in=base 
      file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\wspwt.sav' /in=wt
   /by wave hhid pid.
execute.

cro base by wt.

rename variables (origmsp=orgallwt).

weight by orgallwt.
freq diaryday agesexgp.
weight off.

****************************
*                  Weighted*
*men 18 thru 24    6.2% 439*
*men 25 thru 34   10.1% 716*
*men 35 thru 44    8.4% 595*
*men 45 thru 54    6.5% 461*
*men 55 thru 64    6.1% 432*
*men 65+           7.8% 553*
*women 18 thru 24  8.0% 567*
*women 25 thru 34 12.3% 873*
*women 35 thru 44  8.0% 567*
*women 45 thru 54  8.9% 631*
*women 55 thru 64  8.2% 581*
*women 65+         9.5% 673*
*Total                 7088*
****************************.
var lab orgallwt original combined sample weight.
desc orgallwt.

sort cases by agesexgp diaryday.

aggregate outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\group.sav'
               /break=agesexgp
               /grouptot=sum(allwt) /groupto2=sum(mspinfwt) /groupto3=sum(coupwt).
aggregate outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\day.sav'
               /break= agesexgp diaryday
               /daytot=sum(allwt) /daytot2=sum(mspinfwt) /daytot3=sum(coupwt) /dayn=nu.
execute.
match files file=* 
     /table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\group.sav'
     /by agesexgp.
execute.
match files file=* 
     /table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\day.sav'
     /by agesexgp diaryday.
execute.

compute exptot =(grouptot/7).
compute exptot2=(groupto2/7).
compute exptot3=(groupto3/7).

compute  allrecwt=0.
compute  allinfwt=0.
compute  couplewt=0.
Do if allwt>0.
   compute allrecwt=(exptot/daytot)/(dayn/daytot).
   compute allinfwt=(exptot2/daytot2)/(dayn/daytot2).
   compute couplewt=(exptot3/daytot3)/(dayn/daytot3).
End if.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp2.sav'.

desc allrecwt allinfwt couplewt orgallwt.

if agesexgp=1  allrecwt=allrecwt*(439/430).
if agesexgp=2  allrecwt=allrecwt*(716/708).
if agesexgp=3  allrecwt=allrecwt*(595/577).
if agesexgp=4  allrecwt=allrecwt*(461/456).
if agesexgp=5  allrecwt=allrecwt*(432/416).
if agesexgp=6  allrecwt=allrecwt*(553/535).
if agesexgp=11 allrecwt=allrecwt*(567/560).
if agesexgp=12 allrecwt=allrecwt*(873/872).
if agesexgp=13 allrecwt=allrecwt*(567/555).
if agesexgp=14 allrecwt=allrecwt*(631/625).
if agesexgp=15 allrecwt=allrecwt*(581/565).
if agesexgp=16 allrecwt=allrecwt*(673/661).
compute allrecwt=allrecwt*(7088/7089).
if agesexgp=1  allinfwt=allinfwt*(5745241/5627648).
if agesexgp=2  allinfwt=allinfwt*(9359184/9257858).
if agesexgp=3  allinfwt=allinfwt*(7783876/7542852).
if agesexgp=4  allinfwt=allinfwt*(6023237/5959908).
if agesexgp=5  allinfwt=allinfwt*(5652576/5435791).
if agesexgp=6  allinfwt=allinfwt*(7227884/6989968).
if agesexgp=11 allinfwt=allinfwt*(7413215/7327110).
if agesexgp=12 allinfwt=allinfwt*(11397817/11403405).
if agesexgp=13 allinfwt=allinfwt*(7413215/7261097).
if agesexgp=14 allinfwt=allinfwt*(8247201/8166260).
if agesexgp=15 allinfwt=allinfwt*(7598545/7387866).
if agesexgp=16 allinfwt=allinfwt*(8803193/8645520).
if agesexgp=1  couplewt=couplewt*(152/150).
if agesexgp=2  couplewt=couplewt*(556/551).
if agesexgp=3  couplewt=couplewt*(487/472).
if agesexgp=4  couplewt=couplewt*(389/383).
if agesexgp=5  couplewt=couplewt*(323/313).
if agesexgp=6  couplewt=couplewt*(414/397).
if agesexgp=11 couplewt=couplewt*(272/270).
if agesexgp=12 couplewt=couplewt*(595/590).
if agesexgp=13 couplewt=couplewt*(407/400).
if agesexgp=14 couplewt=couplewt*(425/422).
if agesexgp=15 couplewt=couplewt*(307/299).
if agesexgp=16 couplewt=couplewt*(248/243).
compute couplewt=couplewt*(4574/4575).

weight by allrecwt.
freq diaryday agesexgp.
cro agesexgp by diaryday /cell=row.
weight by allinfwt.
freq diaryday agesexgp.
cro agesexgp by diaryday /cell=row.
weight by couplewt.
freq diaryday.
cro agesexgp by diaryday /cell=row.
weight off.
var lab allrecwt weight for combined main & spouse sample.
var lab allinfwt inflated population weight for combined main & spouse sample.
var lab couplewt weight for couple where both completed good diaries.
sort cases by wave hhid pid.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975allweights.sav'
   /keep wave hhid pid orgallwt allrecwt allinfwt couplewt.

select if pid>1999.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spweights.sav'
   /keep wave hhid pid orgallwt allrecwt allinfwt couplewt.

Get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975allweights.sav'.

select if pid<2000.
execute.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975allweights.sav'.

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'.

sort cases by wave hhid pid.

match files files=* /in=base 
      file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spweights.sav' /in=wt
   /by wave hhid pid.
execute.

cro base by wt.

sort cases by survey wave hhid pid.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'
   /keep survey wave hhid pid diaryday cday month year tottime 
    numep t0pcare t1paid t2ed t3unpaid t4acvol t5outhm t6exerc 
    t7inhm t8media t9trav tmiss tmain1 tmain2 tmain3 tmain4 tmain5 tmain6 tmain7 tmain8 
    tmain9 tmain10 tmain11 tmain12 tmain13 tmain14 tmain15 tmain16 tmain17 tmain18 tmain19 tmain20 
    tmain21 tmain22 tmain23 tmain24 tmain25 tmain26 tmain27 tmain28 tmain29 tmain30 tmain31 tmain32 
    tmain33 tmain34 tmain35 tmain36 tmain37 tmain38 tmain39 tmain40 tmain41 tmain42 tmain43 tmain44 
    tmain45 tmain46 tmain48 tmain49 tmain50 tmain51 tmain52 tmain53 tmain54 tmain55 tmain56 tmain57 
    tmain58 tmain60 tmain62 tmain63 tmain64 tmain65 tmain66 tmain67 tmain68 tmain70 tmain71 tmain72 
    tmain73 tmain74 tmain75 tmain76 tmain77 tmain78 tmain81 tmain82 tmain83 tmain84 tmain85 tmain86 
    tmain87 tmain88 tmain89 tmain90 tmain91 tmain92 tmain93 tmain94 tmain95 tmain96 tmain97 tmain98 
    tsc1 tsc2 tsc3 tsc4 tsc5 tsc6 tsc7 tsc8 tsc9 tsc10 tsc11 tsc12 
    tsc13 tsc14 tsc15 tsc16 tsc17 tsc18 tsc19 tsc20 tsc21 tsc22 
    tsc23 tsc24 tsc25 tsc26 tsc27 tsc28 tsc29 tsc30 tsc31 tsc32 
    tsc33 tsc34 tsc35 tsc36 tsc37 tsc38 tsc39 tsc40 tsc41 tsc42 
    tsc43 tsc44 tsc45 tsc46 tsc48 tsc49 tsc50 tsc51 tsc52 tsc53 
    tsc54 tsc55 tsc56 tsc57 tsc58 tsc60 tsc62 tsc63 tsc64 tsc65 
    tsc66 tsc67 tsc68 tsc70 tsc71 tsc72 tsc73 tsc74 tsc75 tsc76 
    tsc77 tsc78 tsc81 tsc82 tsc83 tsc84 tsc85 tsc86 tsc87 tsc88 
    tsc89 tsc90 tsc91 tsc92 tsc93 tsc94 tsc95 tsc96 tsc97 tsc98 
    outside inside inveh locunk athome atwrksc elsewhr lunk 
    walone wchild wsppart wclsfam wother withunk agesp sexsp 
    educsp wkhrsp empstsp unempsp disrtsp students mwagesp 
    spouse lowqual baddem caremflg orgallwt owghtflg allrecwt allinfwt couplewt. 

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\addspousequal.sav'
   /keep survey wave hhid pid lowqual baddem caremflg orgallwt owghtflg allrecwt allinfwt couplewt.

Get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'.

sort cases by survey wave hhid pid.

match files files=* 
      table='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\addspousequal.sav'
   /by wave hhid.
execute.

apply dictionary from 'C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\AHTUS final files\History of harmonisation - Diary\schema\schemasp1.sav'.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.SAV'
   /drop v7972 v7973 v7976. 

*check that all variables present and appropriately labelled.

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.sav'.

desc survey wave hhid pid diaryday cday month year time clockst 
  start end epnum main sec inout eloc mtrav alone infant child 
  sppart clsfam hhadult animal shoprof cowork wellknw otherp 
  unknwp lowqual baddem agesp sexsp educsp wkhrsp empstsp 
  unempsp disrtsp students mwagesp orgallwt allrecwt allinfwt couplewt.

recode lowqual baddem caremflg (sysmis=0).
recode owghtflg (sysmis=1).
if hhid=466 and wave=2 students=0.

freq survey wave diaryday cday month year main sec inout 
  eloc mtrav alone infant child sppart clsfam hhadult animal 
  shoprof cowork wellknw otherp unknwp agesp sexsp educsp
  wkhrsp empstsp unempsp disrtsp students mwagesp spouse 
  maxep lowqual baddem caremflg owghtflg.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfep.sav'.

get file='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'.

if hhid=466 and wave=2 students=0.

desc survey wave hhid pid diaryday cday month year tottime numep 
     t0pcare t1paid t2ed t3unpaid t4acvol t5outhm t6exerc t7inhm 
     t8media t9trav tmiss tmain1 to tmain85.
desc tmain86 to tsc93.
desc tsc94 to tsc98 outside inveh inside locunk athome atwrksc 
     elsewhr lunk walone wchild wsppart wclsfam wother withunk 
     lowqual baddem agesp sexsp educsp wkhrsp empstsp unempsp 
     disrtsp students mwagesp orgallwt allrecwt allinfwt couplewt.

freq survey wave diaryday cday month year tottime numep agesp 
  sexsp educsp wkhrsp empstsp unempsp disrtsp students mwagesp 
  spouse lowqual baddem owghtflg.

save outfile='C:\Users\Kimberly Fisher\Documents\Kimberly\time\ATUS\1975\USA1975spousehfsum.sav'.

temp.
select if allrecwt=0.
cro lowqual by baddem. 

temp.
select if allrecwt~=0.
freq diaryday.

weight by allrecwt.
freq diaryday.
weight off.
