******************************************************
** Syntax producing the USA heritage time use files **
** BSL-ATUS 2006 created by Evrim Altintas and      **
** Kimberly Fisher                                  **
** Centre for Time Use Research, University of      **
** Oxford, Department of Sociology, Manor Road      **
** Oxford OX1 3UQ United Kingdom                    **
** Last update, 26 January 2014                     **
******************************************************.

*the information needed for the heritage format of
*the ATUS data is stored across the various files.
*the individual elements are now separately extracted.

*note that tu06fwgt replaced by tufinwgt as the weighting
*procedure changed in 2006, and the cross-time weight now
*needs to be based on the same procedure for all years
*as opposed to the different procedure adopted in the earlier
*years.


GET FILE='H:\evrim\AHTUS\2006\atusresp_2006.sav'
   /keep tucaseid tuyear tumonth tudidate tudiday tufinwgt.

freq tuyear tumonth tudidate tudiday. 

rename variables (tucaseid tuyear tumonth tudiday = 
                  pid year month diaryday).
*tudidate must be numeric, not string.
compute cday= tudidate - trunc(tudidate/100)*100.
freq cday.

sort cases by pid.
save outfile='H:\evrim\AHTUS\2006\tempa\datewght.sav'
   /keep pid diaryday cday month year tufinwgt.  

*extract sex and age to check weights - also to refine closefamily code.
GET FILE='H:\evrim\AHTUS\2006\atusrost_2006.sav'.

*select for the diarists only.
select if terrp=18 or terrp=19.

rename variables (tucaseid teage tesex =pid age sex).
freq sex.
desc age.

sort cases by pid.
save outfile='H:\evrim\AHTUS\2006\tempa\dem.sav'
   /keep pid sex age.

GET FILE='H:\evrim\AHTUS\2006\atusrost_2006.sav'
   /keep TUCASEID TULINENO TEAGE TERRP.
freq teage terrp.
*There are four missings of age and 15 of relation.

temp.
select if teage=-3.
freq terrp tulineno tucaseid.
*20060201060073-> this diarist does not know the age or relation of 
*the two people in the house.

   compute u5=0.
   compute u18=0.
*>-1 is not to code missings as child.
   If teage >-1 and teage <5 u5=1.
   If teage >-1 and teage <18 u18=1.
freq u5 u18.
cro teage by u5 u18.

rename variables tucaseid=pid.

sort cases by pid tulineno.
save outfile='H:\evrim\AHTUS\2006\tempa\kidflag.sav'
  /keep pid tulineno teage u5 u18.

*********************************
*make who else present variables*
*********************************.

GET FILE='H:\evrim\AHTUS\2006\atuswho_2006.sav'.
freq tuwhocod.
*52 cases of missings.

rename variables (tucaseid tuact_n=pid epnum).

sort cases by pid tulineno.
match files files=*
   table='H:\evrim\AHTUS\2006\tempa\kidflag.sav'
   /by pid tulineno.
execute.


*presence of animals and shop or professional staff only
*possible to code from the activity data.

compute alone=0.
compute infant=0.
compute child=0.
compute sppart=0.
compute clsfam=0.
compute hhadult=0.
compute cowork=0.
compute wellknw=0.
compute otherp=0.
compute unknwp=0.

apply dictionary from 'H:\evrim\AHTUS\schema1.sav'.
freq alone to unknwp.

If tuwhocod=18 or tuwhocod=19 alone=1.
cro tuwhocod by alone.

cro tuwhocod by u18 u5. 

temp.
select if tuwhocod=-2.
freq teage u5 u18.

*note that some spouses aged <18 - to avoid confusion with spouse and
*a child being present from cases of a spouse aged 16-17 only present,
*code the child variables only for cases where the tuwhocod>spouse/partner.

If u5=1 and tuwhocod>21 infant=1.
If u18=1 and tuwhocod>21 child=1.
freq infant child.

cro child by infant. 
cro tuwhocod by child.
cro u18 by child.
cro u5 by child.


*check cases of people aged <18 present but no child code are
*all diarists or spouses.
temp.
select if child=0 and u18=1.
freq tuwhocod.

if tuwhocod=20 or tuwhocod=21 sppart=1.
freq sppart.
cro tuwhocod by sppart.

*not clear whether some potential close family codes are in
*the same household or not. This code is not possible to 
*create for 1975 (spouse), 1985 or 1992-94. The level of 
*close family present in 1965-66 is 30% of episodes; and
*the level for the main respondent diaries in 1975/76 is 
*33.9%. This definition yields 40% of time around close
*family - much higher - but then time around children is 
*higher in this survey than in the heritage surveys.
*this figure will be somewhat distorted in this file
*as people with multiple children around their whole
*family will have a row case for each child plus the spouse
*or partner for each joint activity - this figure should
*amend down when matched to the activity file.
if (tuwhocod>19 and tuwhocod<26) or tuwhocod=27 clsfam=1.
freq clsfam.

If tuwhocod=26 or (tuwhocod>27 and tuwhocod<40) hhadult=1.
freq hhadult.

If tuwhocod=55 cowork=1.
freq cowork.

If (tuwhocod>19 and tuwhocod<57) wellknw=1.
freq wellknw.

If tuwhocod=57 or tuwhocod=58 otherp=1.
freq otherp.

If trwhona=0 and tuwhocod<0 unknwp=1.
freq unknwp.

cro tuwhocod by hhadult cowork wellknw otherp unknwp.

AGGREGATE
  /OUTFILE="H:\evrim\AHTUS\2006\tempa\addwho.sav"
  /BREAK=pid epnum 
  /alone   = MAX(alone)
  /infant  = MAX(infant)
  /child   = MAX(child) 
  /sppart  = MAX(sppart)
  /clsfam  = MAX(clsfam)
  /hhadult = MAX(hhadult)
  /cowork  = MAX(cowork)
  /wellknw = MAX(wellknw) 
  /otherp  = MAX(otherp)
  /unknwp  = MAX(unknwp).

********************
*time use variables*
********************.

Get file='H:\evrim\AHTUS\2006\atusact_2006.sav'
 /keep tucaseid tuact_n tustart tustop.

sort cases by tucaseid tuact_n. 

SAVE TRANSLATE OUTFILE='H:\evrim\AHTUS\2006\tempa\startstop.dat'
  /TYPE=TAB /MAP /REPLACE /FIELDNAMES.

*this start and stop time information is recorded as string 
*fields (in hour minute second format, though the second 
*field is left blank). The file is saved as ASCII and reopened
*breaking up the time fields to concert the time information
*to a format consistent with the other heritage files.

GET DATA  /TYPE = TXT
 /FILE = 'H:\evrim\AHTUS\2006\tempa\startstop.dat'
 /DELCASE = LINE
 /DELIMITERS = "\t:"
 /ARRANGEMENT = DELIMITED
 /FIRSTCASE = 2
 /IMPORTCASE = ALL
 /VARIABLES =
 pid F14.0
 epnum F2.0
 sthr F2.0
 stmin F2.0
 stsec F2.0
 finhr F2.0
 finmin F2.0
 finsec F2.0
.
CACHE.
EXECUTE.

sort cases by pid(a) epnum (d). 

compute clockst= sthr*100 + stmin.
freq clockst.

*NOTE that ATUS 2006 begins the diary day at 4:00.
*the clockst variable denotes the clock time when
*the activity began - but the variables start and
*end are converted to mark the minute position in
*the diary for consistency with the previous surveys.

Do if sthr>3. 
   compute cst=clockst-400.
Else if sthr<4.
   compute cst=clockst+2000.
End if.
Do if finhr>3. 
   compute cend= (finhr*100 + finmin)-400.
Else if finhr<4. 
   compute cend= (finhr*100 + finmin)+2000.
end if.
execute.

*NOTE also that the end time shows the actual
*end time and not the end of the diary day.
*While this information is extremely useful,
*as it is not available in the heritage surveys,
*the end time of the last episode is set to 2400.

AGGREGATE
  /OUTFILE*
  mode=addvariables
  /BREAK=pid
  /maxep = MAX(epnum).

compute lastep=0.
If epnum=maxep lastep=1.
freq lastep.
*this confirms the recording of 12943 diaries.

if lastep=1 cend=2400.
desc cend cst.

sort cases by pid(a) epnum(a). 

Compute start=trunc(cst/100)*60+(cst-(trunc(cst/100))*100).
Compute end=trunc(cend/100)*60+(cend-(trunc(cend/100))*100).
compute time=end-start.
desc start end time.

save outfile="H:\evrim\AHTUS\2006\tempa\sstime.sav"
   /keep pid epnum clockst start end time maxep lastep. 


*TEST*

temp.						
select if lastep=1.				
freq end.				
*should be 1440=# of diaries (in 2006 12943).	
						
temp.				
select if epnum=1.				
freq start.					
*all should be 0.				


***************************
*process the activity file*
***************************.

Get file='H:\evrim\AHTUS\2006\atusact_2006.sav'.

missing values all ().

rename variables (tucaseid tuact_n =pid epnum).

compute main=-5.
compute sec=0.
compute inout=-5.
compute eloc=-5.
compute mtrav=-5.
compute survey=7.
compute wave=4.
*Wave must be changed every year. 
*(2006=4, 2005=3, 2004=2 etc).

apply dictionary from 'H:\evrim\AHTUS\schema1.sav'.

freq survey wave.

match files files=*
      files="H:\evrim\AHTUS\2006\tempa\sstime.sav"
   /BY pid epnum.
execute. 

match files files=*
      table='H:\evrim\AHTUS\2006\tempa\datewght.sav'
   /BY pid.

match files files=*
      files="H:\evrim\AHTUS\2006\tempa\addwho.sav"
   /by pid epnum.

freq actcode tewhere.

temp.
select if tewhere=-2 or tewhere=-1 or tewhere=89.
freq actcode.

temp.
select if actcode=10101 or actcode=10102 or actcode=10201 or
   actcode=10199 or actcode=10299 or actcode=10401 or 
   actcode=10499 or actcode=30111 or actcode=30112 or 
   actcode=30503 or actcode=30504 or actcode=40111 or 
   actcode=40112 or actcode=40507 or actcode=40508 or 
   actcode=120301 or actcode=130131 or actcode=500105 or
   actcode=500106.
freq actcode.

*all instances of sleep (10101); sleeplessnes (10102); sleeping (nec) (10199)
*washing & dressing (10201); grooming nec (10299); personal care (10401); 
*personal care nec (10499), 500106 (do not remember), and 500105 
*(none of your business) have no recorded location. Recode the 
*location of these activities (except for the do not remember) 
*as the location where they are before starting the activity (unless 
*this is travelling) or as the next location unless the next 
*location is travelling or the end of the diary.

sort cases by pid(a) epnum(d).
compute nextact=-5.
compute nextloc=-5.
if pid=lag(pid) nextact=lag(actcode).
if pid=lag(pid) nextloc=lag(tewhere).
freq nextact nextloc.
*there are 12943 diaries (we know this as the frequency
*of epnum=1 is 12943) with nextloc and nextact=-5 - these
*are the last episodes in the diary day.

*In 2005 ATUS travel codes are changed from 17xxxx to 18xxxx.

temp.
select if nextact=-5.
freq lastep.

sort cases by pid(a) epnum(a).

compute next=-5.
Do if lastep=1.
     compute next=5.
Else if nextloc=-1 or nextloc=89.
     compute next=1.
Else if nextact>500000 and ((nextloc>0 and nextloc<12) or nextloc=30 or 
     nextloc=31 or nextloc=32).
     compute next=3.
Else if nextact<180000 and ((nextloc>0 and nextloc<12) or nextloc=30 or 
     nextloc=31 or nextloc=32).
     compute next=4.
Else if ((nextloc>11 and nextloc<30) or nextloc=99 or (nextact>17999 and 
   nextact<500101) or nextact=500103).
     compute next=2.
End if.
val lab next
    1 next still missing
    2 travel next
    3 next act missing but next location known
    4 next act known and not travel and location known
    5 end of diary and missing location.
freq next.

compute prevact=-5.
compute prevloc=-5.
if pid=lag(pid) prevact=lag(actcode).
if pid=lag(pid) prevloc=lag(tewhere).
freq prevact prevloc.

*again 12943 cases of previous activity and location=-5.
*these are the first episodes.

format actcode (f4.0).

temp.
select if epnum=1.
freq prevact.

compute prev=-5.
Do if epnum=1.
     compute prev=5.
Else if prevloc=-1 or prevloc=89.
     compute prev=1.
Else if prevact>500000 and ((prevloc>0 and prevloc<12) or prevloc=30 or 
     prevloc=31 or prevloc=32).
     compute prev=3.
Else if prevact<180000 and ((prevloc>0 and prevloc<12) or prevloc=30 or 
     prevloc=31 or prevloc=32).
     compute prev=4.
Else if ((prevloc>11 and prevloc<30) or prevloc=99 or (prevact>17999 and 
   prevact<500101) or prevact=500103).
     compute prev=2.
End if.
val lab prev
    1 previous still missing
    2 previous travel
    3 previous act missing but previous location known
    4 previous act known and not travel and location known
    5 start of diary and missing location.
freq prev.

temp.
select if lastep=1 or epnum=1.
freq tewhere.
*most of the first and last episodes have missing location.

compute where=tewhere.
compute where2=tewhere.
freq where.
*where will be used to code location. where2 is used to look at 
*the transformations to ensure the adjustments work as expected.
*before we start, 47033 (17.9% of cases)=-1; 530(0.2% of cases)= 89; and 1 case =99.

Do if pid=lag(pid) and (actcode=10101 or actcode=10102 or actcode=10201 
   or actcode=10299 or actcode=10401 or actcode=10499 or actcode=500106) 
   and (prev=3 or prev=4).
   compute where=prevloc.
Else if pid=lag(pid) and (actcode=10101 or actcode=10102 or actcode=10201 
   or actcode=10299 or actcode=10401 or actcode=10499 or actcode=500106) 
   and (next=3 or next=4).
   compute where=nextloc.
End if.
freq where.
cro tewhere by where.
*19057 (7.2% of cases)=-1; 530 (0.2%)=89 and 1 case= 99.

Do if epnum=1.
   compute eptest=1.
Else if epnum=2.
   compute eptest=2.
Else if lastep=1.
   compute eptest=5.
Else if epnum=maxep-1.
   compute eptest=4.
Else.
   compute eptest=3.
End if.
val lab eptest
   1 1st episode
   2 2nd episode
   3 middle episode
   4 next from last episode
   5 last episode.

temp.
select if where=-1 or where=89.
freq eptest.

*of those locations which remain missing 62.2% are the first episode;
*8.3% 2nd episode; 15.7% last episode; 3.6% penultimate episode, rest 
*in middle.

format lastep to eptest (f4.0).

compute prev2=0.
if where=-1 prev2=lag(where).
if where=-1 and $casenum=1 prev2=-5.
freq prev2.

sort cases by pid(a) epnum(d).

compute next2=0.
if where=-1 next2=lag(where).
if where=-1 and $casenum=1 next2=-5.
freq next2.

sort cases by pid(a) epnum(a).

*second filling-in iteration - where there have been two slots in 
*a row with the location missing, fill in the location as the 
*previous or next location so long as the previous or next location
*not travelling.

Do if pid=lag(pid) and (where=-1 or where=89) and ((prev2>0 and 
     prev2<12) or prev2=30 or prev2=31 or prev2=32).
   compute where=prev2.
Else if (pid=lag(pid) or epnum=1) and (where=-1 or where=89) and 
     ((next2>0 and next2<12) or next2=30 or next2=31 or next2=32).
   compute where=next2.
End if.
freq where.
cro where by where2.

*now 6418 (2.4% of cases)=-1; 530 (0.2%)=89. repeat the 
*previous iteration to pick up second and penultimate cases. 

compute prev2=0.
if where=-1 prev2=lag(where).
if where=-1 and $casenum=1 prev2=-5.
freq prev2.

sort cases by pid(a) epnum(d).

compute next2=0.
if where=-1 next2=lag(where).
if where=-1 and $casenum=1 next2=-5.
freq next2.

sort cases by pid(a) epnum(a).

Do if pid=lag(pid) and (where=-1 or where=89) and ((prev2>0 and prev2<12) 
     or prev2=30 or prev2=31 or prev2=32).
   compute where=prev2.
Else if (pid=lag(pid) or epnum=1) and (where=-1 or where=89) and ((next2>0 and 
     next2<12) or next2=30 or next2=31 or next2=32).
   compute where=next2.
End if.
freq where.
cro where by where2.

*now 5257 (2.0% of cases)=-1; 530 (0.2%)=89.

temp.
select if where=-1 or where=89.
freq eptest.

*more now at beginning of diary- 39.3% first episode; 26.8% 2nd
*episode; 3.0% last episode; 6.3% penult episode, rest in middle.

compute test=0.
if lastep=1 and where=-1 test=1.
freq test.

temp.
select if epnum=1 and where=-1.
freq next actcode nextact.

*these diaries start with location unknown followed by travel 
*or more missing; about 60% sleep followed by personal care.

temp.
select if epnum=2 and where=-1.
cro prevact by nextact nextloc.
*deal with cases of sleep or personal care, followed by personal care
*in episode 2, followed by travel. Determine where people end up 
*after their travel cycle completed.

compute mark=0.
if epnum=2 and actcode=10201 and prevact<10405 and (nextact>130103 
   and nextact<190000) mark=1.
var lab mark 'marker of sleep then wash then cycle/walk or travel'.
compute mark2=0.
if lastep=1 and (prevact>180000 and prevact<500000) and where=-1 and
   actcode<10500 mark2=1.
freq mark mark2.

compute locs=0.
compute locf=0.
if epnum=1 locs=where.
if lastep=1 locf=where.

AGGREGATE
  /OUTFILE*
  mode=addvariables
  /BREAK=pid
  /pattern1 'starts sleep, wash, travel' = MAX(mark)
  /pattern2 'ends travel then person care or sleep' = MAX(mark2)
  /locstart=max(locs)
  /locend=max(locf).

cro pattern1 by locend pattern2.
cro pattern2 by locstart.

if pattern2=1 and lastep=1 and (where=-1 or where=89) and locstart=1 where=1.
if pattern1=1 and epnum=1 and (where=-1 or where=89) and locend=1 where=1.
if pattern1=1 and epnum=2 and (where=-1 or where=89) and locend=1 where=1.
freq where.

*now 2461 cases (0.9%) have location=-1 and 530 (0.2%) location not remembered
*1 with unspecified mode of transport.

*rerun some previous iterations as start and end locations now amended.

sort cases by pid(a) epnum(d).
compute nextloc=-5.
if pid=lag(pid) nextloc=lag(where).
sort cases by pid(a) epnum(a).

save outfile = "H:\evrim\AHTUS\2006\tempa\tempfile1_1.sav".

get file  = "H:\evrim\AHTUS\2006\tempa\tempfile1_1.sav".

compute next=-5.
Do if lastep=1.
     compute next=5.
Else if nextloc=-1 or nextloc=89.
     compute next=1.
Else if nextact>500000 and ((nextloc>0 and nextloc<12) or nextloc=30 or 
     nextloc=31 or nextloc=32).
     compute next=3.
Else if nextact<180000 and ((nextloc>0 and nextloc<12) or nextloc=30 or 
     nextloc=31 or nextloc=32).
     compute next=4.
Else if ((nextloc>11 and nextloc<30) or nextloc=99 or (nextact>17999 and 
   nextact<500101) or nextact=500103).
     compute next=2.
End if.
val lab next
    1 next still missing
    2 travel next
    3 next act missing but next location known
    4 next act known and not travel and location known
    5 end of diary and missing location.
freq next.

compute prevloc=-5.
if pid=lag(pid) prevloc=lag(tewhere).
compute prev=-5.
Do if epnum=1.
     compute prev=5.
Else if prevloc=-1 or prevloc=89.
     compute prev=1.
Else if prevact>500000 and ((prevloc>0 and prevloc<12) or prevloc=30 or 
     prevloc=31 or prevloc=32).
     compute prev=3.
Else if prevact<180000 and ((prevloc>0 and prevloc<12) or prevloc=30 or 
     prevloc=31 or prevloc=32).
     compute prev=4.
Else if ((prevloc>11 and prevloc<30) or prevloc=99 or (prevact>17999 and 
   prevact<500101) or prevact=500103).
     compute prev=2.
End if.
val lab prev
    1 previous still missing
    2 previous travel
    3 previous act missing but previous location known
    4 previous act known and not travel and location known
    5 start of diary and missing location.
freq prev.

Do if pid=lag(pid) and (actcode=10101 or actcode=10102 or actcode=10201 
   or actcode=10299 or actcode=10401 or actcode=10499 or actcode=500106) 
   and (prev=3 or prev=4).
   compute where=prevloc.
Else if pid=lag(pid) and (actcode=10101 or actcode=10102 or actcode=10201 
   or actcode=10299 or actcode=10401 or actcode=10499 or actcode=500106) 
   and (next=3 or next=4).
   compute where=nextloc.
End if.
freq where.
cro tewhere by where.

*now 2171 cases (0.8%) have location=-1 and 530 (0.2%) location not remembered.

compute prev2=0.
if where=-1 prev2=lag(where).
if where=-1 and $casenum=1 prev2=-5.
sort cases by pid(a) epnum(d).
compute next2=0.
if where=-1 next2=lag(where).
if where=-1 and $casenum=1 next2=-5.
sort cases by pid(a) epnum(a).

Do if pid=lag(pid) and (where=-1 or where=89) and ((prev2>0 and 
     prev2<12) or prev2=30 or prev2=31 or prev2=32).
   compute where=prev2.
Else if (pid=lag(pid) or epnum=1) and (where=-1 or where=89) and 
     ((next2>0 and next2<12) or next2=30 or next2=31 or next2=32).
   compute where=next2.
End if.
freq where.
cro where by where2.

*now 2044 cases (0.8%) have location=-1 and 530 (0.2%) location not remembered.


temp.
select if where=89.
freq eptest.
*none of 530 don't remember cases at the beginning or end of the diary,
*most in the middle of the diary. 

temp.
select if where=-1.
freq eptest.

*first and middle episodes now have majority of location not reported during
*sleep or personal care. look at sequences around both cases.

temp.
select if where=89.
freq prevact actcode nextact prevloc nextloc.

*one common pattern here is travel for child care or adult help(own household &
*other household), followed by drop-off or pick up adult/child, followed
*by adult help or child care travel. These cases are not at home or at the
*workplace, unlikely to be school as school runs are more likely to be
*remembered. The AHTUS location codes are less detailed than the ATUS
*codes, and the location is going to be away from home and in transit,
*so these locations set to other.

If where=89 and (prevact>180000 and prevact<190000) and (actcode=30111 or actcode=30112 
   or actcode=30503 or actcode=30504 or actcode=40111 or actcode=40112 or actcode=40507 
   or actcode=40508) and (nextact>180000 and nextact<190000) where=11.

*also a number of 89 cases during walking - check before and after locations and acts.
temp.
select if where=89 and actcode=130131.
cro prevloc by nextloc.
*nearly half of these cases are walks returning to the same place (more home than
*elsewhere), or tansition walks between home or other home and elsewhere. Code such
*cases as outdoors away from home. Other cases in between forms of transport - and 
*walking could be inside, but are not at home or specified place, so code these as
*other place.

do if where=89 and actcode=130131 and ((prevloc>-1 and prevloc<12) or 
   (nextloc>-1 and nextloc<12)).
   compute where=9.
else if where=89 and actcode=130131.
   compute where=11.
end if.

freq where.

*now 2044 cases (0.8%) have location=-1 and 23 (0.0%)=89 location not remembered.

temp.
select if where=89.
freq prevact actcode nextact prevloc nextloc.

*these remaining 89 cases all involve waiting for or dropping off an adult
*or child, (except 1) so set these to other location on same principle as the previous
*transformation.
If where=89 and (actcode=30111 or actcode=30112 or actcode=30503 or actcode=30504 
   or actcode=40112 or actcode=40507 or actcode=40508) where=11.

temp.
select if where=-1 and epnum>1 and lastep=0.
cro prevloc by nextloc.

*two main cases where missing location but not beginning or end of diary day, 
*strings of missing cases (sleep and personal care) together, and single
*personal care breaks in between travel episodes. Deal with former first,
*counting the number of cases in these strings.

compute test=0.
Do if epnum=1 and where=-1.
   compute test=1.
Else if where=-1 and pid=lag(pid).
   compute test=lag(test)+1.
End if.
freq test.

*1 string of 5 or more acts, 3 strings of 4 acts, 54 strings of 3 acts,
* 241 strings of two acts. Visually examine the ones more than three strings.

temp.
select if test>3.
freq pid.
*20061010061823 and 20061110060112.
*20061010061823 is a good diary with 21 episodes. The first one and the last eight episodes 
*have missing locations. The activities in all those episodes are sleep or washing/dressing.
*The resp returns back home watches TV, health-rel safe care and then goes to bed. 
*Wakes up and kitchen cleaning (at home). 
*Recode the period after self care as resp.s home.

*Similarly, 20061110060112 is a good diary with 31 episodes. The resp spends time at home all
*day and then goes to  sleep. Sleeping episodes (interrupted with wash/groom) are missings. 
*Recode the sleeping and washing/dressing period as resp.'s home.

Do if (pid=20061010061823 or pid=20061110060112) and where=-1.
   compute where=1.
End if.

*20061211061850 is also a good diary. The diarist travels to home & sleeps & then personal care and
*then leaves home. Code his sleeping time after traveling home as home. 
Do if pid=20061211061850 and (epnum=1 or epnum=2 or epnum=3 or epnum=23) and where=-1.
   compute where=1.
End if.

If where=-1 and (prevloc>-1 and prevloc<12) and (nextloc>-1 and nextloc<12)
   and prevloc=nextloc where=prevloc.
execute.

temp.
select if test=3.
cro epnum by locend.
*most strings of three are at start of diary day and day ends at home.

temp.
select if where=-1 and epnum<4.
cro locstart by locend.

if where=-1 and epnum<4 and locend=1 where=1.

freq where.
*now 1168 cases (0.4%) have location=-1.

temp.
select if where=-1.
fre prevact nextact actcode.

temp.
select if where=-1.
desc time.

compute test=0. 
if (actcode=10101 or actcode=10102) and where=-1 test=1.

temp.
select if test=1.
freq epnum lastep.
*191(147+44) of these 345 cases where sleep remains in missing location
*are the first or last episode of the diary day. Visually look
*at cases.

compute mark=0.
compute mark2=0.
compute locs=0.
compute locf=0.
if epnum=1 locs=where.
if lastep=1 locf=where.
if where=1 mark=1.
if where=3 mark2=3.
freq mark2.

AGGREGATE
  /OUTFILE*
  mode=addvariables
  /BREAK=pid
  /anyhome 'any time at own home' = MAX(mark)
  /anyohome 'any time at another home' = MAX(mark2)
  /locstart2=max(locs)
  /locend2=max(locf).

temp.
select if test=1.
freq locstart2 locend2.

*where the person starts or ends the day at home and
*the location where they are asleep is unknown at the
*other end of the diary day, code the sleep to being
*at home.

if test=1 and epnum=1 and locend2=1 where=1.
if test=1 and lastep=1 and locstart2=1 where=1.

compute test=0. 
if (actcode=10101 or actcode=10102) and where=-1 test=1.

if test=1 and epnum=1 and locend2=3 where=3.
if test=1 and lastep=1 and locstart2=3 where=3.

compute test=0. 
if (actcode=10101 or actcode=10102) and where=-1 test=1.

temp.
select if test=1.
cro anyhome by anyohome.

temp.
select if test=1.
desc time.

compute test2=0.
if time<61 and test=1 test2=1.
freq test2.
*naps visually examined.

*if the person spends any time at home, assume these sleep and nap
*episodes are at home. If no time spent at home but time spent at
*someone else's home, then the sleeping location set to other home.
if anyhome=1 and test=1 where=1.
if anyhome=0 and anyohome=3 and test=1 where=3.

freq where.
*now 862 cases (0.3%) have location=-1.

compute test=0. 
if (actcode=10101 or actcode=10102) and where=-1 test=1.
freq test.

*now only 39 cases of sleep with unidentified location. visually examine.
*these diaries either clearly involve sleep at an other location
*or give no clear indication. Code these as at other locations.

compute atoth=0.
if where=9 or where=11 atoth=1.

AGGREGATE
  /OUTFILE*
  mode=addvariables
  /BREAK=pid
  /anyother 'any time at other location' = MAX(atoth)
  /nolocslp 'any sleep with no time at home or other home' = MAX(test).

temp.
select if test=1.
cro anyother by nolocslp.

if where=-1 and anyother=1 where=11.
freq where.
*now 371 cases (0.1%) have location=-1.

temp.
select if where=-1.
fre prevact nextact actcode.

temp.
select if where=-1.
desc time.

*visually examine the cases where sleep is missing place.
temp.
select if test=1.
freq pid.

*most of the remainder between travel gaps, remainder left missing.

*now that the location information filled in wherever possible,
*make AHTUS variables.

*****************
*AHTUS variables*
*****************.

*this coding syntax has a hierarchy - coded as outside if possible 
*first, and if not possible to code as outside, then if possible 
*to code as in transit, and if not possible, then to code as inside.
*cases with unknown location that are most likely to take place inside
*sleep and personal care, and those sports that are generally inside,
*USA bowling, billiards, gymnastics, martial arts, set to inside,
*main activity not possible to code but location is walking set to outside;
*and residual set to -8.

*see what people are doing when walking (need to avoid coding mall walking
*as outside).
temp.
select if tewhere=14.
freq actcode.

save outfile= 'H:\evrim\AHTUS\2006\tempa\tempfile2.sav'.

get file= 'H:\evrim\AHTUS\2006\tempa\tempfile2.sav'.

*******
*inout*
*******.

compute inout=-5. 
freq inout.

Do if where~=18 and where~=19 and (where=9 or where=17 or actcode=20401 
    or actcode=20402 or actcode=20499 or actcode=20501 or actcode=20502 or 
    actcode=20599 or actcode=70102 or actcode=40502 or actcode=40105 or 
    actcode=130102 or actcode=130104 or actcode=130106 or actcode=130108 or 
    actcode=130110 or actcode=130112 or actcode=130113 or actcode=130114 or 
    actcode=130116 or actcode=130118 or actcode=130121 or actcode=130123 or 
    actcode=130124 or actcode=130126 or actcode=130127 or actcode=130129 or 
    (where=14 and (actcode=30103 or actcode=30105 or actcode= 30112 or 
    actcode=30199 or actcode=40109 or actcode=40401 or actcode=40199 or 
    actcode=500103 or actcode=500104 or (actcode>180100 and actcode<500101)))).
        compute inout=1.
Else if where<12 or (where>29 and where<89). 
        compute inout=2.
Else if where=12 or where=13 or where=15 or where=16 or where=18 or where=19 or
    where=20 or where=21 or where=99 or (actcode=30103 or actcode=40507 or 
    actcode=110203 or actcode=150202 or (actcode>180100 and actcode<500101) or
    actcode=30112 or actcode=30503 or actcode=40112).
        compute inout=3.
Else if actcode=20101 or actcode=20301 or actcode=20399 or actcode=20104 or actcode=150302 
    or actcode<20000 or actcode=130219 or actcode=130215 or actcode=130207 or actcode=130205 
    or actcode=130119 or actcode=130115 or actcode=130107 or actcode=130105.
        compute inout=2.
Else if where=14.
        compute inout=1.
Else.
        compute inout=-8.
End if.
freq inout.
cro tewhere where by inout.

temp.
select if inout<0.
freq actcode where tewhere.
If inout<0 and actcode=100103 inout=2.

temp.
select if inout=3 and tewhere=14.
freq pid.
*The case where the respondent was recorded as walking in a vehicle was examined (pid=20060302061329).
*The resp. was picking up/drop off a child while walking. Code it as not walking.


temp.
select if inout=1.
freq actcode tewhere.

temp.
select if inout=2.
freq actcode tewhere.

temp.
select if inout=3.
freq actcode tewhere.

******
*eloc*
******.

Do if where=1. 
   compute eloc=1.
Else if where=3.
   compute eloc=2.
Else if where=2.
   compute eloc=3.
Else if where=8.
   compute eloc=4.
Else if where=6 or where=7 or where=10 or where=30 or 
   where=31 or where=32.
   compute eloc=5.
Else if where=4.
   compute eloc=6.
Else if where=5.
   compute eloc=7.
Else if (where>11 and where<22) or (actcode>179999 and actcode<=189999).
   compute eloc=8.
Else if where=9 or where=11.
   compute eloc=9.
Else.
   compute eloc=-8.
End if.
freq eloc.


cro where by eloc.
cro eloc by inout.

temp.
select if eloc=8 and inout=2.
freq actcode where.
*39 of those cases are coded as walking though actcode is not walking, code them as outside.
*The rest is travelling, so code them as inout=3.
If eloc=8 and inout=2 and where=14 inout=1.
If eloc=8 and inout=2 and where=11 inout=3.

temp.
select if eloc=-8.
freq actcode.

*******
*mtrav*
*******.

Do if where=12 or where=13 or where=19.
   compute mtrav=1.
Else if where=15 or where=16 or where=18 or where=20.
   compute mtrav=2.
Else if where=14 or actcode=130131.
   compute mtrav=3.
Else if where=17 or actcode=130104.
   compute mtrav=4.
Else if where=21 or inout=3 or eloc=8.
   compute mtrav=5.
Else.
   compute mtrav=-7.
End if.
freq mtrav.
cro eloc by mtrav.
cro tewhere by mtrav.
cro mtrav by inout.

***************************
*mtrav and inout checklist*
***************************.

* (1) most cases of mtrav=3(walk) should be inout=1(outside).
* (2) mtrav=3(walking) should never be inout=3 (in vehicle).
* (3) all mtrav=1(in car) should be inout=3(in vehicle).
* (4) vast majority of cycling must be inout=1(outside).
* (5) mtrav=5(travel by unknown means) should be inout=3(in a vehicle, almost all of it will be 
in a vehicle).

temp.
select if mtrav=3 or mtrav=4.
freq actcode.

temp.
select if mtrav=5.
freq actcode.

**corect inconsistencies**.

*In 1 case mtrav=1 (car) but inout=1 (outside) instead of inout=3.
temp.
select if mtrav=1 and inout=1.
freq actcode.
*lawn, garden care. Could be on a gardening vehicle and outside.
*Code inout=3.

if mtrav=1 and inout=1 and actcode=20501 inout=3.

*if mtrav=1 and inout=1 and actcode=130104 mtrav=4.
*if mtrav=1 and inout=1 and (actcode=130106 or actcode=130129) inout=3. 

temp.
select if mtrav=3 and inout=3.
freq actcode.

If mtrav=3 and inout=3 and (actcode=130131 or actcode=40112) inout=1.

if mtrav=5 and inout=1 inout=3.
cro mtrav by inout.

cro eloc by mtrav.

temp.
select if mtrav= -7 and eloc=9 and (actcode>179999 and actcode<=189999).
freq actcode tewhere.
*If everything is fine this gives a warning.

*******
*child*
*******.

Do If child=0 and (actcode=30101 or actcode=30102 or actcode=30103 or actcode=30104 or 
   actcode=30105 or actcode=30106 or actcode=30107 or actcode=30109 or 
   actcode=30112 or actcode=30199 or actcode=30201 or actcode=30203 or 
   actcode=30299 or actcode=30301 or actcode=30302 or actcode=30399 or 
   actcode=40101 or actcode=40102 or actcode=40103 or actcode=40104 or 
   actcode=40105 or actcode=40106 or actcode=40107 or actcode=40109 or 
   actcode=40112 or actcode=40199 or actcode=40201 or actcode=40203 or 
   actcode=40299 or actcode=40301 or actcode=40302 or actcode=40399).
   compute child=1.
End if.
freq child.

********
*animal*
********.

compute animal=0.
If actcode=20601 or actcode=20699 or actcode=80701 or actcode=80702 or
   actcode=90301 or actcode=130110 or actcode=130121 animal=1.
freq animal.

*********
*shoprof*
*********.

Compute shoprof=0.
If actcode=30202 or actcode=80201 or actcode=80202 or actcode=80301 or
   actcode=80401 or actcode=80402 or actcode=80501 or actcode=80601 or
   actcode=80701 or actcode=80801 or actcode=80899 or actcode=90101 or 
   actcode=90103 or actcode=90201 or actcode=90301 or actcode=90401 or
   actcode=90501 or actcode=100101 or actcode=100102 or actcode=10103 or
   actcode=100401 or actcode=100499 or (eloc=6 and (actcode=110101 or
   actcode=110199)) or actcode=110202 or actcode=120401 or actcode=120402
   or actcode=120403 or actcode=120404 or actcode=120405 or actcode=130401
   or actcode=130402 or actcode=130499 or (eloc>2 and (actcode=70101 or
   actcode=70103 or actcode=70104 or actcode=70105 or actcode=90102)) 
   shoprof=1.
freq shoprof.

save outfile="H:\evrim\AHTUS\2006\tempa\tempfile3.sav" /drop test test2.

get file ="H:\evrim\AHTUS\2006\tempa\tempfile3.sav".

******
*main*
******.

*use this if find a problem in activity code before rerunning code.
compute main=-5.
freq main.

Do if actcode=500105 or actcode=10401 or actcode=10499 or actcode=10599
   or actcode=19999.
   Compute main=1.
Else if actcode=10101 or actcode=10102.
   Compute main=3.
Else if actcode=10199.
   Compute main=5.
Else if actcode=10201 or actcode=10299.
   Compute main=6.
Else if actcode=10301 or actcode=10399 or actcode=10501.
   Compute main=7.
Else if actcode=50202.
   Compute main=8.
Else if actcode=110201 or actcode=110203 or actcode=110204 or
   actcode=119999 or (eloc~=6 and (actcode=110101 or actcode=110199
   or actcode=110299)).
   Compute main=9.
Else if tewhere~=1 and (actcode=50101 or actcode=50199 or 
   actcode=50205 or actcode=50299 or actcode=59999). 
   Compute main=10.
Else if tewhere=1 and (actcode=50101 or actcode=50199 or 
   actcode=50299 or actcode=59999). 
   Compute main=11.
Else if actcode=50102 or actcode=50301 or actcode=50302 or actcode=50303
   or actcode=50304 or actcode=50399 or actcode=50305.
   Compute main=12.
Else if actcode=50201 or actcode=50203.
   Compute main=13.
Else if actcode=50103 or actcode=50204 or actcode=50104.
   Compute main=14.
Else if (actcode>50400 and actcode<50406) or actcode=50499 or actcode=180504.
   Compute main=15.
Else if actcode=60101 or actcode=60103 or actcode=60104 or
   actcode=60199.
   Compute main=16.
Else if actcode=60301 or actcode=60302 or actcode=60303 or
   actcode=60399.
   Compute main=17.
Else if actcode=60102 or actcode=60299.
   Compute main=18.
Else if actcode=60201 or actcode=60202 or actcode=60203 or actcode=60204
   or actcode=60401 or actcode=60402 or actcode=60403 or actcode=60499 
   or actcode=69999 or actcode=160103.
   Compute main=19.
Else if actcode=20201 or actcode=20202.
   Compute main=20.
Else if actcode=20203 or actcode=20299.
   Compute main=21.
Else if actcode=20101 or actcode=20301 or actcode=20399 or actcode=20401.
   Compute main=22.
Else if actcode=20102 or actcode=20103.
   Compute main=23.
Else if actcode=20302 or actcode=20303 or actcode=20402 or actcode=20499
   or actcode=20502 or actcode=20701 or actcode=20799 or actcode=20801 or
   actcode=20899.
   Compute main=24.
Else if actcode=20104 or actcode=20199 or actcode=20901 or actcode=20902
   or actcode=20905 or actcode=20999 or actcode=29999.
   Compute main=25.
Else if actcode=70101 or actcode=70103 or actcode=70104 or actcode=70105
   or actcode=90102.
   Compute main=26.
Else if actcode=70102 or actcode=70199 or actcode=70201 or actcode=70299 or 
   actcode=70301 or actcode=70399 or actcode=79999 or actcode=160104.
   Compute main=27.
Else if actcode=80501 or actcode=80502 or actcode=80599 or actcode=160105.
   Compute main=28.
Else if actcode=80401 or actcode=80402 or actcode=80403 or actcode=80499
   or actcode=80701 or actcode=80702 or actcode=80799.
   Compute main=29.
Else if actcode=90101 or actcode=90103 or actcode=90104 or actcode=90199
   or actcode=90201 or actcode=90202 or actcode=90299 or actcode=90301 or
   actcode=90302 or actcode=90399 or actcode=90401 or actcode=90402 or 
   actcode=90499 or actcode=90501 or actcode=90502 or actcode=90599 or
   actcode=99999 or actcode=160106.
   Compute main=30.
Else if actcode=80201 or actcode=80202 or actcode=80203 or actcode=80299
   or actcode=100101 or actcode=100102 or actcode=100103 or actcode=100199
   or actcode=100301 or actcode=100302 or actcode=100399 or actcode=100401
   or actcode=100499 or actcode=109999 or actcode=160108.
   Compute main=31.
Else if actcode=80301 or actcode=80302 or actcode=80399 or actcode=80601
   or actcode=80602 or actcode=80699 or actcode=80801 or actcode=80899 or actcode=89999.
   Compute main=32.
Else if (infant=1) and (actcode=30101 or actcode=30108 or 
   actcode=30109 or actcode=30199 or actcode=80101 or actcode=80102 or
   actcode=80199 or actcode=160107).
   Compute main=33.
Else if (child=1 and (actcode=30101 or actcode=30108 or actcode=30109 or 
   actcode=30199 or actcode=80199)) or actcode=80101 or actcode=80102
    or actcode=160107 or actcode=80199.
    Compute main=34.
Else if actcode=30108.
    compute main=34.
Else if actcode=30301 or actcode=30302 or actcode=30303 or actcode=30399.
   Compute main=35.
Else if actcode=30103.
   Compute main=36.
Else if actcode=30104 or actcode=30107 or actcode=30201 or
   actcode=30202 or actcode=30203 or actcode=30204 or
   actcode=30299.
   Compute main=37.
Else if actcode=30102 or actcode=30106.
   Compute main=38.
Else if actcode=30110 or actcode=30111 or actcode=30112 or 
   actcode=39999.
   Compute main=39.
Else if (actcode>30400 and actcode<30406) or actcode=30499 or
   (actcode>30500 and actcode<30505) or actcode=30599 or (actcode>40100
   and actcode<40105) or (actcode>40105 and actcode<40113) or
   actcode=40199 or (actcode>40200 and actcode<40205) or actcode=40299
   or (actcode>40300 and actcode<40304) or actcode=40399 or (actcode>40400
   and actcode<40406) or actcode=40499 or (actcode>40500 and actcode<40509)
   or actcode=40599 or actcode=49999.
   Compute main=40.
Else if (actcode>150100 and actcode<150107) or actcode=150199 or
   (actcode>150200 and actcode<150205) or actcode=150299 or
   actcode=150301 or actcode=150302 or actcode=150399 or actcode=150401
   or actcode=150402 or actcode=150499 or actcode=150501 or actcode=150599
   or actcode=150601 or actcode=150602 or actcode=150699 or actcode=159999
   or actcode=150701 or actcode=150799.
   Compute main=41.
Else if actcode=100201 or actcode=100299 or actcode=100303.
   Compute main=42.
Else if (actcode>140100 and actcode<140105) or actcode=149999.
   Compute main=49.
Else if actcode=120405 or actcode=120499 or actcode=120504.
   Compute main=50.
Else if (actcode>130200 and actcode<130300) or actcode=130302 or
   actcode=130399 or actcode=130402 or actcode=130499.
   Compute main=51.
Else if actcode=120403.
   Compute main=52.
Else if actcode=120401.
   Compute main=53.
Else if actcode=120402.
   Compute main=54.
Else if actcode=110202 or actcode=110101 or actcode=110199 or 
   actcode=120404 or actcode=110299.
   Compute main=56.
Else if actcode=120201 or actcode=120202 or actcode=120299.
   Compute main=57.
Else if (actcode>130100 and actcode<130104) or actcode=130105 or 
   actcode=130107 or (actcode>130108 and actcode<130112) or 
   (actcode>130112 and actcode<130116) or actcode=130117 or 
   (actcode>130118 and actcode<130131) or (actcode>130131 
   and actcode<130200) or actcode=130301 or actcode=130401 or 
   actcode=139999.
   Compute main=60.
Else if actcode=130131 or (actcode>500000 and tewhere=14).
   Compute main=62.
Else if actcode=130104.
   Compute main=63.
Else if actcode=130108.
   Compute main=64.
Else if actcode=30105 or actcode=40105.
   Compute main=65.
Else if actcode=130106 or actcode=130112 or actcode=130116 or actcode=130118.
   Compute main=66.
Else if actcode=20501 or actcode=20599.
   Compute main=67.
Else if actcode=20601 or actcode=20699.
   Compute main=68.
Else if actcode=120101 or actcode=120199.
   Compute main=72.
Else if actcode=120307 or actcode=129999.
   Compute main=73.
Else if actcode=120313.
   Compute main=75.
Else if actcode=120309.
   Compute main=76.
Else if actcode=120310 or actcode=120311.
   Compute main=77.
Else if actcode=120301 or actcode=120302 or actcode=120399 or
   actcode=120501 or actcode=120502 or actcode=120503 or 
   actcode=120599.
   Compute main=78.
Else if actcode=120312.
   Compute main=81.
Else if actcode=120306.
   Compute main=84.
Else if actcode=120305.
   Compute main=85.
Else if actcode=120303 or actcode=120304.
   Compute main=86.
Else if actcode=20903.
   Compute main=87.
Else if actcode=160101 or actcode=160102 or actcode=169999 or
   actcode=160199 or actcode=160201 or actcode=160299.
   Compute main=88.
Else if actcode=20904 or actcode=120308.
   Compute main=89.
Else if actcode=500103.
   Compute main=90.
Else if actcode=180101 or actcode=180199 or (actcode>181100 and actcode< 181200) 
   or actcode=180302 or actcode=180304 or actcode=180305 or (actcode>180400 and actcode<180500).
   Compute main=91.
Else if actcode=180502.
   Compute main=92.
Else if actcode=180501 or actcode=180599 or actcode=180503.
   Compute main=93.
Else if actcode=180601 or actcode=180602 or actcode=180699
   or actcode=180603 or actcode=180604.
   Compute main=94.
Else if (actcode>180200 and actcode<180300) or (actcode>180700 and actcode<180800)
   or (actcode>180800 and actcode<180900) or (actcode>180900 and actcode<181002)
   or (actcode>181002 and actcode<181100).
   Compute main=95.
Else if actcode=180301 or actcode=180303 or actcode=180399.
   Compute main=96.
Else if (actcode>181400 and actcode<181500) or actcode=181002 or 
   (actcode>181500 and actcode<181600).
   Compute main=97.
Else if actcode=189999 or (actcode>181200 and actcode<181400) or 
   (actcode>181600 and actcode<181700) or (actcode>181800 and actcode<181900).
   Compute main=98.
Else if actcode=500101 or actcode=500102 or actcode=500104 or 
   actcode=500106 or actcode=500107 or actcode=509999.
   Compute main=-8.
end if.
freq main.

*any -5 codes will be cases of new codes that were not assigned to
*a location.
temp.
select if main=-5.
freq actcode.
*if all ok, this will produce a warning that there are no such cases.

temp.
select if main<15.
cro actcode by main.

temp.
select if main>14 and main<20.
cro actcode by main.

temp.
select if main>19 and main<28.
cro actcode by main.

temp.
select if main>27 and main<35.
cro actcode by main.

temp.
select if main>34 and main<42.
cro actcode by main.

temp.
select if main>41 and main<56.
cro actcode by main.

temp.
select if main>55 and main<62.
cro actcode by main.

temp.
select if main>61 and main<70.
cro actcode by main.

temp.
select if main>69 and main<76.
cro actcode by main.

temp.
select if main>75 and main<84.
cro actcode by main.

temp.
select if main>83 and main<91.
cro actcode by main.

temp.
select if main>90.
cro actcode by main.

************************************
*set up variable for quality checks*
************************************.

vector dqcheck(3).
Loop i=1 to 3.
   compute dqcheck(i)=0.
end loop.
var lab dqcheck1 "miss main, mode of transport or in restaurant".
var lab dqcheck2 "miss main, 2nd act reported".
var lab dqcheck3 "miss 20 min before/after travel".
val lab dqcheck1 to dqcheck3
   0 ordinary diary
   1 includes pattern.
freq dqcheck1 to dqcheck3.

temp.
select if main=-8.
freq eloc.

Do If main=-8 and eloc=8.
   compute main=90.
   compute dqcheck1=1.
Else if main=-8 and eloc=6.
   compute main=56.
   compute dqcheck1=1.
End if.

*fill in what secondary activity is possible to identify.
If trtcc_ln>0 or trtcocln>0 sec=34.
If main<90 and eloc=8 sec=90.
freq sec.

*If the main activity is missing and the location is 
*valid and not at home or another home and the 
*previous location is valid, not travelling, and 
*different from the present location, the main 
*activity is coded to impute travel
*
*if the main activity is valid and not travel and
*both the current and previous locations are valid 
*and the previous location is not travelling and the 
*current and previous location differ, the secondary 
*activity is coded as imputed travel
*
*if the main activity is missing and the location is
*at home or another home and the previous location is
*travel, main activity is coded as unknown personal
*or household care
*
*if the main activity is missing and the previous location
*is travel and the present location is valid but not at
*a home, the main activity is coded as imputed out of
*home activity.

Do if pid=lag(pid).
   Do if main<0 and ((eloc=1 or eloc=2) and lag(eloc)=8).
      compute main=2.
      compute dqcheck3=1. 
   Else if main<0 and ((eloc>2 and eloc<8) or eloc=9) and lag(eloc)=8.
      compute main=58.
   Else if main<0 and ((eloc>0 and eloc~=8 and lag(eloc)>0
      and lag(eloc)~=8) and eloc~=lag(eloc)).
      compute main=90.
      compute dqcheck1=1. 
   Else if (main>0 and main<90) and sec=0 and ( ((eloc>1 and 
      eloc<6) or eloc=7) and ((lag(eloc)>1 and lag(eloc)<6) or
      lag(eloc)=7)) and eloc~=lag(eloc).
      compute sec=90.
   End if.
End if.
freq sec.

temp.
select if main=-8 or main=2 or main=58 or main=90.
freq main.

*if main activity still missing and the location is
*valid and not at home, code the main activity as
*imputed activity away from home.

If main<0 and eloc>2 main=58.

temp.
select if main=-8 or main=58.
freq main.

temp.
select if main=-8.
freq actcode.

*47 of the missing activities are coded as unrecorded as 
*simultaneous activities recorded. investigate where these.

temp.
select if main=-8 and actcode=500104.
freq eloc sec clockst alone child sppart hhadult.
*most such cases take place at home or another person's home;
*1/3 of cases overlap a child being in the person's care;
*cases spread throughout the day. 

*check two of the three bad diary tests for these cases,
*calculating missing time as not including this simultaneous
*activity code.
compute misstest=0.
if main=-8 and actcode~=500104 misstest=time.

AGGREGATE
  /OUTFILE*
  mode=addvariables
  /BREAK=pid
  /summiss=sum(misstest)
  /totep=NU(epnum).

temp.
select if main=-8 and actcode=500104.
freq totep summiss.

*these diaries have 9 or more activities, and 39 of them
*have no or an acceptable amount of missing time. Recode this 
*activity as imputed personal or household care.

if summiss<=90 and main=-8 and actcode=500104 main=2.

*now see if any of the remaining missing cases happen at the end of the diary day.
compute test=0.
if lastep=1 and main=-8 and lag(main)>0 test=1.

temp.
select if test=1.
freq time eloc actcode.
*there are 7 such cases at home.

compute test2=0.
if test=1 test2=lag(main).
freq test2.
*4 sleep, 1 other meals, 1 other dom work, 1 watch TV.

If test=1 main=4.

temp.
select if main=-8 or main=2 or main=4 or main=58 or main=90.
freq main.

*now look at cases where the first activity is missing.
compute test=0.
If epnum=1 and main=-8 test=1.
freq test.

temp.
select if test=1.
freq time eloc.

*3 such cases, all at home.
compute test2=0.
if lag(test)=1 test2=main.
freq test2.

cro test2 by eloc.

*2 asleep, 1 food prep, 1 travel.

if test=1 and test2<90 main=4.
if time<91 and (test=1 and test2>89) main=2.

temp.
select if main=-8 or main=2 or main=4 or main=58.
freq main.

*look at cases that remain missing that happen after sleep.
compute test=0.
if pid=lag(pid) and main=-8 and (lag(main)=3 or lag(main)=4) test=1.

temp.
select if test=1.
freq eloc time.

*104 such cases (102 at own home); those less than an hour 
*coded as imputed personal or household care.

If time<61 and test=1 main=2.

temp.
select if main=-8 or main=2.
freq main.

compute test=0.
if main=-8 and (lag(main)=9 or lag(main)=20 
   or lag(main)=21) test=1.

temp.
select if test=1.
freq time eloc.

*275 cases where the time gap in a diary follows eating
*or food preparation of setting table/putting away 
*dishes; all at home or another's home. 66% an hour or less, 
*some gaps very long. Set gaps of an hour or less to 
*imputed personal or household care.

If test=1 and (eloc=1 or eloc=2) and time<61 main=2.

temp.
select if main=-8 or main=2.
freq main.

temp.
select if actcode>500000.
freq main.

*at this point, 1164 of the 2337 cases coded with missing codes
*in the original data are still coded as missing - 50 now general
*personal care; 498 imputed personal or household care, 10 imputed 
*sleep; 19 restaurant; 334 imputed time away from home; 30 walking; 
*232 imputed travel; 30 walking.

temp.
select if main=-8.
freq time eloc.

*remaining gaps range from 1 minute to 11.5 hours. Majority 
*are (60%) an hour or less. No further effort made to fill in gaps
*using other diary information.

If (main>89 or sec>89) and mtrav=-7 mtrav=5. 
freq mtrav.

*impute eating where no main activity eating but
*main activity food preparation or setting table reported.

compute eatdr=0.
If main=8 or main=9 or main=56 eatdr=time. 

*check for missing eating time but recorded set table or food prep.
AGGREGATE
  /OUTFILE=*
  mode=addvariables
  /BREAK=pid
  /anyeat = SUM(eatdr).
freq anyeat.
*at the moment, 2.9% no eating.

temp.
select if anyeat=0.
freq maxep main.
*some really low episode diaries with missing eating.
*There are some diaries with food preparation activities 
*but no eating.

Do if anyeat=0 and (main=20 or main=21) and sec=0 and maxep>9.
   compute sec=2.
End if.
freq sec.

sort cases by pid epnum.
save outfile ='H:\evrim\AHTUS\2006\tempa\tempfile4.sav'.


***********************************************
****** THE EATING AND HEALTH MODULE FILE ******
***********************************************.

get file='H:\evrim\AHTUS\2006\EH\ehresp_2006.sav'.
freq eudrink eueat.

compute tempid=0.
If eudrink=1 or eueat=1 tempid=1.
cro tempid by eudrink eueat.

select if tempid=1.
sort cases by tucaseid tulineno.
save outfile= "H:\evrim\AHTUS\2006\tempa\ehid.sav"
/keep tucaseid tulineno tempid.

get file='H:\evrim\AHTUS\2006\EH\ehact_2006.sav'.
recode euedur24 euddur24 (low thru 0=0) (else=copy).
desc euedur24 euddur24.
sort cases by tucaseid tuact_n.

match files files=* 
      files='H:\evrim\AHTUS\2006\atusact_2006.sav'
   /BY tucaseid tuact_n.
execute. 

match files files=*
      table='H:\evrim\AHTUS\2006\tempa\ehid.sav'/in=ineh
   /BY tucaseid.
execute. 

*this leaves diarists who reported secondary e&d.
select if ineh=1.
execute.

compute temped= euedur24 + euddur24.
freq temped.

temp.
select if temped>tuadur24.
cro tuadur24 by temped.
*1300 cases.

temp.
select if euddur24>tuadur24.
cro euddur24 by temped.

cro tucc5 by tucc7.
compute totcc=0.
If TUCC5=1 or TUCC5B=1 or TUCC8=1 or TUCC7=1 totcc=tuadur24.

compute test1=0.
If totcc>0 and temped>0 test1=1.
freq test1.

compute test2=0.
If totcc>0 and euddur24>0 test2=1.
freq test2.

compute test3=0.
If totcc>0 and euedur24>0 test3=1.
freq test3.

rename variables (tucaseid tuact_n =pid epnum).
sort cases by pid epnum.
save outfile= "H:\evrim\AHTUS\2006\tempa\ehact06.sav".

*******************************************
*PROCESS THE EATING AND HEALTH MODULE FILE*
*******************************************.

get file ='H:\evrim\AHTUS\2006\tempa\tempfile4.sav'.
sort cases by pid epnum.
match files file=* 
   table="H:\evrim\AHTUS\2006\tempa\ehact06.sav"
   /by pid epnum.
execute.

desc temped EUEDUR24 EUDDUR24.

temp.
select if temped>1440.
freq pid.

compute temp3=0.
If euddur24>0 and euedur24>0 temp3=1.
freq temp3.

freq sec.
*for our purposes, here sysmiss means 
*no time reported in this act by this diarist.
recode euedur24 euddur24 (sysmis=0) (else=copy).
execute.

***NEW CODE STARTS HERE*
************************.

compute test=0.
Do if sec=0 and (EUEDUR24>0 or EUDDUR24>0).
   compute test=1.
Else if sec=34 and (EUEDUR24>0 or EUDDUR24>0).
   compute test=3.
Else if sec>0 and (EUEDUR24>0 or EUDDUR24>0).
   compute test=5.
Else if sec=34 and EUEDUR24=0 and EUDDUR24=0.
   compute test=2.
Else if sec>0 and EUEDUR24=0 and EUDDUR24=0.
   compute test=4.
End if.
val lab test
   0 'no secondary activity'
   1 'only secondary eating/drinking'
   2 'secondary care only'
   3 'secondary care and eating/drinking'
   4 'other CTUR secondary code only'
   5 'other CTUR secondary code and eating/drinking'.
freq test.

*78.2% cases have no sec activity.
*15.5% have only sec ccare.
*4.7% have only sec eating/drinking.
*803 have other CTUR sec code and 71 have both other CTUR sec and eat/drink. 
*3241 sec ccare and eating.
cro test by sec.

*of the cases where CTUR has imputed a code, 30 have imputed secondary
*eating and reported secondary eating - in these cases we will remove
*the CTUR imputed eating and replace it with the secondary eating
*reported by the participant. In 41 cases, we have imputed travel. Check
*these cases at a future point in the code.

compute seatdr=-5.
Do if euddur24=0 and euedur24=0.
 compute seatdr=0.
Else if euddur24>0 and euedur24=0.
 compute seatdr=1.
Else if euddur24=0 and euedur24>0.
 compute seatdr=2.
Else if euddur24>0 and euedur24>0.
 compute seatdr=3.
End if.
val lab seatdr
 0 'neither sec eat nor sec drinking'
 1 'only sec drinking'
 2 'only sec eating'
 3 'both sec eating and sec drinking'.
freq seatdr.
cro euedur24 by seatdr.
cro euddur24 by seatdr.
cro test by seatdr.

*reset variable names for final AHTUS variables - these variables will be
*reconstructed to include the secondary eating and drinking.
rename variables (start end main sec inout eloc mtrav alone infant child sppart 
     clsfam hhadult cowork wellknw otherp unknwp animal shoprof = ostart oend omain 
     osec oinout oeloc omtrav oalone oinfant ochild osppart oclsfam ohhadult ocowork 
     owellknw ootherp ounknwp oanimal oshoprof).

*as some secondary eating and drinking does not equal the total time of the episode,
*we will put this time in the middle of the episode.

vector start(3) end(3) main(3) sec(3) inout(3) eloc(3) mtrav(3) alone(3) infant(3) 
       child(3) sppart(3) clsfam(3) hhadult(3) cowork(3) wellknw(3) otherp(3) unknwp(3)
       animal(3) shoprof(3).
do repeat a=start1 to shoprof3.
   compute a=-5.
end repeat.
execute.

*set current episode to the first in the set of three in the new episode data range.
*nothing will change where there is no secondary eating/drinking or the secondary
*eating/drinking is the only secondary activity and has the same duration of the 
*main activity episode.

compute start1=ostart.
compute end1=oend.
compute main1=omain.
compute sec1=osec.
compute inout1=oinout.
compute eloc1=oeloc.
compute mtrav1=omtrav.
compute alone1=oalone.
compute infant1=oinfant.
compute child1=ochild.
compute sppart1=osppart.
compute clsfam1=oclsfam.
compute hhadult1=ohhadult.
compute cowork1=ocowork.
compute wellknw1=owellknw.
compute otherp1=ootherp.
compute unknwp1=ounknwp.
compute animal1=oanimal.
compute shoprof1=oshoprof.
execute.

*****
**A**
*****.
*check cases where main is missing but there is eat/drink only*
***************************************************************.
temp.
select if omain=-8 and osec=0.
freq seatdr.

*39 cases where main is missing but seceatdr>0.
   *17 cases with drinking only
   *13 cases eating only
   *9 both eat and drink.

temp.
select if omain=-8 and osec=0 and seatdr>0.
freq oalone oinfant ochild osppart ohhadult ocowork owellknw 
     ootherp time oeloc prevact nextact.

*Missing time varies between 5 min to 480.
*All the missings are at home.
*Most of previous  next act is personal care or travel.

*If previous or next act is in home social code missing main
*as main=71(imputed in home social), and sec=9 eating.
Do if omain=-8 and osec=0 and seatdr>0 and (oeloc=1 or oeloc=2) and 
((prevact>119999 and prevact<130000) or (nextact>119999 and nextact<130000)).
   compute main1=71.
   compute sec1=9.
End if.
execute.

temp.
select if omain=-8 and osec=0 and seatdr>0.
freq time oeloc oalone oinfant ochild osppart oclsfam 
     ohhadult ocowork owellknw ootherp prevact nextact.
*16 cases are now imputed in home social. Still 23 left missin.
*All the cases are at home. Mostly preceeded/ followed by personal care.

freq sec1.
*Code the remaining 23 cases as imputed personal or hhold care.
Do if omain=-8 and osec=0 and seatdr>0 and (oeloc=1 or oeloc=2).
   compute main1=2.
   compute sec1=9.
end if.
freq sec1.
*this makes 39 cases of secondary eating.

*****
**B**
*****.
*Deal with cases with only secondary eating/drinking*
*including addressing replacing imputed eating with *
*actually reported secondary eating                 *
*****************************************************.
*There are 12454 episodes with only reported secondary eating/drinking.
freq test seatdr.
cro test by seatdr.

compute sectemp=0.
Do if seatdr=1.
  compute sectemp=euddur24.
Else if seatdr=2.
  compute sectemp=euedur24.
Else if seatdr=3.
  compute sectemp=euedur24 + euddur24.
End if.
*note that where the sum of eating and drinking time is larger 
*than the epsiode time, we will not exceed the total episode time.

temp.
select if sectemp>time.
freq pid.
*1300 cases where sectemp>time. This creates problems later - reset sectemp
to be no more than ther duration of the episode.
if sectemp>time sectemp=time.
var lab sectemp 'secondary eating or drinking'.
cro sectemp by seatdr.

var lab sectemp 'secondary eating or drinking'.
cro sectemp by seatdr.

temp.
select if test=1 and sectemp<time.
freq omain.
*In 7749 cases minutes in secondary eating/drinking (sectemp) are 
*less than the total time of the episode. In such cases, we will
*divide the episode into three segments and put the secondary eat/drink 
*time in the middle of the episode. If the minutes left after deducting
*sec eat/drink time is not even number, we will make 5 minute rounding 
*and put the longer episode at the beginning. 
*Otherwise we will truncate on an even 5 minutes.

*Deal with cases of secondary eating and drinking only where the secondary
*episode time is the same or greater than the main activity time.

Do if (test=1 or (test=5 and osec=2)) and sectemp ge time.
   compute sec1=9.
End if.
freq sec1.
*now 4742 cases of secondary eating.

*now deal with cases where the reported secondary eating / drinking time
*is less than the epsiode time.

compute remain=0.
*create a value in remain only for cases where sectemp<time.

*These are cases of secondary eating and drinking only where the secondary
*episode time use less than the main activity time.

Do if (test=1 or (test>2 and osec=2)) and sectemp<time.
   compute remain=time-sectemp.
End if.
*subtract the sec eating time from the total episode to find remaining minutes.
freq remain.

Do if (test=1 or (test>2 and osec=2)) and sectemp<time.
   compute r1=rnd(remain/2).
   compute r2=trunc(remain/2).
End if.
freq r1 r2.

temp.
select if r1=r2.
freq time sectemp.
*4049 cases where these numbers are identical,

temp.
select if r1~=r2.
freq time sectemp.
*3817 cases where these values are not equal.
*the cases where the values are the same produce some
*instances where episodes with no time (0 minutes) - 
*these addressed later in this code.

*now fill in the three new episodes with this information.
Do if test=1 and sectemp<time.
   compute start2=start1+r1.
   compute end1=end1-r2-sectemp.
   compute start3=start2+sectemp.
End if.
execute.
*visually check that this produces the desired result.

temp.
select if start2>-5 and end1~=start2.
freq pid.
*ok so far - end1=start2, no cases of deviation.

*also check that start1 not = start2.
compute check=0.
if start1=start2 check=1.
freq check.
*as long as check=0, there will be no 0 time episodes.

*add in secondary eating in the middle.
*as main adjusted, copy over main1 values, but other codes not 
*changed, hence new episodes retain original reported values.
Do if test=1 and sectemp<time.
   compute end2=end1+sectemp.
   compute end3=end1+sectemp+r2.
   compute main2=main1.
   compute main3=main1.
   compute sec2=9.
   compute sec3=osec.
   compute inout2=oinout.
   compute inout3=oinout.
   compute eloc2=oeloc.
   compute eloc3=oeloc.
   compute mtrav2=omtrav.
   compute mtrav3=omtrav.
   compute alone2=oalone.
   compute alone3=oalone.
   compute infant2=oinfant.
   compute infant3=oinfant.
   compute child2=ochild.
   compute child3=ochild.
   compute sppart2=osppart.
   compute sppart3=osppart.
   compute clsfam2=oclsfam.
   compute clsfam3=oclsfam.
   compute hhadult2=ohhadult.
   compute hhadult3=ohhadult.
   compute cowork2=ocowork.
   compute cowork3=ocowork.
   compute wellknw2=owellknw.
   compute wellknw3=owellknw.
   compute otherp2=ootherp.
   compute otherp3=ootherp.
   compute unknwp2=ounknwp.
   compute unknwp3=ounknwp.
   compute animal2=oanimal.
   compute animal3=oanimal.
   compute shoprof2=oshoprof.
   compute shoprof3=oshoprof.
End if.
execute.
*visually check some cases - these look ok. Check that sec2 now has some 9 cases, but sec3 remains all 0 or -5.
*should still be 4742 cases of secondary eating in sec1, and same number of cases with 9 in sec2 as with 0 in sec3.
freq sec1 sec2 sec3.

*end3 should = oend.
temp.
select if end3>-5 and end3~=oend.
freq pid.
*ok so far - end3=oend, no cases of deviation.

*check for 0 time episodes, start1 should not = start2, and start2 should not = start3.
compute check=0.
if start1=start2 check=1.
if start2=start3 and start2>-5 check=1.
freq check.
*as long as check=0, there will be no 0 time episodes.
*still all ok.

*****
**C**
*****.
*Deal with 41 cases with secondary eating/drinking  *
*and imputed travel                                 *
*****************************************************.

temp.
select if test=5 and osec=90.
cro sectemp by remain.

temp.
select if test=5 and osec=90.
freq pid.

*for users who wish to find these cases, they are:
*pid - person identifier   - 1 episode					
*20060111052254, 20060201061483, 20060201062171, 20060302062251,
*20060403061330, 20060504060094, 20060504060117, 20060504062201,
*20060504062356, 20060504062504, 20060505061366, 20060604061367,
*20060604061604, 20060604061876, 20060605060698, 20060606061127,
*20060705060647, 20060706060827, 20060706061971, 20060706062017,
*20060707060507, 20060807061379, 20060807061852, 20060807062047,
*20060908060909, 20061008061805, 20061009061369, 20061009061748, 
*20061009062317, 20061109061856, 20061211061130, 20061211061446,
*20061211061928	
*these four cases have 2 such episodes
*20060201062490, 20060605061288, 20060707061052, 20061211062272.

*in all these 41 cases, the reported secondary eating and drinking is 
*the same or more than the total episode time. In 12 cases, the time
*slot is <20 minutes (in one case only 3 minutes); all other cases are
*20-364 minutes. For the 12 shorter episodes, make secondary travel
*2 minutes; if other cases, make secondary travel 10 minutes.

Do if test=5 and osec=90 and sectemp<20.
   compute start2=oend-2.
   compute end1=oend-2.
   compute end2=oend.
   compute main2=main1.
   compute sec1=9.
   compute sec2=osec.
   compute inout2=oinout.
   compute eloc2=oeloc.
   compute mtrav2=omtrav.
   compute alone2=oalone.
   compute infant2=oinfant.
   compute child2=ochild.
   compute sppart2=osppart.
   compute clsfam2=oclsfam.
   compute hhadult2=ohhadult.
   compute cowork2=ocowork.
   compute wellknw2=owellknw.
   compute otherp2=ootherp.
   compute unknwp2=ounknwp.
   compute animal2=oanimal.
   compute shoprof2=oshoprof.
Else if test=5 and osec=90.
   compute start2=oend-10.
   compute end1=end1-10.
   compute end2=oend.
   compute main2=main1.
   compute sec1=9.
   compute sec2=osec.
   compute inout2=oinout.
   compute eloc2=oeloc.
   compute mtrav2=omtrav.
   compute alone2=oalone.
   compute infant2=oinfant.
   compute child2=ochild.
   compute sppart2=osppart.
   compute clsfam2=oclsfam.
   compute hhadult2=ohhadult.
   compute cowork2=ocowork.
   compute wellknw2=owellknw.
   compute otherp2=ootherp.
   compute unknwp2=ounknwp.
   compute animal2=oanimal.
   compute shoprof2=oshoprof.
End if.
execute.
*visually check some cases - these look ok. Check that sec2 now has 41 90 cases, 
*but sec3 remains all 0 or -5.
freq sec1 sec2 sec3.
*now 4783 cases of secondary eating (code 9) in sec1. 

*****
**D**
*****.
*Deal with cases with secondary eating/drinking and *
*child being in your care                           *
*****************************************************.

temp.
select if test=3 and osec=34.
cro sectemp by remain.

temp.
select if test=3 and osec=34.
freq pid.

*for users who wish to find these cases, they are:
*pid - person identifier   - 1 episode					
*20060101060848 20060101060857 20060101060914 20060101061082 20060101061174 20060101061220	
*20060101061394 20060101061406 20060101061597 20060101061783 20060101061821 20060101061834
*20060101061883 20060101062027 20060101062116 20060101062118 20060101062180 20060101062324 
*20060101062366 20060101062547 20060110051545 20060111050629 20060111050695 20060111050706
*20060111050749 20060111050791 20060111050817 20060111050958 20060111050989 20060111051077 
*20060111051078 20060111051189 20060111051206 20060111051236 20060111051383 20060111051683
*20060111051706 20060111051716 20060111051739 20060111051760 20060111051795 20060111051877 
*20060111051933 20060111052104 20060111052140 20060111052253 20060111052261 20060111052265
*20060111052271 20060111052285 20060111052309 20060111052320 20060111052473 20060111052517 
*20060112050066 20060112050097 20060112050110 20060112050517 20060112050532 20060112050644
*20060112050661 20060112050701 20060112050715 20060112050731 20060112050809 20060112050819 
*20060112050831 20060112050844 20060112050923 20060112050928 20060112050969 20060112051066
*20060112051092 20060112051096 20060112051138 20060112051181 20060112051210 20060112051315 
*20060112051321 20060112051332 20060112051341 20060112051351 20060112051362 20060112051395
*20060112051397 20060112051406 20060112051411 20060112051452 20060112051453 20060112051535 
*20060112051537 20060112051549 20060112051596 20060112051636 20060112051664 20060112051673
*20060112051745 20060112051767 20060112051770 20060112051778 20060112051793 20060112051797 
*20060112051807 20060112051931 20060112051936 20060112051967 20060112051995 20060112052013
*20060112052033 20060112052047 20060112052055 20060112052194 20060112052198 20060112052238
*20060112052352 20060112052374 20060112052378 20060112052405 20060112052417 20060112052431
*20060112052471 20060112052477 20060112052489 20060112052539 20060201060707 20060201060755
*20060201060773 20060201060784 20060201060787 20060201060845 20060201060856 20060201060942
*20060201060963 20060201060997 20060201061023 20060201061044 20060201061051 20060201061061
*20060201061062 20060201061073 20060201061166 20060201061218 20060201061225 20060201061264
*20060201061268 20060201061331 20060201061347 20060201061374 20060201061407 20060201061437
*20060201061448 20060201061540 20060201061580 20060201061607 20060201061664 20060201061699
*20060201061700 20060201061738 20060201061741 20060201061760 20060201061795 20060201061846
*20060201061853 20060201061894 20060201061896 20060201061912 20060201061913 20060201061923
*20060201061980 20060201062063 20060201062096 20060201062136 20060201062171 20060201062373
*20060201062380 20060201062405 20060201062438 20060201062446 20060201062455 20060201062553
*20060202060050 20060202060605 20060202060776 20060202061401 20060202062102 20060202062380
*20060212051030 20060212051376 20060212052282 20060301060562 20060301060647 20060301060658
*20060301060726 20060301060827 20060301060992 20060301061068 20060301061507 20060301061521
*20060301061775 20060301062012 20060301062223 20060301062256 20060301062310 20060302060017 
*20060302060044 20060302060068 20060302060098 20060302060101 20060302060538 20060302060594
*20060302060611 20060302060633 20060302060669 20060302060706 20060302060715 20060302060716
*20060302060746 20060302060765 20060302060798 20060302060831 20060302060850 20060302060894
*20060302060964 20060302060988 20060302061027 20060302061123 20060302061133 20060302061134
*20060302061211 20060302061294 20060302061326 20060302061327 20060302061335 20060302061359
*20060302061370 20060302061430 20060302061435 20060302061474 20060302061479 20060302061485
*20060302061515 20060302061517 20060302061522 20060302061597 20060302061611 20060302061662
*20060302061697 20060302061723 20060302061744 20060302061751 20060302061786 20060302061836
*20060302061869 20060302061880 20060302061905 20060302061916 20060302061919 20060302061942
*20060302061958 20060302062123 20060302062151 20060302062199 20060302062201 20060302062239 
*20060302062241 20060302062276 20060302062297 20060302062338 20060302062371 20060302062426
*20060302062485 20060302062512 20060303061285 20060303061489 20060303062277 20060303062319
*20060312051049 20060312051381 20060312052216 20060402060545 20060402060729 20060402061113
*20060402061138 20060402061411 20060402061530 20060402061547 20060402061558 20060402061594
*20060402061755 20060402061775 20060402061931 20060402061982 20060402062079 20060402062101
*20060402062277 20060402062464 20060403060526 20060403060564 20060403060565 20060403060598
*20060403060619 20060403060646 20060403060648 20060403060659 20060403060677 20060403060714
*20060403060763 20060403060775 20060403060777 20060403060827 20060403060841 20060403060893
*20060403060897 20060403060917 20060403060969 20060403061011 20060403061037 20060403061038
*20060403061079 20060403061208 20060403061229 20060403061267 20060403061268 20060403061302
*20060403061320 20060403061370 20060403061412 20060403061416 20060403061444 20060403061453
*20060403061455 20060403061599 20060403061617 20060403061629 20060403061630 20060403061649
*20060403061701 20060403061738 20060403061750 20060403061753 20060403061863 20060403061870
*20060403061900 20060403061939 20060403061949 20060403061963 20060403061968 20060403061998
*20060403062022 20060403062136 20060403062144 20060403062156 20060403062281 20060403062289
*20060403062325 20060403062331 20060403062370 20060403062380 20060403062416 20060403062418
*20060403062434 20060403062435 20060403062445 20060403062451 20060403062460 20060403062464
*20060403062537 20060404060089 20060404060127 20060404060512 20060404060760 20060404061035
*20060404061054 20060404061123 20060404061230 20060404061378 20060404061536 20060404061617
*20060404061713 20060404061748 20060404061753 20060404061789 20060404061884 20060404062090
*20060404062195 20060404062264 20060404062387 20060404062461 20060404062462 20060404062520
*20060502061060 20060502062497 20060503060847 20060503061014 20060503061519 20060503061710
*20060503061898 20060503062193 20060503062301 20060503062389 20060503062510 20060504060101
*20060504060507 20060504060532 20060504060569 20060504060580 20060504060776 20060504060796
*20060504060817 20060504060827 20060504060849 20060504060886 20060504060922 20060504060934
*20060504060952 20060504060976 20060504060983 20060504060985 20060504061169 20060504061200
*20060504061203 20060504061211 20060504061240 20060504061254 20060504061263 20060504061269
*20060504061285 20060504061350 20060504061364 20060504061388 20060504061407 20060504061441
*20060504061442 20060504061487 20060504061586 20060504061687 20060504061714 20060504061736
*20060504061740 20060504061743 20060504061821 20060504061839 20060504061935 20060504061938
*20060504061949 20060504061971 20060504062106 20060504062225 20060504062238 20060504062240
*20060504062246 20060504062250 20060504062384 20060504062415 20060504062517 20060505060010
*20060505060883 20060505060934 20060505061220 20060505061431 20060505061541 20060505061707
*20060505061740 20060505061785 20060505061915 20060505062128 20060505062144 20060505062181
*20060505062295 20060505062445 20060505062536 20060604060877 20060604060963 20060604060986
*20060604061170 20060604061178 20060604061607 20060604061619 20060604061710 20060604061954
*20060604061992 20060604062045 20060604062113 20060604062371 20060604062452 20060605060020
*20060605060579 20060605060611 20060605060624 20060605060639 20060605060692 20060605060732
*20060605060758 20060605060773 20060605060805 20060605060833 20060605060840 20060605060870
*20060605060925 20060605060951 20060605060952 20060605061051 20060605061109 20060605061137
*20060605061141 20060605061166 20060605061211 20060605061250 20060605061386 20060605061393
*20060605061403 20060605061461 20060605061515 20060605061574 20060605061609 20060605061620
*20060605061638 20060605061652 20060605061660 20060605061674 20060605061676 20060605061717
*20060605061747 20060605061748 20060605061784 20060605061809 20060605061871 20060605061878
*20060605061888 20060605061963 20060605061971 20060605061975 20060605061977 20060605062103
*20060605062130 20060605062131 20060605062216 20060605062226 20060605062244 20060605062264
*20060605062282 20060605062334 20060605062393 20060605062413 20060605062442 20060605062451
*20060605062466 20060605062500 20060605062529 20060605062542 20060606060948 20060606060973
*20060606061047 20060705060635 20060705060998 20060705061075 20060705061413 20060705061579 
*20060705061593 20060705061709 20060705062012 20060705062021 20060705062121 20060705062219
*20060706060006 20060706060030 20060706060043 20060706060060 20060706060065 20060706060071
*20060706060509 20060706060536 20060706060590 20060706060609 20060706060663 20060706060671
*20060706060704 20060706060708 20060706060716 20060706060735 20060706060738 20060706060773
*20060706060813 20060706060819 20060706060830 20060706060878 20060706060949 20060706060952
*20060706061015 20060706061025 20060706061041 20060706061117 20060706061157 20060706061196
*20060706061282 20060706061318 20060706061320 20060706061328 20060706061367 20060706061369
*20060706061388 20060706061410 20060706061442 20060706061480 20060706061537 20060706061554
*20060706061598 20060706061635 20060706061721 20060706061737 20060706061745 20060706061746
*20060706061849 20060706061867 20060706061894 20060706061914 20060706061942 20060706061943
*20060706061971 20060706061975 20060706062010 20060706062013 20060706062055 20060706062095
*20060706062113 20060706062117 20060706062186 20060706062213 20060706062266 20060706062308
*20060706062323 20060706062339 20060706062372 20060706062397 20060706062399 20060706062427
*20060706062429 20060706062445 20060706062459 20060706062486 20060706062518 20060706062519
*20060706062523 20060707060606 20060707061270 20060707061306 20060707061738 20060707061787
*20060707062174 20060707062234 20060707062266 20060707062349 20060707062369 20060707062550
*20060707062554 20060806060061 20060806060625 20060806060669 20060806060823 20060806061071
*20060806061405 20060806061463 20060806061629 20060806062038 20060806062222 20060806062229
*20060806062402 20060806062440 20060806062485 20060807060039 20060807060047 20060807060073
*20060807060109 20060807060547 20060807060569 20060807060571 20060807060576 20060807060594
*20060807060642 20060807060655 20060807060670 20060807060690 20060807060786 20060807060793
*20060807060818 20060807060826 20060807060833 20060807060844 20060807061043 20060807061065
*20060807061096 20060807061118 20060807061128 20060807061162 20060807061215 20060807061217
*20060807061349 20060807061363 20060807061366 20060807061403 20060807061407 20060807061411
*20060807061539 20060807061554 20060807061591 20060807061599 20060807061638 20060807061657
*20060807061706 20060807061900 20060807061964 20060807062043 20060807062111 20060807062194
*20060807062221 20060807062239 20060807062274 20060807062299 20060807062307 20060807062332
*20060807062366 20060807062514 20060807062535 20060808060536 20060808060576 20060808060722
*20060808061560 20060808061712 20060808061892 20060808062354 20060808062377 20060907060740
*20060907061293 20060907061367 20060907061390 20060907061392 20060907061427 20060907061445
*20060907061705 20060907061896 20060907062370 20060908060018 20060908060093 20060908060531
*20060908060544 20060908060556 20060908060563 20060908060564 20060908060649 20060908060685
*20060908060711 20060908060714 20060908060721 20060908060736 20060908060744 20060908060750
*20060908060753 20060908060765 20060908060796 20060908060823 20060908060845 20060908060909
*20060908060934 20060908060972 20060908060987 20060908061022 20060908061064 20060908061086
*20060908061108 20060908061144 20060908061152 20060908061213 20060908061220 20060908061259
*20060908061335 20060908061348 20060908061359 20060908061364 20060908061377 20060908061385
*20060908061396 20060908061485 20060908061515 20060908061582 20060908061650 20060908061665
*20060908061703 20060908061742 20060908061752 20060908061858 20060908061869 20060908061936
*20060908061982 20060908061990 20060908062081 20060908062165 20060908062214 20060908062261
*20060908062345 20060908062372 20060908062442 20060908062466 20060908062493 20060908062507
*20060908062512 20060909060005 20060909060711 20060909060976 20060909060983 20060909061164
*20060909061184 20060909061488 20060909061992 20060909062177 20060909062231 20060909062239
*20060909062308 20060909062315 20060909062368 20061008061160 20061008061162 20061008061805
*20061008061811 20061008061839 20061008062293 20061008062351 20061008062352 20061008062376
*20061008062393 20061008062444 20061008062518 20061009060527 20061009060537 20061009060551
*20061009060568 20061009060575 20061009060594 20061009060647 20061009060713 20061009060809
*20061009060835 20061009060846 20061009060883 20061009060902 20061009060954 20061009061023
*20061009061045 20061009061072 20061009061098 20061009061105 20061009061136 20061009061138
*20061009061186 20061009061223 20061009061362 20061009061370 20061009061471 20061009061473
*20061009061477 20061009061480 20061009061531 20061009061618 20061009061791 20061009061804
*20061009061810 20061009061814 20061009061833 20061009061927 20061009061993 20061009062052
*20061009062150 20061009062248 20061009062252 20061009062257 20061009062260 20061009062279
*20061009062320 20061009062329 20061009062332 20061009062384 20061009062401 20061009062426
*20061009062471 20061009062486 20061009062488 20061009062527 20061009062535 20061009062543
*20061010060061 20061010060144 20061010060786 20061010061042 20061010061159 20061010061306
*20061010061407 20061010061470 20061010061535 20061010061637 20061010061774 20061010061836
*20061010061991 20061010062056 20061010062071 20061010062142 20061010062213 20061109061144
*20061109061258 20061109061365 20061109061481 20061109061766 20061109061790 20061109061908
*20061109062473 20061109062515 20061110060537 20061110060584 20061110060591 20061110060673
*20061110060708 20061110060802 20061110060813 20061110060841 20061110060858 20061110060873
*20061110060927 20061110060968 20061110060999 20061110061008 20061110061099 20061110061100
*20061110061122 20061110061337 20061110061348 20061110061389 20061110061390 20061110061449
*20061110061451 20061110061488 20061110061502 20061110061519 20061110061526 20061110061544
*20061110061662 20061110061673 20061110061746 20061110061748 20061110061751 20061110061815
*20061110061828 20061110061868 20061110061893 20061110061947 20061110061953 20061110061992
*20061110062035 20061110062050 20061110062051 20061110062112 20061110062180 20061110062200
*20061110062220 20061110062245 20061110062293 20061110062331 20061110062358 20061110062366
*20061110062374 20061110062413 20061110062417 20061110062418 20061110062455 20061110062470
*20061110062517 20061110062536 20061111060117 20061111061454 20061111061920 20061111061930
*20061111062360 20061210060518 20061210060693 20061210060757 20061210060879 20061210060970
*20061210061004 20061210061460 20061210061757 20061211060029 20061211060031 20061211060130
*20061211060508 20061211060556 20061211060581 20061211060635 20061211060701 20061211060724
*20061211060802 20061211060829 20061211060879 20061211060890 20061211060928 20061211060958
*20061211060986 20061211061015 20061211061055 20061211061058 20061211061106 20061211061108
*20061211061126 20061211061142 20061211061152 20061211061173 20061211061272 20061211061289
*20061211061307 20061211061309 20061211061359 20061211061446 20061211061459 20061211061476
*20061211061493 20061211061513 20061211061630 20061211061715 20061211061738 20061211061772
*20061211061774 20061211061786 20061211061872 20061211061891 20061211061931 20061211061935
*20061211061943 20061211061952 20061211061960 20061211062018 20061211062129 20061211062204
*20061211062221 20061211062273 20061211062276 20061211062301 20061211062352 20061211062455
*20061211062490 20061211062551 20061212060064 20061212060893 20061212061269 20061212061542
*20061212061631 20061212061786 20061212061832 20061212061869.

*2-5 episodes
*20060101060033 20060101060057 20060101061463 20060101061497 20060101061740 20060101061825 
*20060101061924 20060101062008 20060101062057 20060101062331 20060101062388 20060101062459
*20060110050724 20060110051869 20060111050138 20060111050532 20060111050645 20060111050786 
*20060111051095 20060111051112 20060111051124 20060111051136 20060111051215 20060111051289
*20060111051389 20060111051427 20060111051883 20060111052146 20060111052158 20060111052174 
*20060111052299 20060112050013 20060112050030 20060112050108 20060112050551 20060112050615
*20060112050768 20060112050776 20060112050800 20060112050816 20060112050873 20060112050912 
*20060112050921 20060112050927 20060112050996 20060112050999 20060112051152 20060112051186
*20060112051200 20060112051213 20060112051258 20060112051312 20060112051352 20060112051368 
*20060112051389 20060112051500 20060112051515 20060112051545 20060112051567 20060112051593
*20060112051616 20060112051663 20060112051707 20060112051758 20060112051759 20060112051772 
*20060112051777 20060112051781 20060112051785 20060112051787 20060112051801 20060112051831
*20060112051868 20060112051891 20060112051941 20060112051991 20060112052079 20060112052148
*20060112052158 20060112052185 20060112052332 20060112052354 20060112052355 20060112052361
*20060112052367 20060112052403 20060112052422 20060112052429 20060112052457 20060112052480
*20060112052492 20060112052513 20060112052517 20060201060061 20060201060575 20060201060613
*20060201060652 20060201060837 20060201060898 20060201060926 20060201060974 20060201061002
*20060201061008 20060201061046 20060201061050 20060201061077 20060201061163 20060201061278
*20060201061317 20060201061396 20060201061440 20060201061491 20060201061556 20060201061666
*20060201061672 20060201061696 20060201061841 20060201061851 20060201061865 20060201061921
*20060201061932 20060201061957 20060201062105 20060201062124 20060201062185 20060201062234
*20060201062243 20060201062265 20060201062267 20060201062312 20060201062326 20060201062341
*20060201062355 20060201062371 20060201062375 20060201062382 20060201062430 20060201062436
*20060201062485 20060201062527 20060201062533 20060202060730 20060202062224 20060202062283
*20060202062542 20060212050858 20060212050906 20060212050950 20060212051935 20060212052395
*20060301060775 20060301060814 20060301061205 20060301061348 20060301061353 20060301061427
*20060301061479 20060301061772 20060301061925 20060301062560 20060302060027 20060302060066
*20060302060571 20060302060586 20060302060613 20060302060724 20060302060737 20060302061073
*20060302061106 20060302061122 20060302061127 20060302061166 20060302061224 20060302061355
*20060302061438 20060302061443 20060302061453 20060302061507 20060302061590 20060302061712
*20060302061785 20060302061871 20060302061872 20060302061935 20060302061938 20060302061970
*20060302062020 20060302062093 20060302062221 20060302062222 20060302062292 20060302062309
*20060302062560 20060303060986 20060303060994 20060303060998 20060303061049 20060303061052
*20060303061766 20060303061923 20060303062353 20060303062356 20060303062403 20060402061116
*20060402061210 20060402061272 20060402061492 20060402061759 20060402061855 20060402061894
*20060402062179 20060403060007 20060403060042 20060403060557 20060403060643 20060403060731
*20060403060806 20060403060965 20060403061036 20060403061078 20060403061107 20060403061118
*20060403061250 20060403061479 20060403061481 20060403061544 20060403061551 20060403061666
*20060403061687 20060403061734 20060403061791 20060403061794 20060403061859 20060403061897
*20060403061924 20060403061957 20060403062096 20060403062142 20060403062143 20060403062192
*20060403062227 20060403062257 20060403062328 20060403062332 20060403062349 20060403062386
*20060403062419 20060403062509 20060404060524 20060404060718 20060404060779 20060404060998
*20060404061601 20060404062166 20060502062114 20060503061024 20060503061045 20060503061415
*20060503061805 20060503061986 20060503062288 20060503062555 20060504060004 20060504060584
*20060504060596 20060504060648 20060504060708 20060504060835 20060504060842 20060504060884
*20060504060907 20060504061040 20060504061308 20060504061313 20060504061374 20060504061532
*20060504061539 20060504061715 20060504061799 20060504061834 20060504061857 20060504061863
*20060504061918 20060504062001 20060504062028 20060504062213 20060504062270 20060504062337
*20060504062514 20060504062529 20060504062559 20060504062562 20060505061046 20060505061125
*20060505061445 20060505061851 20060505062047 20060505062087 20060505062371 20060505062416
*20060505062461 20060505062473 20060603061796 20060604060786 20060604061076 20060604061092
*20060604061284 20060604061876 20060604062180 20060604062358 20060605060030 20060605060508
*20060605060533 20060605060537 20060605060698 20060605060844 20060605061019 20060605061059
*20060605061068 20060605061146 20060605061163 20060605061210 20060605061225 20060605061255
*20060605061273 20060605061351 20060605061404 20060605061432 20060605061594 20060605061613
*20060605061647 20060605061665 20060605061731 20060605061761 20060605061869 20060605061908
*20060605061965 20060605062030 20060605062077 20060605062139 20060605062142 20060605062278
*20060605062324 20060605062340 20060605062369 20060605062388 20060605062419 20060605062452
*20060605062482 20060605062507 20060605062522 20060605062533 20060606060098 20060606060549
*20060606061569 20060606061696 20060606062320 20060606062452 20060704061125 20060705060067
*20060705061241 20060705061281 20060705061337 20060705061442 20060705062262 20060705062506
*20060706060541 20060706060578 20060706060715 20060706060717 20060706060739 20060706060769
*20060706060802 20060706060837 20060706060976 20060706061010 20060706061123 20060706061166
*20060706061173 20060706061189 20060706061445 20060706061456 20060706061472 20060706061489
*20060706061508 20060706061626 20060706061706 20060706061774 20060706061833 20060706061847
*20060706061864 20060706062104 20060706062157 20060706062163 20060706062194 20060706062221
*20060706062228 20060706062237 20060706062257 20060706062283 20060706062288 20060706062300
*20060706062302 20060706062364 20060706062401 20060706062417 20060706062487 20060707060136
*20060707060537 20060707060541 20060707060691 20060707060765 20060707061095 20060707061506
*20060707061816 20060707061935 20060707061987 20060707062067 20060806060516 20060806060941
*20060806060969 20060806061287 20060806061337 20060806061763 20060806061861 20060806062148
*20060806062263 20060806062335 20060806062534 20060807060069 20060807060106 20060807060110
*20060807060535 20060807060619 20060807060628 20060807060634 20060807060661 20060807060678
*20060807060741 20060807060751 20060807060857 20060807060863 20060807060945 20060807061070 
*20060807061093 20060807061099 20060807061131 20060807061158 20060807061210 20060807061299
*20060807061391 20060807061395 20060807061510 20060807061511 20060807061564 20060807061639
*20060807061803 20060807061825 20060807061845 20060807061980 20060807062011 20060807062115
*20060807062260 20060807062285 20060807062297 20060807062330 20060807062358 20060807062371
*20060807062396 20060807062415 20060807062482 20060807062511 20060808061142 20060808061720
*20060808062007 20060808062057 20060906061534 20060907060602 20060907060708 20060907060861
*20060907061538 20060907062118 20060907062403 20060908060009 20060908060045 20060908060056
*20060908060070 20060908060601 20060908060616 20060908060638 20060908060850 20060908060884
*20060908060886 20060908060944 20060908061062 20060908061072 20060908061074 20060908061229
*20060908061318 20060908061411 20060908061487 20060908061492 20060908061553 20060908061652
*20060908061673 20060908061689 20060908061758 20060908061761 20060908061819 20060908061870
*20060908061945 20060908061961 20060908062023 20060908062095 20060908062222 20060908062295
*20060908062315 20060908062328 20060908062329 20060908062368 20060908062379 20060908062436
*20060908062453 20060908062484 20060909060726 20060909061151 20060909061562 20060909061865
*20060909061874 20060909062069 20060909062180 20060909062273 20060909062310 20061008060996
*20061008061010 20061008061357 20061008061574 20061008061624 20061008061745 20061008061848
*20061008061953 20061008061964 20061008062239 20061009060003 20061009060555 20061009060650
*20061009060706 20061009060718 20061009060752 20061009060922 20061009061081 20061009061094
*20061009061120 20061009061123 20061009061220 20061009061317 20061009061374 20061009061429
*20061009061479 20061009061482 20061009061640 20061009061651 20061009061666 20061009061746
*20061009061754 20061009061855 20061009061885 20061009061888 20061009061986 20061009062002
*20061009062020 20061009062220 20061009062334 20061009062349 20061009062358 20061009062418
*20061009062432 20061009062482 20061009062521 20061009062551 20061010060713 20061010060837
*20061010061369 20061010061607 20061010061647 20061010061692 20061010061822 20061010061871
*20061010062280 20061010062328 20061010062395 20061010062463 20061109061087 20061109061328
*20061109061601 20061109061850 20061109061901 20061109062099 20061109062108 20061109062191
*20061109062391 20061110060014 20061110060051 20061110060052 20061110060141 20061110060506
*20061110060525 20061110060532 20061110060777 20061110060952 20061110060954 20061110061118
*20061110061165 20061110061181 20061110061194 20061110061339 20061110061423 20061110061456
*20061110061472 20061110061554 20061110061555 20061110061665 20061110061731 20061110061773
*20061110061789 20061110061841 20061110061866 20061110061879 20061110061887 20061110061892
*20061110062109 20061110062113 20061110062125 20061110062159 20061110062210 20061110062217
*20061110062224 20061110062279 20061110062296 20061110062310 20061110062402 20061110062460
*20061110062466 20061110062493 20061110062511 20061111060023 20061111060523 20061111060700
*20061111061448 20061111061929 20061111062211 20061111062324 20061111062489 20061210060780
*20061210061041 20061210061107 20061210061400 20061210061612 20061210062037 20061211060063
*20061211060502 20061211060587 20061211060600 20061211060677 20061211060961 20061211061148
*20061211061168 20061211061207 20061211061222 20061211061242 20061211061245 20061211061260
*20061211061268 20061211061320 20061211061349 20061211061383 20061211061608 20061211061691
*20061211061729 20061211061731 20061211061769 20061211061775 20061211061784 20061211061903
*20061211061967 20061211062047 20061211062055 20061211062087 20061211062091 20061211062126
*20061211062170 20061211062175 20061211062227 20061211062229 20061211062247 20061211062254
*20061211062259 20061211062265 20061211062327 20061211062337 20061211062342 20061211062386
*20061211062423 20061211062450 20061211062470 20061212060131 20061212060548 20061212060967
*20061212061176 20061212061431 20061212061612 20061212061961 20061212062325 20061212062330
*20061212062385 20061212062525 20061212062536.
	
*more than 6-9 episodes
*20060101061380 20060112051080 20060201062028 20060201062113 20060201062364 20060202062287
*20060212051685 20060302061804 20060402060622 20060402062508 20060403061611 20060503060121
*20060505060604 20060605060756 20060605061537 20060706062455 20060807061817 20060808060968 
*20060808061649 20060908060653 20060908061068 20060908061660 20060908061908 20060908061913 
*20060908061926 20060908061985 20060908062050 20061010060814 20061010062535 20061109062324 
*20061110062009 20061111062398 20061211061177 20061211061328 20061211061430 20061211061458 
*20061211061823 20061211062363 20061211062548.

*more than 10+ episodes
*20060201060873 20060403061177 20060403062343 20060505060818 20060605061480 20060707061137.

*288 episodes less than 5 minutes, 434 episodes are 5 minutes - treat these as secondary eating only. 
*For episodes with 6-30 minutes of both child in care and eating, code as 15 minutes of eating &
*15 minutes of care; for joint episodes of more than 30 minutes, codes as half and half for each
*secondary activity, but in this case make 3 episodes,with eating in the middle.

Do if test=3 and sectemp>5.
   compute kideatr1=rnd(sectemp/2).
   compute kideatr2=trunc(sectemp/2).
End if.
cro test by kideatr1.

temp.
select if sectemp>30.
freq kideatr1 kideatr2.

Do if test=3 and (sectemp>5 and sectemp<31).
   compute start2=oend-kideatr2.
   compute end1=oend-kideatr2.
   compute end2=oend.
   compute main2=main1.
   compute sec1=9.
   compute sec2=osec.
   compute inout2=oinout.
   compute eloc2=oeloc.
   compute mtrav2=omtrav.
   compute alone2=oalone.
   compute infant2=oinfant.
   compute child2=ochild.
   compute sppart2=osppart.
   compute clsfam2=oclsfam.
   compute hhadult2=ohhadult.
   compute cowork2=ocowork.
   compute wellknw2=owellknw.
   compute otherp2=ootherp.
   compute unknwp2=ounknwp.
   compute animal2=oanimal.
   compute shoprof2=oshoprof.
Else if test=3 and sectemp>30 and (kideatr2=16 or kideatr2=18
   or kideatr2=20 or kideatr2=22 or kideatr2=24 or kideatr2=26 or kideatr2=30
   or kideatr2=32 or kideatr2=34 or kideatr2=40 or kideatr2=42 or kideatr2=46
   or kideatr2=48 or kideatr2=50 or kideatr2=52 or kideatr2=54 or kideatr2=56
   or kideatr2=60 or kideatr2=62 or kideatr2=64 or kideatr2=66 or kideatr2=70
   or kideatr2=72 or kideatr2=74 or kideatr2=80 or kideatr2=82 or kideatr2=84
   or kideatr2=90 or kideatr2=92 or kideatr2=94 or kideatr2=98 or kideatr2=100
   or kideatr2=102 or kideatr2=110 or kideatr2=112 or kideatr2=116 or kideatr2=120
   or kideatr2=122 or kideatr2=124 or kideatr2=130 or kideatr2=142 or kideatr2=146
   or kideatr2=150 or kideatr2=154 or kideatr2=160 or kideatr2=170 or kideatr2=172
   or kideatr2=180 or kideatr2=182 or kideatr2=190 or kideatr2=210 or kideatr2=220
   or kideatr2=240 or kideatr2=242 or kideatr2=266 or kideatr2=270 or kideatr2>285).
   compute start2=start1+(kideatr2/2).
   compute end1=start1+(kideatr2/2).
   compute start3=oend-(kideatr2/2).
   compute end2=oend-(kideatr2/2).
   compute end3=oend.
   compute main2=main1.
   compute main3=main1.
   compute sec2=9.
   compute sec3=osec.
   compute inout2=oinout.
   compute inout3=oinout.
   compute eloc2=oeloc.
   compute eloc3=oeloc.
   compute mtrav2=omtrav.
   compute mtrav3=omtrav.
   compute alone2=oalone.
   compute alone3=oalone.
   compute infant2=oinfant.
   compute infant3=oinfant.
   compute child2=ochild.
   compute child3=ochild.
   compute sppart2=osppart.
   compute sppart3=osppart.
   compute clsfam2=oclsfam.
   compute clsfam3=oclsfam.
   compute hhadult2=ohhadult.
   compute hhadult3=ohhadult.
   compute cowork2=ocowork.
   compute cowork3=ocowork.
   compute wellknw2=owellknw.
   compute wellknw3=owellknw.
   compute otherp2=ootherp.
   compute otherp3=ootherp.
   compute unknwp2=ounknwp.
   compute unknwp3=ounknwp.
   compute animal2=oanimal.
   compute animal3=oanimal.
   compute shoprof2=oshoprof.
   compute shoprof3=oshoprof.
Else if test=3 and sectemp>30.
   compute start2=start1+((kideatr2-1)/2).
   compute end1=start1+((kideatr2-1)/2).
   compute start3=oend-((kideatr2-1)/2).
   compute end2=oend-((kideatr2-1)/2).
   compute end3=oend.
   compute main2=main1.
   compute main3=main1.
   compute sec2=9.
   compute sec3=osec.
   compute inout2=oinout.
   compute inout3=oinout.
   compute eloc2=oeloc.
   compute eloc3=oeloc.
   compute mtrav2=omtrav.
   compute mtrav3=omtrav.
   compute alone2=oalone.
   compute alone3=oalone.
   compute infant2=oinfant.
   compute infant3=oinfant.
   compute child2=ochild.
   compute child3=ochild.
   compute sppart2=osppart.
   compute sppart3=osppart.
   compute clsfam2=oclsfam.
   compute clsfam3=oclsfam.
   compute hhadult2=ohhadult.
   compute hhadult3=ohhadult.
   compute cowork2=ocowork.
   compute cowork3=ocowork.
   compute wellknw2=owellknw.
   compute wellknw3=owellknw.
   compute otherp2=ootherp.
   compute otherp3=ootherp.
   compute unknwp2=ounknwp.
   compute unknwp3=ounknwp.
   compute animal2=oanimal.
   compute animal3=oanimal.
   compute shoprof2=oshoprof.
   compute shoprof3=oshoprof.
End if.
execute.
*visually check some cases - these look ok. Sec3 remains all 34 or 0 or -5 .
freq sec1 sec2 sec3.
*now 6441 cases of secondary eating in sec1 (code 9).

*check for 0 time episodes, start1 should not = start2, and start2 should not = start3.
compute check=0.
if start1=start2 check=1.
freq check.
*no cases or start1=start2.
compute check=0.
if start2=start3 and start2>-5 check2=1.
freq check.
*all still ok.

sort cases by pid.
match files /file=* /table="H:\evrim\AHTUS\2006\usa06questall.sav" /by pid.
execute.

sort cases by pid. 
vector start=start1 to start3 /end=end1 to end3 /main=main1 to main3 /sec=sec1 to sec3 /inout=inout1 to inout3
      /eloc=eloc1 to eloc3 /mtrav=mtrav1 to mtrav3 /alone=alone1 to alone3 /infant=infant1 to infant3 /child= 
       child1 to child3 /sppart=sppart1 to sppart3 /clsfam=clsfam1 to clsfam3 /hhadult=hhadult1 to hhadult3 
      /cowork=cowork1 to cowork3 /wellknw=wellknw1 to wellknw3 /otherp=otherp1 to otherp3 /unknwp=unknwp1 to
       unknwp3 /animal=animal1 to animal3 /shoprof=shoprof1 to shoprof3.

loop i=1 to 3.
     compute start=start(i).
     compute end=end(i).
     compute main=main(i). 
     compute sec=sec(i).
     compute inout=inout(i).
     compute eloc=eloc(i).
     compute mtrav=mtrav(i).
     compute alone=alone(i). 
     compute infant=infant(i).
     compute child=child(i).
     compute sppart=sppart(i).
     compute clsfam=clsfam(i).
     compute hhadult=hhadult(i).
     compute cowork=cowork(i).
     compute wellknw=wellknw(i).
     compute otherp=otherp(i).
     compute unknwp=unknwp(i).
     compute animal=animal(i).
     compute shoprof=shoprof(i).
     xsave outfile='H:\evrim\AHTUS\2006\tempa\revised-diary.sav'
    /keep = survey wave pid diaryday cday month year start end main sec inout eloc 
     mtrav alone infant child sppart clsfam hhadult cowork wellknw otherp unknwp 
     animal shoprof TUFINWGT age.
end loop.
execute.

sort cases by pid epnum.
save outfile ='H:\evrim\AHTUS\2006\tempa\tempfile6.sav'.

get file='H:\evrim\AHTUS\2006\tempa\revised-diary.sav'.

freq main.
*-5 cases are slots that are not needed as there was no secondary activity during that slot. 
*remove these rows.
select if main~=-5.
freq main.

*reconstruct clockst following addition of new episodes.
Do if start=0.
   compute clockst = 400. 
Else if start<60.
   compute clockst = 400 + start. 
Else if start<120.
   compute clockst = 500 + start-60. 
Else if start<180.
   compute clockst = 600 + start-120. 
Else if start<240.
   compute clockst = 700 + start-180. 
Else if start<300.
   compute clockst = 800 + start-240. 
Else if start<360.
   compute clockst = 900 + start-300. 
Else if start<420.
   compute clockst = 1000 + start-360. 
Else if start<480.
   compute clockst = 1100 + start-420. 
Else if start<540.
   compute clockst = 1200 + start-480. 
Else if start<600.
   compute clockst = 1300 + start-540. 
Else if start<660.
   compute clockst = 1400 + start-600. 
Else if start<720.
   compute clockst = 1500 + start-660. 
Else if start<780.
   compute clockst = 1600 + start-720. 
Else if start<840.
   compute clockst = 1700 + start-780. 
Else if start<900.
   compute clockst = 1800 + start-840. 
Else if start<960.
   compute clockst = 1900 + start-900. 
Else if start<1020.
   compute clockst = 2000 + start-960. 
Else if start<1080.
   compute clockst = 2100 + start-1020. 
Else if start<1140.
   compute clockst = 2200 + start-1080. 
Else if start<1200.
   compute clockst = 2300 + start-1140. 
Else if start<1260.
   compute clockst = 0 + start-1200. 
Else if start<1320.
   compute clockst = 100 + start-1260. 
Else if start<1380.
   compute clockst = 200 + start-1320. 
Else if start<1440.
   compute clockst = 300 + start-1380. 
End if.
freq clockst.

*reconstruct time following addition of new episodes.
compute time=end-start.
desc time.

*check that all diaries contain 1440 minutes.
aggregate outfile=* mode=addvariables /break=pid  /tottime=sum(time).
freq tottime.
*they do - good outcome.

*reconstruct epnum following addition of new episodes.
Do if start=0.
   compute epnum=1.
Else if pid=lag(pid).
   compute epnum=lag(epnum)+1.
End if.
freq epnum.

**hfep is being saved here for the first time**.
save outfile='H:\evrim\AHTUS\2006\USA2006hfep.SAV'
   /KEEP survey wave pid diaryday cday month year time 
    clockst start end epnum main sec inout eloc mtrav alone 
    infant child sppart clsfam hhadult animal shoprof 
    cowork wellknw otherp unknwp tufinwgt age. 

*extract the state information to construct a separate weight
*excluding those states not found in all studies in the AHTUS.

match files file='H:\evrim\AHTUS\2006\atusresp_2006.sav' /in=inresp
      file='H:\evrim\AHTUS\2006\atuscps_2006.sav' /in=incps
     /keep tucaseid tuyear gestfips.

cro incps by inresp.

*this leaves just the respondents who completed diaries. The CPS 
*file includes information on all persons interviewed in the 
*households and other cases need to be eliminated.

sel if inresp=1.
execute.

fre gestfips.

compute state=gestfips.

recode state   (-9=-9) (1=1)   (2=2)   (4=3)   (5=4)   (6=5)   (8=6) 
(9=7)   (10=8)  (11=9)  (12=10) (13=11) (15=12) (16=13) (17=14) (18=15) 
(19=16) (20=17) (21=18) (22=19) (23=20) (24=21) (25=22) (26=23) (27=24) 
(28=25) (29=26) (30=27) (31=28) (32=29) (33=30) (34=31) (35=32) (36=33) 
(37=34) (38=35) (39=36) (40=37) (41=38) (42=39) (44=40) (45=41) (46=42) 
(47=43) (48=44) (49=45) (50=46) (51=47) (53=48) (54=49) (55=50) (56=51). 

val lab state
-9 data not available	
 1 ALABAMA	
 2 ALASKA	
 3 ARIZONA	
 4 ARKANSAS	
 5 CALIFORNIA	
 6 COLORADO	
 7 CONNECTICUT	
 8 DELAWARE	
 9 DISTRICT OF COLUMBIA	
10 FLORIDA	
11 GEORGIA	
12 HAWAII	
13 IDAHO	
14 ILLINOIS	
15 INDIANA	
16 IOWA	
17 KANSAS	
18 KENTUCKY	
19 LOUISIANA	
20 MAINE	
21 MARYLAND	
22 MASSACHUSETTS	
23 MICHIGAN	
24 MINNESOTA	
25 MISSISSIPPI	
26 MISSOURI	
27 MONTANA	
28 NEBRASKA	
29 NEVADA	
30 NEW HAMPSHIRE	
31 NEW JERSEY	
32 NEW MEXICO	
33 NEW YORK	
34 NORTH CAROLINA	
35 NORTH DAKOTA	
36 OHIO	
37 OKLAHOMA	
38 OREGON	
39 PENNSYLVANIA	
40 RHODE ISLAND	
41 SOUTH CAROLINA	
42 SOUTH DAKOTA	
43 TENNESSEE	
44 TEXAS	
45 UTAH	
46 VERMONT	
47 VIRGINIA	
48 WASHINGTON	
49 WEST VIRGINIA	
50 WISCONSIN	
51 WYOMING.

compute exclude=0.
if any (state,2,8,12,13,17,27,29,30,32,35,40,46,51) exclude=1.
var lab exclude states to exclude in xtimewt.
val lab exclude
   0 states in all samples
   1 states only in most recent samples.
cro exclude by state.

rename variables (tucaseid = pid).

save outfile='H:\evrim\AHTUS\2006\tempa\excludestates.sav'   /keep pid exclude.

*create variables for summary time use file.

Get file='H:\evrim\AHTUS\2006\USA2006hfep.SAV'.

freq main.
*0.4% of main activity time missing in this file.
freq age.

sort cases by survey pid.

Compute t0pcare=0.
Compute t1paidw=0.
Compute t2ed=0.
compute t3unpaid=0.
compute t4acvol=0.
compute t5outhm=0.
compute t6exerc=0.
compute t7inhm=0.
compute t8media=0.
compute t9trav=0.
compute tmiss=0.
vector tmain(98) tsc(98).
compute outside=0.
compute inveh=0.
compute inside=0.
compute locunk=0.
compute athome=0.
compute atwrksc=0.
compute elsewhr=0.
compute lunk=0.
compute walone=0.
compute wchild=0.
compute wsppart=0.
compute wclsfam=0.
compute wother=0.
compute withunk=0.


If main>-1 and main<10 t0pcare  =time.
If main>9 and main<16 t1paidw   =time.
If main>15 and main<20 t2ed     =time.
If main>19 and main<40 t3unpaid =time.
If main>39 and main<50 t4acvol  =time.
If main>49 and main<60 t5outhm  =time.
If main>59 and main<70 t6exerc  =time.
If main>69 and main<80 t7inhm   =time.
If main>79 and main<90 t8media  =time.
If main>89 and main<100 t9trav  =time.
If main=-8 tmiss                =time.
If inout=1 outside              =time.
if inout=2 inside               =time.
if inout=3 inveh                =time.
if inout=-8 locunk              =time.
if eloc=1 athome                =time.
if eloc=3 or eloc=4 atwrksc     =time.
if eloc=2 or eloc>4 elsewhr     =time.
If eloc=-8 lunk                 =time.
If alone=1 walone               =time.
If child=1 wchild               =time.
If sppart=1 wsppart             =time.
If clsfam=1 wclsfam             =time.
If otherp=1 or cowork=1 or shoprof=1 or hhadult=1 or
   (clsfam=0 and wellknw=1) wother=time.
If unknwp=1 withunk             =time.

Do repeat a=tmain1 to tmain98 /b=tsc1 to tsc98 /i=1 to 98.
   compute a=0.
   compute b=0.
   If main=i a=time.
   If main=i and (sec>32 and sec<40) b=time.
End repeat.

apply dictionary from 'H:\evrim\AHTUS\schema2.sav'.

desc t0pcare t1paidw t2ed t3unpaid t4acvol t5outhm 
     t6exerc t7inhm t8media t9trav tmiss outside inside 
     inveh locunk athome atwrksc elsewhr lunk walone 
     wchild wsppart wclsfam wother withunk.

*compute a test variable to ensure the 1 and 2 digits
*sets of time use codes add up to 1440. both cases need
*to include missing time in the sum.
compute t1dig = SUM(t0pcare to tmiss).
compute t2dig = SUM (tmiss to tmain98).
execute.

save outfile="H:\evrim\AHTUS\2006\tempa\tempfile7.sav".
get file ="H:\evrim\AHTUS\2006\tempa\tempfile7.sav".
freq age.
desc tsc1 to tsc98.
desc tmain1 to tmain98.
*the variables that have no labels do not exist as AHTUS codes
*(tmain47, tmain59, tmain61, tmain69, tmain79 and tmain80).

*set all variable codes which could not be constructed 
*to -9 for missing.

recode tmain5 tsc5 tmain43 tsc43 tmain44 tsc44 tmain45 tsc45 
       tmain46 tsc46 tmain48 tsc48 tmain55 tsc55 tmain70 tsc70
       tmain74 tsc74  tmain82 tsc82 tmain83 tsc83 (0=-9).
execute.

AGGREGATE /OUTFILE='H:\evrim\AHTUS\2006\USA2006hfsum.sav'
  /BREAK=survey wave pid
  /diaryday = MAX(diaryday) /cday = MAX(cday)
  /month = MAX(month)       /year = MAX(year)
  /tottime "total minutes recorded in diary" = SUM(time) 
  /numep 'total original episodes recorded' = MAX(epnum) 
  /t0pcare = SUM(t0pcare)   /t1paid = SUM(t1paidw)   /t2ed = SUM(t2ed)       
  /t3unpaid = SUM(t3unpaid) /t4acvol = SUM(t4acvol)  /t5outhm = SUM(t5outhm) 
  /t6exerc = SUM(t6exerc)   /t7inhm = SUM(t7inhm)    /t8media = SUM(t8media) 
  /t9trav = SUM(t9trav)     /tmiss = SUM(tmiss)      /age     = MAX(age)
  /tmain1  = SUM(tmain1)    /tmain2  = SUM(tmain2)   /tmain3  = SUM(tmain3)
  /tmain4  = SUM(tmain4)    /tmain5  = MAX(tmain5)   /tmain6  = SUM(tmain6)
  /tmain7  = SUM(tmain7)    /tmain8  = SUM(tmain8)   /tmain9  = SUM(tmain9)
  /tmain10 = SUM(tmain10)   /tmain11 = SUM(tmain11)  /tmain12 = SUM(tmain12)
  /tmain13 = SUM(tmain13)   /tmain14 = SUM(tmain14)  /tmain15 = SUM(tmain15)
  /tmain16 = SUM(tmain16)   /tmain17 = SUM(tmain17)  /tmain18 = SUM(tmain18)
  /tmain19 = SUM(tmain19)   /tmain20 = SUM(tmain20)  /tmain21 = SUM(tmain21)
  /tmain22 = SUM(tmain22)   /tmain23 = SUM(tmain23)  /tmain24 = SUM(tmain24)
  /tmain25 = SUM(tmain25)   /tmain26 = SUM(tmain26)  /tmain27 = SUM(tmain27)
  /tmain28 = SUM(tmain28)   /tmain29 = SUM(tmain29)  /tmain30 = SUM(tmain30)
  /tmain31 = SUM(tmain31)   /tmain32 = SUM(tmain32)  /tmain33 = SUM(tmain33)
  /tmain34 = SUM(tmain34)   /tmain35 = SUM(tmain35)  /tmain36 = SUM(tmain36)
  /tmain37 = SUM(tmain37)   /tmain38 = SUM(tmain38)  /tmain39 = SUM(tmain39)
  /tmain40 = SUM(tmain40)   /tmain41 = SUM(tmain41)  /tmain42 = SUM(tmain42)
  /tmain43 = MAX(tmain43)   /tmain44 = MAX(tmain44)  /tmain45 = MAX(tmain45)
  /tmain46 = MAX(tmain46)   /tmain48 = MAX(tmain48)  /tmain49 = SUM(tmain49)
  /tmain50 = SUM(tmain50)   /tmain51 = SUM(tmain51)  /tmain52 = SUM(tmain52)
  /tmain53 = SUM(tmain53)   /tmain54 = SUM(tmain54)  /tmain55 = MAX(tmain55)
  /tmain56 = SUM(tmain56)   /tmain57 = SUM(tmain57)  /tmain58 = SUM(tmain58)
  /tmain60 = SUM(tmain60)   /tmain62 = SUM(tmain62)  /tmain63 = SUM(tmain63)
  /tmain64 = SUM(tmain64)   /tmain65 = SUM(tmain65)  /tmain66 = SUM(tmain66)
  /tmain67 = SUM(tmain67)   /tmain68 = SUM(tmain68)  /tmain70 = MAX(tmain70)
  /tmain71 = SUM(tmain71)   /tmain72 = SUM(tmain72)  /tmain73 = SUM(tmain73)
  /tmain74 = MAX(tmain74)   /tmain75 = SUM(tmain75)  /tmain76 = SUM(tmain76)
  /tmain77 = SUM(tmain77)   /tmain78 = SUM(tmain78)  /tmain81 = SUM(tmain81)
  /tmain82 = MAX(tmain82)   /tmain83 = MAX(tmain83)  /tmain84 = SUM(tmain84)
  /tmain85 = SUM(tmain85)   /tmain86 = SUM(tmain86)  /tmain87 = SUM(tmain87)
  /tmain88 = SUM(tmain88)   /tmain89 = SUM(tmain89)  /tmain90 = SUM(tmain90)
  /tmain91 = SUM(tmain91)   /tmain92 = SUM(tmain92)  /tmain93 = SUM(tmain93)
  /tmain94 = SUM(tmain94)   /tmain95 = SUM(tmain95)  /tmain96 = SUM(tmain96)
  /tmain97 = SUM(tmain97)   /tmain98 = SUM(tmain98)  /tsc1 = SUM(tsc1)
  /tsc2 = SUM(tsc2)         /tsc3 = SUM(tsc3)        /tsc4 = SUM(tsc4)
  /tsc5 = MAX(tsc5)         /tsc6 = SUM(tsc6)        /tsc7 = SUM(tsc7)
  /tsc8 = SUM(tsc8)         /tsc9 = SUM(tsc9)        /tsc10= SUM(tsc10)
  /tsc11= SUM(tsc11)        /tsc12= SUM(tsc12)       /tsc13= SUM(tsc13)
  /tsc14= SUM(tsc14)        /tsc15= SUM(tsc15)       /tsc16= SUM(tsc16)
  /tsc17= SUM(tsc17)        /tsc18= SUM(tsc18)       /tsc19= SUM(tsc19)
  /tsc20= SUM(tsc20)        /tsc21= SUM(tsc21)       /tsc22= SUM(tsc22)
  /tsc23= SUM(tsc23)        /tsc24= SUM(tsc24)       /tsc25= SUM(tsc25)
  /tsc26= SUM(tsc26)        /tsc27= SUM(tsc27)       /tsc28= SUM(tsc28)
  /tsc29= SUM(tsc29)        /tsc30= SUM(tsc30)       /tsc31= SUM(tsc31)
  /tsc32= SUM(tsc32)        /tsc33= SUM(tsc33)       /tsc34= SUM(tsc34)
  /tsc35= SUM(tsc35)        /tsc36= SUM(tsc36)       /tsc37= SUM(tsc37)
  /tsc38= SUM(tsc38)        /tsc39= SUM(tsc39)       /tsc40= SUM(tsc40)
  /tsc41= SUM(tsc41)        /tsc42= SUM(tsc42)       /tsc43= MAX(tsc43)
  /tsc44= MAX(tsc44)        /tsc45= MAX(tsc45)       /tsc46= MAX(tsc46)
  /tsc48= MAX(tsc48)        /tsc49= SUM(tsc49)       /tsc50= SUM(tsc50)
  /tsc51= SUM(tsc51)        /tsc52= SUM(tsc52)       /tsc53= SUM(tsc53)
  /tsc54= SUM(tsc54)        /tsc55= MAX(tsc55)       /tsc56= SUM(tsc56)
  /tsc57= SUM(tsc57)        /tsc58= SUM(tsc58)       /tsc60= SUM(tsc60)
  /tsc62= SUM(tsc62)        /tsc63= SUM(tsc63)       /tsc64= SUM(tsc64)
  /tsc65= SUM(tsc65)        /tsc66= SUM(tsc66)       /tsc67= SUM(tsc67)
  /tsc68= SUM(tsc68)        /tsc70= MAX(tsc70)       /tsc71= SUM(tsc71)
  /tsc72= SUM(tsc72)        /tsc73= SUM(tsc73)       /tsc74= MAX(tsc74)
  /tsc75= SUM(tsc75)        /tsc76= SUM(tsc76)       /tsc77= SUM(tsc77)
  /tsc78= SUM(tsc78)        /tsc81= SUM(tsc81)       /tsc82= MAX(tsc82)
  /tsc83= MAX(tsc83)        /tsc84= SUM(tsc84)       /tsc85= SUM(tsc85)
  /tsc86= SUM(tsc86)        /tsc87= SUM(tsc87)       /tsc88= SUM(tsc88)
  /tsc89= SUM(tsc89)        /tsc90= SUM(tsc90)       /tsc91= SUM(tsc91)
  /tsc92= SUM(tsc92)        /tsc93= SUM(tsc93)       /tsc94= SUM(tsc94)
  /tsc95= SUM(tsc95)        /tsc96= SUM(tsc96)       /tsc97= SUM(tsc97)
  /tsc98= SUM(tsc98)        /outside= SUM(outside)   /inside=SUM(inside)
  /inveh= SUM(inveh)        /locunk = SUM(locunk)    /athome=SUM(athome)
  /atwrksc=SUM(atwrksc)     /elsewhr= SUM(elsewhr)   /lunk = SUM(lunk)
  /walone = SUM(walone)     /wchild = SUM(wchild)    /wsppart=SUM(wsppart)
  /wclsfam= SUM(wclsfam)    /wother = SUM(wother)    /withunk=SUM(withunk)
  /t1dig = SUM(t1dig)       /t2dig = SUM(t2dig)       /tufinwgt=MAX(tufinwgt).

freq age.
*Both adult and child diaries.

**********************************************************************************************
*HHID - originally this was set to the variable hrhhid, which is the CPS household identifier*
*in early year of the ATUS, this variable permitted a match back to the CPS variables, but   *
*values are recycled in later years of the survey, making the match back to the CPS more     *
*complex, better for users to use the ATUS-X system to extract CPS variables for use with the*
*AHTUS variables   https://www.atusdata.org/index.shtml                                      *
**********************************************************************************************.
*
*extract hhid. in this file, there is a variable called
*occurnum labelled unique person identifier which is
*not used as only in this file; also there is an
*alternative household identifier - qstnum - which
*also is not used. The ATUS User Guide identifies 
*hrhhid as the household id which links back to the
*other waves of the CPS data.
*
*Get file='H:\evrim\AHTUS\2006\atuscps_2006.sav'   /keep tucaseid hrhhid huinttyp.
*
*sort cases by tucaseid.
*
*match files file=* /in=incps
   table='H:\evrim\AHTUS\2006\atusresp_2006.sav' /in=inresp
   /by tucaseid.
*
*cro inresp by incps.
*
*freq huinttyp.
*this selection leaves only lines per CPS interview in households
*of respondents who completed diaries, though there will be a line
*for each CPS participant where there was more than one in the household.
*this step gets rid of the non-time diary element participants.
*
*sel if inresp=1.
*execute.
*
*rename variables (tucaseid = pid).
*
*sort cases by pid.

*at the aggregate statement, the number of cases is
*dropped to the number of diarists.
*
*AGGREGATE outfile='H:\evrim\AHTUS\2006\tempa\hhid.sav'
  /BREAK=pid /hhid = MAX(hrhhid).

*extract marker of whether household children present.

GET FILE='H:\evrim\AHTUS\2006\atusresp_2006.sav'  /keep tucaseid trhhchld.

rename variables tucaseid=pid.

save outfile='H:\evrim\AHTUS\2006\tempa\d.sav'.

******************************************************
*now ready to finalise files, start with summary file*
******************************************************.

Get file='H:\evrim\AHTUS\2006\USA2006hfsum.sav'.

*check that variables sum to 1440 in aggregated file.

formats t0pcare to t2dig (f8.0).
execute.

freq t1dig t2dig tottime.
*all diaries add up to the correct 1440 minutes for 
*both the 1 and 2 digit levels of activity code.

match files /file=*
      /file='H:\evrim\AHTUS\2006\tempa\dem.sav'
      /file='H:\evrim\AHTUS\2006\tempa\d.sav'/by pid.
execute.

compute hhid=0.
sort cases by hhid pid.
save outfile='H:\evrim\AHTUS\2006\tempa\weights.sav'.

save outfile 'H:\evrim\AHTUS\2006\tempa\burayakadar.sav'.
get file 'H:\evrim\AHTUS\2006\tempa\burayakadar.sav'.
freq age.

*********
*badcase*
*********.

Get file='H:\evrim\AHTUS\2006\USA2006hfep.SAV'.
freq main.
compute hhid=0.

sort cases by hhid pid.

**compute misbasic variable**.

compute tmiss2=0.
compute aeatdr=0.
compute asleep=0.
compute apcare=0.
compute atrav=0.
compute anycare=0.
execute.

If main=-8  tmiss2=time.
desc tmiss2.

*include the diaries with food preparation activities 
*but no eating.
If main=8 or main=9 or main=20 or main=21 or main=56 or sec=2 or
   sec=8 or sec=9 or sec=20 or sec=21 or sec=56 or eloc=6
   aeatdr=1. 

*includes do nothing, think, time out or work break.
If main=3 or main=4 or main=5 or main=13 or main=78 or 
   sec=3 or sec=4 or sec=5 or sec=13 or sec=78 
   asleep=1.

*includes purchase of per'l care and imputed p'l or hhold care.
If main=1 or main=2 or main=6 or main=7 or main=28 or 
   sec=1 or sec=6 or sec=7 or sec=28
   apcare=1.

*includes sports/exercise, walking, cycling, outdoor recreation,
*gardening, petcare, hunting.
If (main>89 and main<99) or main=60 or main=62 or main=63 or main=64 or 
   main=65 or main=66 or main=67 or main=68 or (sec>89 and sec<99) or 
   sec=60 or sec=62 or sec=63 or sec=64 or sec=65 or sec=66 or sec=67 or sec=68
   atrav=1.

*to create carer flag.
If (main>32 and main<41) or (sec>32 and sec<41)
   anycare=1.
execute.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=survey wave hhid pid
  /eatdr=MAX(aeatdr) /sleep=MAX(asleep) /pcare=MAX(apcare) /trav=MAX(atrav).
freq eatdr sleep pcare trav.

*compute test variable to figure the diarists who stayed at home all day.
compute test=0.
if eloc~=lag(eloc) and (hhid=lag(hhid) and pid=lag(pid)) and trav=0 test=1.
freq test.

compute test2=0.
if (hhid=lag(hhid) and pid=lag(pid)) and lag(asleep)=1 and (atrav=1 or (main>9 and main<70) 
   or main>89) and pcare=0 test2=1.
freq test2.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=survey wave hhid pid
  /pcarex=MAX(test2) /travx=MAX(test).
if pcare=0 and pcarex=1 pcare=1.
if trav=0 and travx=1 trav=1.
freq eatdr sleep pcare trav.

compute test=0.
if eloc=1 or eloc=2 test=time.
AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=survey wave hhid pid
  /athome=SUM(test) /maxep=MAX(epnum).
desc athome maxep.

*Diaries including only 2 of the basic act but have at least
*12 episodes where the diarist reports being at home all day
*but otherwise meet the other 4 good diary criteria count as 
*good diaries.

if trav=0 and maxep>11 and athome>1000 trav=1.
freq trav.

AGGREGATE
  /OUTFILE=*
  /BREAK=survey wave hhid pid
  /eatdr=SUM(eatdr) /sleep=SUM(sleep) /pcare=SUM(pcare) /tmiss2=SUM(tmiss2)
  /trav=SUM(trav) /anycare=MAX(anycare) /epnum=MAX(epnum) /day=MAX(diaryday).

compute misbasic=0.
execute.
If trav=0  misbasic=misbasic+1.
If sleep=0 misbasic=misbasic+1.
If pcare=0 misbasic=misbasic+1.
If eatdr=0 misbasic=misbasic+1.
execute.
var lab misbasic number basic activites not recorded.
freq misbasic.
cro anycare by misbasic.
*diaries of carers who otherwise meet the 4 good diary criteria count as good diaries.
if (epnum>7 or anycare=1) and misbasic=2 misbasic=1.
freq misbasic.

temp.
select if misbasic>1.
freq epnum tmiss2.

*we need sex and age information.
sort cases by hhid pid.
match files files= * 
    file="H:\evrim\AHTUS\2006\tempa\usa06sexage_all.sav"
    file='H:\evrim\AHTUS\2006\tempa\weights.sav' 
/by hhid pid.
execute. 

compute lowqual=0.
execute.
if tmiss2>90 or epnum<7 or misbasic>1 lowqual=1.
freq lowqual.
*426 - 3.3% bad diaries.-12517 good ones. 

recode tmiss2 (0 thru 90=0) (91 thru hi=1).
recode epnum (0 thru 6=1) (7 thru hi=0) into nep.
recode misbasic (0,1=0) (2,3,4=1).
execute.
freq tmiss2 nep misbasic age sex.

*As no sex or age missing, only the diary quality variables
*determine bad case in this case.

cro tmiss2 by nep by misbasic.

*426 (3.2%) bad diaries. 1 diary low quality on all 3 counts.
*31 bad on 2 counts. 
	*31 missing basic acts and low episode.
*394 bad on 1 count. 
	*71 have low number of episodes; 
	*305 missing 91+ minutes only; 
	*18 missing 2+ basic acts only.

**********
*caremflg*
**********.

*If the person is missing 2+ basic acts but providing care he/she is flagged as carer.
*The person flagged with caremflg is likely to combine one of the basic acts with care.
cro anycare by misbasic.
compute caremflg=0.
if anycare=1 and misbasic=1 and epnum>6 caremflg=1.
freq caremflg.
cro caremflg by anycare by misbasic.

sort cases by hhid pid.
save outfile='H:\evrim\AHTUS\2006\tempa\weights2.sav'.

get file='H:\evrim\AHTUS\2006\tempa\weights2.sav'.

*********
*weights*
*********.

weight by tufinwgt. 
freq diaryday.
weight off.

*tufinwgt corrects for survey and day of the week.
compute childm=0.
If age<18 childm=1.
freq childm.
means age by childm
   /cells= min max.

compute origwght = tufinwgt.
compute owghtflg = 3.
compute xtimewt=0.
compute infltwt=0.
compute recwght=0.

*Note that recwght should sum to the number of diary cases (good and bad)
*and its mean should be 1.
*Also, the number of cases when you weight by the original inflated weight should be equal
*to the the number of cases when you weight by infltwt

apply dictionary from 'H:\evrim\AHTUS\schema2.sav'.

compute baddem=0.
if sex<1 or age<15 baddem=1.  
freq lowqual baddem.

recode age (15 thru 17=0)(18 thru 24=1)(25 thru 34=2)
           (35 thru 44=3)(45 thru 54=4)(55 thru 64=5)
           (65 thru 74=6)(75 thru high=7)(else=8)
                 into agegp.
recode age (15 thru 17=0)(18 thru 24=1)(25 thru 34=2)
           (35 thru 44=3)(45 thru 54=4)(55 thru 64=5)
           (65 thru 74=6)(75 thru high=7)(else=8)
                 into agegp2.
If lowqual=1 or baddem=1 or diaryday=-8 agegp=8.
cro agegp by trhhchld. 

freq agegp agegp2.
*need to deflate to sampled number.
desc origwght.
*the final weight weights up to the population size.
*12943 diarists, mean 6574184.973865103, but this weight artificially 
*increases the child diarists compared to the adults.

temp.
select if age<18.
desc origwght.
*the weight for young people is 6998628.742549871.

temp.
select if age>17.
desc origwght.
*the weight for adults is 6548335.652542758.

Do if age<18.
   compute origw2=origwght/6998628.742549871.
Else if age>17.
   compute origw2=origwght/6548335.652542758.
End if.
desc origw2.

compute agesexgp=agegp + 10*(sex-1).
compute agesex2=agegp2 + 10*(sex-1).
freq agesexgp agesex2.
recode agesexgp agesex2 (0=1) (10=2) (1=21) (2=22) (3=23)
    (4=24) (5=25) (6=26) (7=27) (11=31) (12=32) (13=33)
    (14=34) (15=35) (16=36) (17=37) (8=90) (18=91).
val lab agesexgp agesex2
1  "men 15-17"
2  "women 15-17"
21 "men 18-24" 
22 "men 25-34" 
23 "men 35-44" 
24 "men 45-54" 
25 "men 55-64" 
26 "men 65-74" 
27 "men 75+"   
31 "women 18-24" 
32 "women 25-34" 
33 "women 35-44"
34 "women 45-54" 
35 "women 55-64" 
36 "women 65-74"
37 "women 75+"   
90 "men miss age/bad diary"
91 "women miss age/bad diary".
missing values agesexgp (90 thru high).

cro agesexgp agesex2 by sex.
means age by agesexgp agesex2
   /cells min max.

missing values all ().

if agesexgp>89 origw2=0.

*The older datasets covered samples of most contiguous states +
*Washington DC, but did not draw samples from 11 states: 
*Delaware, Idaho, Kansas, Montana, Nevada, New Hampshire, 
*New Mexico, North Dakota, Rhode Island, Vermont, and Wyoming. 
*The 1992-94, 1995, 1998-1999 and 1999-2001 samples did cover 
*these states, but did not include Alaska and Hawaii. The ATUS 
*covers all 50 states. It is possible that with some analysis,
*an apparent different across time may reflect the range of
*states included. For this reason, we construct two weights
*in addition to our recommended weight, one which excludes 
*the states not covered in the older samples, and a second
*which includes all states and inflates to the national population.

sort cases by pid.
match files /file=* /file='H:\evrim\AHTUS\2006\tempa\excludestates.sav' /by pid.
freq exclude.

*5.9% of diarists are states included only in the most recent samples.
 
temp.
select if lowqual=0 and exclude=0.
freq agesexgp. 

temp.
select if agesexgp<5 and exclude=0.
freq agesexgp.

temp.
select if (agesexgp>5 and agesexgp<90) and exclude=0.
freq agesexgp.

missing values all ().

compute origw3=origw2.
if agesexgp>89 or exclude=1 origw3=0.

temp.
select if agesexgp>89 or exclude=1.
desc origw3.

temp.
select if origw3>0.
desc origw3.

weight by origw3.
 fre childm agesexgp.
weight off.

sort cases by agesexgp diaryday.

aggregate outfile='H:\evrim\AHTUS\2006\tempa\group.sav'
               /break=agesexgp
               /grouptot=sum(origw2).
aggregate outfile='H:\evrim\AHTUS\2006\tempa\day.sav'
               /break= agesexgp diaryday
               /daytot=sum(origw2) 
               /dayn=nu.
execute.

match files file=* 
     /table='H:\evrim\AHTUS\2006\tempa\group.sav'
     /by agesexgp.
execute.

match files file=* 
     /table='H:\evrim\AHTUS\2006\tempa\day.sav'
     /by agesexgp diaryday.
execute.

sort cases by agesexgp exclude diaryday.

aggregate outfile='H:\evrim\AHTUS\2006\tempa\group3.sav'
               /break=agesexgp exclude
               /groupt3=sum(origw3).
aggregate outfile='H:\evrim\AHTUS\2006\tempa\day3.sav'
               /break= agesexgp exclude diaryday
               /daytot3=sum(origw3) 
               /dayn3=nu.
execute.

match files file=* 
     /table='H:\evrim\AHTUS\2006\tempa\group3.sav'
     /by agesexgp exclude.
execute.

match files file=* 
     /table='H:\evrim\AHTUS\2006\tempa\day3.sav'
     /by agesexgp exclude diaryday.
execute.

compute exptot=(grouptot/7).
compute exptot3=(groupt3/7).

Do if lowqual=0 and baddem=0. 
   compute recwght=(exptot/daytot)/(dayn/daytot).
End if.

Do if lowqual=0 and baddem=0 and exclude=0. 
   compute xtimewt=(exptot3/daytot3)/(dayn3/daytot3).
End if.

desc recwght xtimewt. 
compute under18=0.
if age<18 under18=1.
cro exclude by under18.
freq age.
*743 child diaries in all states in all samples; 
*12200 adult diaries in all states in all samples.
*704 child diaries in states in all samples.
*11481 adult diaries in states in all samples.

compute suma=0.
compute sumc=0.
if age>17 suma=recwght.
if age<18 sumc=recwght.
compute xsuma=0.
compute xsumc=0.
if age>17 xsuma=xtimewt.
if age<18 xsumc=xtimewt.

AGGREGATE
  /OUTFILE=*
  MODE=ADDVARIABLES
  /BREAK=survey
  /recadsum = SUM(suma)
  /recchsum = SUM(sumc)
  /xadsum = SUM(xsuma)
  /xchildsum = SUM(xsumc).
freq recadsum recchsum xadsum xchildsum.
*the sum of adult weights is 11856.107903405851 - it should sum to 12200.
*the sum of child weights is 729.6092339819842 - it should sum to 743.
*the sum of xtime adult weights is 11135.385324127867 - it should sum to 11481.
*the sum of xchild weights is 688.3962918876597 - it should sum to 704.

Do if age>17.
   compute recwght=recwght*(12200/11856.107903405851).
Else if age<18.
   compute recwght=recwght*(743/ 729.6092339819842).
End if.
desc recwght.
*mean is precisely 1.

Do if age>17.
   compute xtimewt=xtimewt*(11481/ 11135.385324127867 ).
Else if age<18.
   compute xtimewt=xtimewt*(704/688.3962918876597).
End if.
desc xtimewt.

temp.
select if exclude=0.
desc xtimewt.
*mean among the states in all years is 1.

weight by recwght.
fre diaryday agesexgp.
*the age/sex group distribution still matches the 
*CPS distribution from the original survey weights.
cro agesexgp by diaryday /cell=row.
cro diaryday by childm.
weight off.

temp.
select if age<18.
desc origwght.
*the weight for young people is 6998628.742549871.

temp.
select if age>17.
desc origwght.
*the weight for adults is 6548335.652542738.

*the numbers are means of original weights for adults and children.
Do if age<18.
   compute infltwt=recwght*6998628.742549871.
Else if age>17.
   compute infltwt=recwght*6548335.652542738.
End if.
desc infltwt. 

sort cases by survey wave hhid pid. 
Save outfile='H:\evrim\AHTUS\2006\USA2006youthsum.sav'
   /drop sleep t1dig t2dig tufinwgt anycare sex age 
    TRHHCHLD misbasic agegp agegp2 origw2 agesexgp 
    agesex2 exclude origw3 grouptot daytot dayn 
    groupt3 daytot3 dayn3 exptot exptot3.

sort cases by pid. 
Save outfile='H:\evrim\AHTUS\2006\tempa\addlow.sav'
   /keep hhid pid lowqual baddem caremflg origwght 
    owghtflg xtimewt infltwt recwght childm.

sort cases by survey wave hhid pid. 
select if childm=0.
Save outfile='H:\evrim\AHTUS\2006\USA2006hfsum.sav'
   /keep survey wave hhid pid diaryday cday month year 
    tottime numep t0pcare t1paid t2ed t3unpaid t4acvol 
    t5outhm t6exerc t7inhm t8media t9trav tmiss tmain1 tmain2
    tmain3  tmain4  tmain5  tmain6  tmain7  tmain8  tmain9 
    tmain10 tmain11 tmain12 tmain13 tmain14 tmain15 tmain16 
    tmain17 tmain18 tmain19 tmain20 tmain21 tmain22 tmain23 
    tmain24 tmain25 tmain26 tmain27 tmain28 tmain29 tmain30 
    tmain31 tmain32 tmain33 tmain34 tmain35 tmain36 tmain37 
    tmain38 tmain39 tmain40 tmain41 tmain42 tmain43 tmain44 
    tmain45 tmain46 tmain48 tmain49 tmain50 tmain51 tmain52 
    tmain53 tmain54 tmain55 tmain56 tmain57 tmain58 tmain60 
    tmain62 tmain63 tmain64 tmain65 tmain66 tmain67 tmain68 
    tmain70 tmain71 tmain72 tmain73 tmain74 tmain75 tmain76 
    tmain77 tmain78 tmain81 tmain82 tmain83 tmain84 tmain85 
    tmain86 tmain87 tmain88 tmain89 tmain90 tmain91 tmain92 
    tmain93 tmain94 tmain95 tmain96 tmain97 tmain98 tsc1 
    tsc2  tsc3  tsc4  tsc5  tsc6  tsc7  tsc8  tsc9  tsc10 
    tsc11 tsc12 tsc13 tsc14 tsc15 tsc16 tsc17 tsc18 tsc19 
    tsc20 tsc21 tsc22 tsc23 tsc24 tsc25 tsc26 tsc27 tsc28 
    tsc29 tsc30 tsc31 tsc32 tsc33 tsc34 tsc35 tsc36 tsc37 
    tsc38 tsc39 tsc40 tsc41 tsc42 tsc43 tsc44 tsc45 tsc46 
    tsc48 tsc49 tsc50 tsc51 tsc52 tsc53 tsc54 tsc55 tsc56 
    tsc57 tsc58 tsc60 tsc62 tsc63 tsc64 tsc65 tsc66 tsc67 
    tsc68 tsc70 tsc71 tsc72 tsc73 tsc74 tsc75 tsc76 tsc77 
    tsc78 tsc81 tsc82 tsc83 tsc84 tsc85 tsc86 tsc87 tsc88 
    tsc89 tsc90 tsc91 tsc92 tsc93 tsc94 tsc95 tsc96 tsc97 
    tsc98 outside inveh inside locunk athome atwrksc elsewhr 
    lunk walone wchild wsppart wclsfam wother withunk lowqual 
    baddem caremflg origwght owghtflg xtimewt infltwt recwght.

Get file='H:\evrim\AHTUS\2006\USA2006hfep.SAV'.
freq age.
freq survey.
match files files=* 
      table='H:\evrim\AHTUS\2006\tempa\addlow.sav'
   /BY pid.
execute.
apply dictionary from 'H:\evrim\AHTUS\schema1.sav'.
cro age by childm.
save outfile='H:\evrim\AHTUS\2006\USA2006hfepA.SAV'. 
*This has both child and adult files.

save outfile='H:\evrim\AHTUS\2006\USA2006youthep.sav'.

get file='H:\evrim\AHTUS\2006\USA2006hfepA.SAV'.

temp.
select if childm=0.
SAVE OUTFILE='H:\evrim\AHTUS\2006\USA2006hfep.sav'
   /keep survey wave hhid pid diaryday cday month year time 
    clockst start end epnum main sec inout eloc mtrav alone 
    infant child sppart clsfam hhadult animal shoprof cowork 
    wellknw otherp unknwp lowqual baddem caremflg origwght 
    owghtflg xtimewt infltwt recwght.
*Now USA2006hfep only includes adult files.

******************************************
*check prevalence of secondary activities*
******************************************.

compute anysec=0.
compute sectime=0.
compute secep=0.
compute seccc=0.
compute seccctm=0.
compute secccep=0.
Do If sec>0.
   compute anysec=1.
   compute sectime= time.
   compute secep=1.
End if.
Do If (sec>32 and sec<40) or sec=96 or sec=99.
   compute seccc=1.
   compute seccctm= time.
   compute secccep=1.
End if.
freq anysec secep seccc secccep.
desc sectime seccctm.

AGGREGATE
  /OUTFILE='H:\evrim\AHTUS\2006\tempa\aggr.sav'
  /BREAK=hhid
  /anysec 'any secondary activity' = MAX(anysec) 
  /seccc 'any secondary childcare' = MAX(seccc) 
  /sectime 'secondary activity time' = SUM(sectime) 
  /seccctm 'secnodary childcare time' = SUM(seccctm) 
  /secccep '# of secondary childcare episodes' = SUM(secccep)
  /secep '# of secondary activity episodes' = SUM(secep)
  /epnum 'number of episodes' = MAX(epnum)
  /lowqual = MAX(lowqual).

Get FILE='H:\evrim\AHTUS\2006\tempa\aggr.sav'.

compute propsec= secep/epnum*100.
compute pcc= secccep/epnum*100.
select if lowqual=0. 
freq anysec seccc.
desc sectime seccctm propsec pcc.

temp.
select if seccc=1.
desc seccctm pcc.

**************************************************
*test labels and variables and finalise the files*
**************************************************.

Get file='H:\evrim\AHTUS\2006\USA2006hfep.SAV'.

desc survey wave hhid pid diaryday cday month year time clockst 
  start end epnum main sec inout eloc mtrav alone infant child 
  sppart clsfam hhadult animal shoprof cowork wellknw otherp 
  unknwp lowqual origwght xtimewt infltwt recwght. 

freq survey wave diaryday cday month year epnum main sec inout 
     eloc mtrav alone infant child sppart clsfam hhadult animal 
     shoprof cowork wellknw otherp unknwp lowqual baddem caremflg.

get file='H:\evrim\AHTUS\2006\USA2006hfsum.sav'.

desc survey wave hhid pid diaryday cday month year tottime numep 
     t0pcare t1paid t2ed t3unpaid t4acvol t5outhm t6exerc t7inhm 
     t8media t9trav tmiss tmain1 to tsc98 outside inveh inside 
     locunk athome atwrksc elsewhr lunk walone wchild wsppart 
     wclsfam wother withunk origwght xtimewt infltwt recwght. 

*this computation must be updated for every survey in accordance with the
*unreported activity types (-9s) in that particular survey.
compute t=sum(tmiss to tmain4) + sum(tmain6 to tmain42) + sum(tmain49 to tmain54) + 
          sum(tmain56 to tmain68) + sum(tmain71 to tmain73) + sum(tmain75 to tmain81) +
          sum(tmain84 to tmain98).
freq t.
*should total to 1440 minutes for all cases.

freq survey wave diaryday cday month year tottime numep lowqual 
     baddem caremflg.

temp.
select if recwght=0.
cro lowqual by baddem. 

temp.
select if recwght~=0.
freq diaryday.

weight by recwght.
freq diaryday.
*all days now should be 14.3%.
weight off.

Get file='H:\evrim\AHTUS\2006\USA2006youthsum.sav'
   /keep survey wave hhid pid diaryday cday month year 
    tottime numep t0pcare t1paid t2ed t3unpaid t4acvol 
    t5outhm t6exerc t7inhm t8media t9trav tmiss tmain1 tmain2
    tmain3  tmain4  tmain5  tmain6  tmain7  tmain8  tmain9 
    tmain10 tmain11 tmain12 tmain13 tmain14 tmain15 tmain16 
    tmain17 tmain18 tmain19 tmain20 tmain21 tmain22 tmain23 
    tmain24 tmain25 tmain26 tmain27 tmain28 tmain29 tmain30 
    tmain31 tmain32 tmain33 tmain34 tmain35 tmain36 tmain37 
    tmain38 tmain39 tmain40 tmain41 tmain42 tmain43 tmain44 
    tmain45 tmain46 tmain48 tmain49 tmain50 tmain51 tmain52 
    tmain53 tmain54 tmain55 tmain56 tmain57 tmain58 tmain60 
    tmain62 tmain63 tmain64 tmain65 tmain66 tmain67 tmain68 
    tmain70 tmain71 tmain72 tmain73 tmain74 tmain75 tmain76 
    tmain77 tmain78 tmain81 tmain82 tmain83 tmain84 tmain85 
    tmain86 tmain87 tmain88 tmain89 tmain90 tmain91 tmain92 
    tmain93 tmain94 tmain95 tmain96 tmain97 tmain98 tsc1  
    tsc2  tsc3  tsc4  tsc5  tsc6  tsc7  tsc8  tsc9  tsc10
    tsc11 tsc12 tsc13 tsc14 tsc15 tsc16 tsc17 tsc18 tsc19 
    tsc20 tsc21 tsc22 tsc23 tsc24 tsc25 tsc26 tsc27 tsc28 
    tsc29 tsc30 tsc31 tsc32 tsc33 tsc34 tsc35 tsc36 tsc37 
    tsc38 tsc39 tsc40 tsc41 tsc42 tsc43 tsc44 tsc45 tsc46 
    tsc48 tsc49 tsc50 tsc51 tsc52 tsc53 tsc54 tsc55 tsc56 
    tsc57 tsc58 tsc60 tsc62 tsc63 tsc64 tsc65 tsc66 tsc67 
    tsc68 tsc70 tsc71 tsc72 tsc73 tsc74 tsc75 tsc76 tsc77 
    tsc78 tsc81 tsc82 tsc83 tsc84 tsc85 tsc86 tsc87 tsc88 
    tsc89 tsc90 tsc91 tsc92 tsc93 tsc94 tsc95 tsc96 tsc97 
    tsc98 outside inveh inside locunk athome atwrksc elsewhr 
    lunk walone wchild wsppart wclsfam wother withunk lowqual 
    baddem caremflg origwght owghtflg xtimewt infltwt recwght 
    childm.

select if childm=1.

*this computation must be updated for every survey in accordance with the
*unreported activity types (-9s) in that particular survey.
compute t=sum(tmiss to tmain4) + sum(tmain6 to tmain42) + sum(tmain49 to tmain54) + 
          sum(tmain56 to tmain68) + sum(tmain71 to tmain73) + sum(tmain75 to tmain81) +
          sum(tmain84 to tmain98).
freq t.
*should total to 1440 minutes for all cases.

desc survey wave hhid pid diaryday cday month year tottime numep 
     t0pcare t1paid t2ed t3unpaid t4acvol t5outhm t6exerc t7inhm 
     t8media t9trav tmiss tmain1 to tsc98 outside inveh inside 
     locunk athome atwrksc elsewhr lunk walone wchild wsppart 
     wclsfam wother withunk xtimewt infltwt origwght recwght. 

freq survey wave diaryday cday month year tottime numep lowqual 
     baddem caremflg.

temp.
select if recwght=0.
cro lowqual by baddem. 

temp.
select if recwght~=0.
freq diaryday.

weight by recwght.
freq diaryday.
*all days should be 14.3%.

**child summary file**.
weight off.
apply dictionary from 'H:\evrim\AHTUS\schema1.sav'.
sort cases by survey wave hhid pid.
Save outfile='H:\evrim\AHTUS\2006\Harmonised files\USA2006youthsum.sav'
   /drop childm
   /compressed.

Get file='H:\evrim\AHTUS\2006\USA2006youthep.sav'
   /keep survey wave hhid pid diaryday cday month year time 
    clockst start end epnum main sec inout eloc mtrav alone 
    infant child sppart clsfam hhadult animal shoprof cowork 
    wellknw otherp unknwp lowqual baddem caremflg origwght 
    owghtflg xtimewt infltwt recwght childm.

select if childm=1.

desc survey wave hhid pid diaryday cday month year time clockst 
  start end epnum main sec inout eloc mtrav alone infant child 
  sppart clsfam hhadult animal shoprof cowork wellknw otherp 
  unknwp origwght xtimewt infltwt recwght. 

freq survey wave diaryday cday month year epnum main sec inout 
     eloc mtrav alone infant child sppart clsfam hhadult animal 
     shoprof cowork wellknw otherp unknwp lowqual baddem caremflg.


**child episode file**.
weight off.
apply dictionary from 'H:\evrim\AHTUS\schema1.sav'.
sort cases by survey wave hhid pid. 
Save outfile='H:\evrim\AHTUS\2006\harmonised Files\USA2006youthep.sav'
   /drop childm
   /compressed.

**********************************************
*put adult files in 'Harmonised Files' folder*
**********************************************.

**adult summary file**.

get file='H:\evrim\AHTUS\2006\USA2006hfsum.sav'.
sort cases by survey wave hhid pid. 

weight off.
apply dictionary from 'H:\evrim\AHTUS\schema2.sav'.
sort cases by survey wave hhid pid. 
Save outfile='H:\evrim\AHTUS\2006\Harmonised files\USA2006hfsum.sav'
   /keep survey wave hhid pid diaryday cday month year 
    tottime numep t0pcare t1paid t2ed t3unpaid t4acvol 
    t5outhm t6exerc t7inhm t8media t9trav tmiss tmain1 tmain2
    tmain3  tmain4  tmain5  tmain6  tmain7  tmain8  tmain9 
    tmain10 tmain11 tmain12 tmain13 tmain14 tmain15 tmain16 
    tmain17 tmain18 tmain19 tmain20 tmain21 tmain22 tmain23 
    tmain24 tmain25 tmain26 tmain27 tmain28 tmain29 tmain30 
    tmain31 tmain32 tmain33 tmain34 tmain35 tmain36 tmain37 
    tmain38 tmain39 tmain40 tmain41 tmain42 tmain43 tmain44 
    tmain45 tmain46 tmain48 tmain49 tmain50 tmain51 tmain52 
    tmain53 tmain54 tmain55 tmain56 tmain57 tmain58 tmain60 
    tmain62 tmain63 tmain64 tmain65 tmain66 tmain67 tmain68 
    tmain70 tmain71 tmain72 tmain73 tmain74 tmain75 tmain76 
    tmain77 tmain78 tmain81 tmain82 tmain83 tmain84 tmain85 
    tmain86 tmain87 tmain88 tmain89 tmain90 tmain91 tmain92 
    tmain93 tmain94 tmain95 tmain96 tmain97 tmain98 tsc1  
    tsc2  tsc3  tsc4  tsc5  tsc6  tsc7  tsc8  tsc9  tsc10
    tsc11 tsc12 tsc13 tsc14 tsc15 tsc16 tsc17 tsc18 tsc19 
    tsc20 tsc21 tsc22 tsc23 tsc24 tsc25 tsc26 tsc27 tsc28 
    tsc29 tsc30 tsc31 tsc32 tsc33 tsc34 tsc35 tsc36 tsc37 
    tsc38 tsc39 tsc40 tsc41 tsc42 tsc43 tsc44 tsc45 tsc46 
    tsc48 tsc49 tsc50 tsc51 tsc52 tsc53 tsc54 tsc55 tsc56 
    tsc57 tsc58 tsc60 tsc62 tsc63 tsc64 tsc65 tsc66 tsc67 
    tsc68 tsc70 tsc71 tsc72 tsc73 tsc74 tsc75 tsc76 tsc77 
    tsc78 tsc81 tsc82 tsc83 tsc84 tsc85 tsc86 tsc87 tsc88 
    tsc89 tsc90 tsc91 tsc92 tsc93 tsc94 tsc95 tsc96 tsc97 
    tsc98 outside inveh inside locunk athome atwrksc elsewhr 
    lunk walone wchild wsppart wclsfam wother withunk lowqual 
    baddem caremflg origwght owghtflg xtimewt infltwt recwght.

**adult episode file**.

get file='H:\evrim\AHTUS\2006\USA2006hfep.sav'.

weight off.
sort cases by survey wave hhid pid.
apply dictionary from 'H:\evrim\AHTUS\schema1.sav'.
Save outfile='H:\evrim\AHTUS\2006\Harmonised files\USA2006hfep.sav'
 /keep survey wave hhid pid diaryday cday month year time 
    clockst start end epnum main sec inout eloc mtrav alone 
    infant child sppart clsfam hhadult animal shoprof cowork 
    wellknw otherp unknwp lowqual baddem caremflg origwght 
    owghtflg xtimewt infltwt recwght.


**************************************************
**The end of the syntax producing 		**
**the USA heritage time use files BSL-ATUS 2006 ** 
**************************************************.



